@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:15-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:25-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1509,7 +1509,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-asmmac_so_21c63225b79ddfd1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+asmmac_so_feeff5c36028d06f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1660,7 +1660,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_asmmac_so_21c63225b79ddfd1 [3] =
+static const struct liarc_code_S arr_decl_asmmac_so_feeff5c36028d06f [3] =
   {
     { "asmmac_so_code_1", 13, asmmac_so_code_1 },
     { "asmmac_so_code_2", 10, asmmac_so_code_2 },
@@ -1668,19 +1668,19 @@ static const struct liarc_code_S arr_decl_asmmac_so_21c63225b79ddfd1 [3] =
   };
 
 int
-decl_asmmac_so_21c63225b79ddfd1 (void)
+decl_asmmac_so_feeff5c36028d06f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_asmmac_so_21c63225b79ddfd1);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_asmmac_so_feeff5c36028d06f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("asmmac.so", 7, decl_asmmac_so_21c63225b79ddfd1, asmmac_so_21c63225b79ddfd1)
+DECLARE_COMPILED_CODE ("asmmac.so", 7, decl_asmmac_so_feeff5c36028d06f, asmmac_so_feeff5c36028d06f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_asmmac_so_data_21c63225b79ddfd1 [1115] =
+static const unsigned char prog_asmmac_so_data_feeff5c36028d06f [1131] =
   "\x58\x0a\xef\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0d\x0d\xb9"
   "\xc1\xba\x08\x0d\x0d\x0d\xbb\x0d\xb3\x08\x8a\x08\x8a\xc1\xbb\x28"
   "\x0d\x28\x0d\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\x28\x0d\xbe\x23\x22"
@@ -1696,9 +1696,10 @@ static const unsigned char prog_asmmac_so_data_21c63225b79ddfd1 [1115] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbe\x9a\xbd"
   "\x88\xb5\xb6\x2a\x0d\xc2\x02\x02\x0d\xc3\xb4\x1b\x2a\xb7\x2a\x28"
   "\x0d\x26\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x21\x17\x02\x49\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74"
-  "\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d"
-  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f"
+  "\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53"
+  "\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72"
+  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74"
+  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f"
   "\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x63"
   "\x6b\x2f\x61\x73\x6d\x6d\x61\x63\x2e\x69\x6e\x66\x15\x23\x5b\x70"
   "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
@@ -1753,19 +1754,19 @@ static const unsigned char prog_asmmac_so_data_21c63225b79ddfd1 [1115] =
   "\x06\x81\x85\x02\x01\x04\x81\x83\x02\x0f\x21";
 
 SCHEME_OBJECT *
-asmmac_so_data_21c63225b79ddfd1 (entry_count_t dispatch_base)
+asmmac_so_data_feeff5c36028d06f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_asmmac_so_data_21c63225b79ddfd1 [0]))), (sizeof (prog_asmmac_so_data_21c63225b79ddfd1)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_asmmac_so_data_feeff5c36028d06f [0]))), (sizeof (prog_asmmac_so_data_feeff5c36028d06f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_11]));
 }
 
-DECLARE_COMPILED_DATA_NS ("asmmac.so", asmmac_so_data_21c63225b79ddfd1)
+DECLARE_COMPILED_DATA_NS ("asmmac.so", asmmac_so_data_feeff5c36028d06f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("asmmac.so", "1ff5aaf4dd4b2da4")
+DECLARE_DYNAMIC_INITIALIZATION ("asmmac.so", "12dc089e8dda5132")
