@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:16-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:25-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -494,7 +494,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-asutl_so_1093d704a6d266e1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+asutl_so_f52196d51fff5136 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -919,7 +919,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_asutl_so_1093d704a6d266e1 [7] =
+static const struct liarc_code_S arr_decl_asutl_so_f52196d51fff5136 [7] =
   {
     { "asutl_so_code_1", 1, asutl_so_code_1 },
     { "asutl_so_code_2", 1, asutl_so_code_2 },
@@ -931,19 +931,19 @@ static const struct liarc_code_S arr_decl_asutl_so_1093d704a6d266e1 [7] =
   };
 
 int
-decl_asutl_so_1093d704a6d266e1 (void)
+decl_asutl_so_f52196d51fff5136 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_asutl_so_1093d704a6d266e1);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_asutl_so_f52196d51fff5136);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("asutl.so", 16, decl_asutl_so_1093d704a6d266e1, asutl_so_1093d704a6d266e1)
+DECLARE_COMPILED_CODE ("asutl.so", 16, decl_asutl_so_f52196d51fff5136, asutl_so_f52196d51fff5136)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_asutl_so_data_1093d704a6d266e1 [681] =
+static const unsigned char prog_asutl_so_data_f52196d51fff5136 [697] =
   "\x3a\x0a\xa0\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x22\x29\x21"
   "\x9d\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0\x83"
   "\x88\x22\x29\x21\x9c\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c\x2b"
@@ -954,9 +954,10 @@ static const unsigned char prog_asutl_so_data_1093d704a6d266e1 [681] =
   "\x2a\xb1\x2a\x9e\x28\x0d\x26\x0d\x0d\x24\x28\xb6\x28\x0d\x28\x0d"
   "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x21\x17\x02\x48\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
-  "\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f"
-  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
+  "\x29\x21\x17\x02\x58\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
+  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
+  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
   "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61"
   "\x63\x6b\x2f\x61\x73\x75\x74\x6c\x2e\x69\x6e\x66\x15\x23\x5b\x70"
   "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
@@ -989,19 +990,19 @@ static const unsigned char prog_asutl_so_data_1093d704a6d266e1 [681] =
   "\x89\x02\x01\x04\x81\x83\x02\x21\x3a";
 
 SCHEME_OBJECT *
-asutl_so_data_1093d704a6d266e1 (entry_count_t dispatch_base)
+asutl_so_data_f52196d51fff5136 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_asutl_so_data_1093d704a6d266e1 [0]))), (sizeof (prog_asutl_so_data_1093d704a6d266e1)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_asutl_so_data_f52196d51fff5136 [0]))), (sizeof (prog_asutl_so_data_f52196d51fff5136)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_24]));
 }
 
-DECLARE_COMPILED_DATA_NS ("asutl.so", asutl_so_data_1093d704a6d266e1)
+DECLARE_COMPILED_DATA_NS ("asutl.so", asutl_so_data_f52196d51fff5136)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("asutl.so", "f8414914df5de92a")
+DECLARE_DYNAMIC_INITIALIZATION ("asutl.so", "7ced3580e668696b")
