@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:16-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:26-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -688,7 +688,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-insseq_so_b2705716ea95d075 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+insseq_so_396188da7d895554 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -770,7 +770,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_insseq_so_b2705716ea95d075 [5] =
+static const struct liarc_code_S arr_decl_insseq_so_396188da7d895554 [5] =
   {
     { "insseq_so_code_1", 1, insseq_so_code_1 },
     { "insseq_so_code_2", 1, insseq_so_code_2 },
@@ -780,19 +780,19 @@ static const struct liarc_code_S arr_decl_insseq_so_b2705716ea95d075 [5] =
   };
 
 int
-decl_insseq_so_b2705716ea95d075 (void)
+decl_insseq_so_396188da7d895554 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_insseq_so_b2705716ea95d075);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_insseq_so_396188da7d895554);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("insseq.so", 3, decl_insseq_so_b2705716ea95d075, insseq_so_b2705716ea95d075)
+DECLARE_COMPILED_CODE ("insseq.so", 3, decl_insseq_so_396188da7d895554, insseq_so_396188da7d895554)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_insseq_so_data_b2705716ea95d075 [585] =
+static const unsigned char prog_insseq_so_data_396188da7d895554 [601] =
   "\x1f\x08\x84\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\x08\x22"
   "\x29\x21\x9e\x2b\xba\x1d\xb0\x82\x88\x08\x22\x29\x21\x9d\x2b\xbb"
   "\x1d\xb0\x83\x88\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d"
@@ -801,10 +801,11 @@ static const unsigned char prog_insseq_so_data_b2705716ea95d075 [585] =
   "\x88\xc2\xb5\xb1\x08\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x21\x17\x2b\xbd\x9c\xb9\x88\xb1\xb5\x2a\xb6\x2a\xb4\x2a\xb3"
   "\x2a\x08\xb2\x2a\x9d\x0d\x0d\x0d\x0d\x0d\x0d\x9d\x28\x0d\x26\x22"
-  "\x29\x22\x29\x22\x29\x21\x17\x02\x49\x2f\x55\x73\x65\x72\x73\x2f"
-  "\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
-  "\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
-  "\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
+  "\x29\x22\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f"
+  "\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68"
+  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e"
+  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
   "\x72\x2f\x62\x61\x63\x6b\x2f\x69\x6e\x73\x73\x65\x71\x2e\x69\x6e"
   "\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"
   "\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x63\x61\x72\x04\x04\x83\x04\x03"
@@ -832,19 +833,19 @@ static const unsigned char prog_insseq_so_data_b2705716ea95d075 [585] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-insseq_so_data_b2705716ea95d075 (entry_count_t dispatch_base)
+insseq_so_data_396188da7d895554 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_insseq_so_data_b2705716ea95d075 [0]))), (sizeof (prog_insseq_so_data_b2705716ea95d075)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_insseq_so_data_396188da7d895554 [0]))), (sizeof (prog_insseq_so_data_396188da7d895554)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("insseq.so", insseq_so_data_b2705716ea95d075)
+DECLARE_COMPILED_DATA_NS ("insseq.so", insseq_so_data_396188da7d895554)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("insseq.so", "7d9399724c810cb0")
+DECLARE_DYNAMIC_INITIALIZATION ("insseq.so", "bd925d1520a6e958")
