@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:18-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:28-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -675,7 +675,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-symtab_so_25764e2646fd23d0 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+symtab_so_808f44fd7dd8bb42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -840,7 +840,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_symtab_so_25764e2646fd23d0 [7] =
+static const struct liarc_code_S arr_decl_symtab_so_808f44fd7dd8bb42 [7] =
   {
     { "symtab_so_code_1", 3, symtab_so_code_1 },
     { "symtab_so_code_2", 5, symtab_so_code_2 },
@@ -852,19 +852,19 @@ static const struct liarc_code_S arr_decl_symtab_so_25764e2646fd23d0 [7] =
   };
 
 int
-decl_symtab_so_25764e2646fd23d0 (void)
+decl_symtab_so_808f44fd7dd8bb42 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_symtab_so_25764e2646fd23d0);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_symtab_so_808f44fd7dd8bb42);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("symtab.so", 7, decl_symtab_so_25764e2646fd23d0, symtab_so_25764e2646fd23d0)
+DECLARE_COMPILED_CODE ("symtab.so", 7, decl_symtab_so_808f44fd7dd8bb42, symtab_so_808f44fd7dd8bb42)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_symtab_so_data_25764e2646fd23d0 [810] =
+static const unsigned char prog_symtab_so_data_808f44fd7dd8bb42 [826] =
   "\x22\x0a\xbe\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x08\x28\x0d"
   "\xb9\x28\x0d\x28\x0d\xba\x28\x0d\xbb\x23\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x2b\xbc\x1d\xb0\x82\x88\x0c\xc1\xbd\x0c\x28\xb1\x28\xb2"
@@ -877,9 +877,10 @@ static const unsigned char prog_symtab_so_data_25764e2646fd23d0 [810] =
   "\xb0\x2a\xb5\x2a\xb7\x2a\xb1\x2a\xb6\x2a\xb2\x2a\xb4\x2a\x9e\xb3"
   "\x0d\x0d\x0d\x0d\x0d\x0d\x9e\x07\x28\x0d\x26\x0d\x0d\x24\x28\x0d"
   "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
-  "\x17\x02\x49\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d"
-  "\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69"
-  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73"
+  "\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f"
+  "\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65"
+  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d"
+  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73"
   "\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x63\x6b"
   "\x2f\x73\x79\x6d\x74\x61\x62\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
   "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
@@ -918,19 +919,19 @@ static const unsigned char prog_symtab_so_data_25764e2646fd23d0 [810] =
   "\x81\x8b\x02\x01\x04\x81\x89\x02\x0f\x22";
 
 SCHEME_OBJECT *
-symtab_so_data_25764e2646fd23d0 (entry_count_t dispatch_base)
+symtab_so_data_808f44fd7dd8bb42 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_symtab_so_data_25764e2646fd23d0 [0]))), (sizeof (prog_symtab_so_data_25764e2646fd23d0)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_symtab_so_data_808f44fd7dd8bb42 [0]))), (sizeof (prog_symtab_so_data_808f44fd7dd8bb42)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_12]));
 }
 
-DECLARE_COMPILED_DATA_NS ("symtab.so", symtab_so_data_25764e2646fd23d0)
+DECLARE_COMPILED_DATA_NS ("symtab.so", symtab_so_data_808f44fd7dd8bb42)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("symtab.so", "19d3f465b4b51568")
+DECLARE_DYNAMIC_INITIALIZATION ("symtab.so", "d60258d7bead1b03")
