@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:20-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:29-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1372,7 +1372,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-contin_so_10520a7bb38145ed (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+contin_so_aecea5170464e637 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2542,7 +2542,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_contin_so_10520a7bb38145ed [10] =
+static const struct liarc_code_S arr_decl_contin_so_aecea5170464e637 [10] =
   {
     { "contin_so_code_1", 7, contin_so_code_1 },
     { "contin_so_code_2", 3, contin_so_code_2 },
@@ -2557,19 +2557,19 @@ static const struct liarc_code_S arr_decl_contin_so_10520a7bb38145ed [10] =
   };
 
 int
-decl_contin_so_10520a7bb38145ed (void)
+decl_contin_so_aecea5170464e637 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_contin_so_10520a7bb38145ed);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_contin_so_aecea5170464e637);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("contin.so", 68, decl_contin_so_10520a7bb38145ed, contin_so_10520a7bb38145ed)
+DECLARE_COMPILED_CODE ("contin.so", 68, decl_contin_so_aecea5170464e637, contin_so_aecea5170464e637)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_contin_so_data_10520a7bb38145ed [3215] =
+static const unsigned char prog_contin_so_data_aecea5170464e637 [3231] =
   "\xd9\x01\x14\x87\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc3\x02\x08"
   "\x0d\x0d\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xb9"
@@ -2602,10 +2602,11 @@ static const unsigned char prog_contin_so_data_10520a7bb38145ed [3215] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x49\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
+  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
   "\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f\x63\x6f\x6e\x74\x69"
   "\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0c\x76\x65\x63\x74"
@@ -2773,19 +2774,19 @@ static const unsigned char prog_contin_so_data_10520a7bb38145ed [3215] =
   "\x02\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\x89\x01\xd9\x01";
 
 SCHEME_OBJECT *
-contin_so_data_10520a7bb38145ed (entry_count_t dispatch_base)
+contin_so_data_aecea5170464e637 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_contin_so_data_10520a7bb38145ed [0]))), (sizeof (prog_contin_so_data_10520a7bb38145ed)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_contin_so_data_aecea5170464e637 [0]))), (sizeof (prog_contin_so_data_aecea5170464e637)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_74]));
 }
 
-DECLARE_COMPILED_DATA_NS ("contin.so", contin_so_data_10520a7bb38145ed)
+DECLARE_COMPILED_DATA_NS ("contin.so", contin_so_data_aecea5170464e637)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("contin.so", "27f59e8fd9f87b5e")
+DECLARE_DYNAMIC_INITIALIZATION ("contin.so", "419885123c99e6bd")
