@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:20-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:30-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2118,7 +2118,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-crstop_so_9b944ae011cefe43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+crstop_so_59fe619d4320b6ff (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2336,7 +2336,7 @@ DEFLABEL (continuation_5)
 INVOKE_INTERFACE_TARGET_1
 }
 
-static const struct liarc_code_S arr_decl_crstop_so_9b944ae011cefe43 [25] =
+static const struct liarc_code_S arr_decl_crstop_so_59fe619d4320b6ff [25] =
   {
     { "crstop_so_code_1", 1, crstop_so_code_1 },
     { "crstop_so_code_2", 1, crstop_so_code_2 },
@@ -2366,19 +2366,19 @@ static const struct liarc_code_S arr_decl_crstop_so_9b944ae011cefe43 [25] =
   };
 
 int
-decl_crstop_so_9b944ae011cefe43 (void)
+decl_crstop_so_59fe619d4320b6ff (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_crstop_so_9b944ae011cefe43);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_crstop_so_59fe619d4320b6ff);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("crstop.so", 6, decl_crstop_so_9b944ae011cefe43, crstop_so_9b944ae011cefe43)
+DECLARE_COMPILED_CODE ("crstop.so", 6, decl_crstop_so_59fe619d4320b6ff, crstop_so_59fe619d4320b6ff)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_crstop_so_data_9b944ae011cefe43 [1976] =
+static const unsigned char prog_crstop_so_data_59fe619d4320b6ff [1992] =
   "\x3e\x1f\xf5\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0\x83\x88"
   "\x22\x29\x21\x9c\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c\x2b\xbc"
@@ -2410,10 +2410,11 @@ static const unsigned char prog_crstop_so_data_9b944ae011cefe43 [1976] =
   "\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x0d\x0d\x17\x0d\x0c\x0d\x0d"
   "\x0d\x0d\x0d\x9c\x84\x83\x82\x81\x80\x9c\x1b\x2a\x1b\x2a\xb7\x2a"
   "\xb6\x2a\xb5\x2a\x85\x28\x0d\x28\x0d\x26\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x49\x2f\x55\x73\x65\x72\x73"
-  "\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65"
-  "\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
-  "\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
+  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73"
+  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63"
+  "\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
+  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
   "\x65\x72\x2f\x62\x61\x73\x65\x2f\x63\x72\x73\x74\x6f\x70\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
   "\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x07\x04\x82\x02\x03\x02\x08\x04"
@@ -2505,19 +2506,19 @@ static const unsigned char prog_crstop_so_data_9b944ae011cefe43 [1976] =
   "\x02\x01\x04\x81\x83\x02\x0d\x2c";
 
 SCHEME_OBJECT *
-crstop_so_data_9b944ae011cefe43 (entry_count_t dispatch_base)
+crstop_so_data_59fe619d4320b6ff (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_crstop_so_data_9b944ae011cefe43 [0]))), (sizeof (prog_crstop_so_data_9b944ae011cefe43)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_crstop_so_data_59fe619d4320b6ff [0]))), (sizeof (prog_crstop_so_data_59fe619d4320b6ff)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_11]));
 }
 
-DECLARE_COMPILED_DATA_NS ("crstop.so", crstop_so_data_9b944ae011cefe43)
+DECLARE_COMPILED_DATA_NS ("crstop.so", crstop_so_data_59fe619d4320b6ff)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("crstop.so", "10c1d9905d605b4c")
+DECLARE_DYNAMIC_INITIALIZATION ("crstop.so", "ee9070f3f7cb15a2")
