@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:22-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:32-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -224,7 +224,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-make_so_eec1953cfb6c441f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+make_so_f13b7169c8da347d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -276,27 +276,28 @@ INVOKE_INTERFACE_TARGET_4
 }
 
 int
-decl_make_so_eec1953cfb6c441f (void)
+decl_make_so_f13b7169c8da347d (void)
 {
   DECLARE_SUBCODE ("make_so_code_1", 10, make_so_code_1);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("make.so", 3, decl_make_so_eec1953cfb6c441f, make_so_eec1953cfb6c441f)
+DECLARE_COMPILED_CODE ("make.so", 3, decl_make_so_f13b7169c8da347d, make_so_f13b7169c8da347d)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_make_so_data_eec1953cfb6c441f [494] =
+static const unsigned char prog_make_so_data_f13b7169c8da347d [510] =
   "\x34\x02\x4d\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\x0d\x0d\x08\x89"
   "\x0d\x0c\x84\x02\x08\x89\x0c\x1d\x0c\x0d\x0d\x28\x0d\x28\x0d\x28"
   "\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
   "\x2b\xb8\x98\x88\xb0\xb0\x2a\x22\x29\x22\x29\x22\x29\x21\x17\x02"
-  "\x47\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63"
+  "\x57\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
+  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
+  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
   "\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f\x6d"
   "\x61\x6b\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
   "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x12\x6c\x65"
@@ -322,19 +323,19 @@ static const unsigned char prog_make_so_data_eec1953cfb6c441f [494] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x0d";
 
 SCHEME_OBJECT *
-make_so_data_eec1953cfb6c441f (entry_count_t dispatch_base)
+make_so_data_f13b7169c8da347d (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_make_so_data_eec1953cfb6c441f [0]))), (sizeof (prog_make_so_data_eec1953cfb6c441f)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_make_so_data_f13b7169c8da347d [0]))), (sizeof (prog_make_so_data_f13b7169c8da347d)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_6]));
 }
 
-DECLARE_COMPILED_DATA_NS ("make.so", make_so_data_eec1953cfb6c441f)
+DECLARE_COMPILED_DATA_NS ("make.so", make_so_data_f13b7169c8da347d)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("make.so", "943311b34ed9521a")
+DECLARE_DYNAMIC_INITIALIZATION ("make.so", "77d42fb4b2d8f2d8")
