@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:22-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:32-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1073,7 +1073,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-mvalue_so_0fe6e7b1e681fe8f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+mvalue_so_59a96199729f1702 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1161,7 +1161,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_mvalue_so_0fe6e7b1e681fe8f [11] =
+static const struct liarc_code_S arr_decl_mvalue_so_59a96199729f1702 [11] =
   {
     { "mvalue_so_code_1", 1, mvalue_so_code_1 },
     { "mvalue_so_code_2", 2, mvalue_so_code_2 },
@@ -1177,19 +1177,19 @@ static const struct liarc_code_S arr_decl_mvalue_so_0fe6e7b1e681fe8f [11] =
   };
 
 int
-decl_mvalue_so_0fe6e7b1e681fe8f (void)
+decl_mvalue_so_59a96199729f1702 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_mvalue_so_0fe6e7b1e681fe8f);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_mvalue_so_59a96199729f1702);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("mvalue.so", 3, decl_mvalue_so_0fe6e7b1e681fe8f, mvalue_so_0fe6e7b1e681fe8f)
+DECLARE_COMPILED_CODE ("mvalue.so", 3, decl_mvalue_so_59a96199729f1702, mvalue_so_59a96199729f1702)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_mvalue_so_data_0fe6e7b1e681fe8f [692] =
+static const unsigned char prog_mvalue_so_data_59a96199729f1702 [708] =
   "\x25\x10\xdd\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x0d\xba\x24\x22\x29\x22\x29\x21\x17\x2b"
   "\xbb\x1d\xb0\x83\x88\xc2\xbc\x22\x29\x22\x29\x21\x9f\x2b\xbd\x1d"
@@ -1204,9 +1204,10 @@ static const unsigned char prog_mvalue_so_data_0fe6e7b1e681fe8f [692] =
   "\x88\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb7\x2a"
   "\xb6\x2a\xb5\x2a\xb3\x2a\xb1\x2a\x17\xb2\x0d\x0d\x0d\x0d\x0d\x0d"
   "\x0d\xb0\xb4\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17"
-  "\x02\x49\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70"
-  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74"
-  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72"
+  "\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66"
+  "\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72"
   "\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f"
   "\x6d\x76\x61\x6c\x75\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
   "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
@@ -1236,19 +1237,19 @@ static const unsigned char prog_mvalue_so_data_0fe6e7b1e681fe8f [692] =
   "\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-mvalue_so_data_0fe6e7b1e681fe8f (entry_count_t dispatch_base)
+mvalue_so_data_59a96199729f1702 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_mvalue_so_data_0fe6e7b1e681fe8f [0]))), (sizeof (prog_mvalue_so_data_0fe6e7b1e681fe8f)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_mvalue_so_data_59a96199729f1702 [0]))), (sizeof (prog_mvalue_so_data_59a96199729f1702)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("mvalue.so", mvalue_so_data_0fe6e7b1e681fe8f)
+DECLARE_COMPILED_DATA_NS ("mvalue.so", mvalue_so_data_59a96199729f1702)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("mvalue.so", "ae51b0da2926e670")
+DECLARE_DYNAMIC_INITIALIZATION ("mvalue.so", "3349aec9a7ca905c")
