@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:23-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:32-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1229,7 +1229,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-pmlook_so_0e221b829373fcf0 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+pmlook_so_37005b77bdc6b23a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1312,7 +1312,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_pmlook_so_0e221b829373fcf0 [6] =
+static const struct liarc_code_S arr_decl_pmlook_so_37005b77bdc6b23a [6] =
   {
     { "pmlook_so_code_1", 5, pmlook_so_code_1 },
     { "pmlook_so_code_2", 17, pmlook_so_code_2 },
@@ -1323,19 +1323,19 @@ static const struct liarc_code_S arr_decl_pmlook_so_0e221b829373fcf0 [6] =
   };
 
 int
-decl_pmlook_so_0e221b829373fcf0 (void)
+decl_pmlook_so_37005b77bdc6b23a (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_pmlook_so_0e221b829373fcf0);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_pmlook_so_37005b77bdc6b23a);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("pmlook.so", 3, decl_pmlook_so_0e221b829373fcf0, pmlook_so_0e221b829373fcf0)
+DECLARE_COMPILED_CODE ("pmlook.so", 3, decl_pmlook_so_37005b77bdc6b23a, pmlook_so_37005b77bdc6b23a)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_pmlook_so_data_0e221b829373fcf0 [748] =
+static const unsigned char prog_pmlook_so_data_37005b77bdc6b23a [764] =
   "\x33\x0a\xc2\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\xc1\xba"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0"
   "\x82\x88\xb1\xb2\xc2\x08\x28\x0d\xbc\x28\x0d\x23\x22\x29\x22\x29"
@@ -1348,9 +1348,10 @@ static const unsigned char prog_pmlook_so_data_0e221b829373fcf0 [748] =
   "\x29\x21\x17\x2b\xba\x1d\xb0\x86\x88\xb1\x22\x29\x21\x9d\x2b\xb9"
   "\x9d\xb8\x88\xb0\xb1\x2a\x0d\xb2\x2a\x1b\x2a\xb6\x2a\xb5\x2a\xb3"
   "\x2a\x9e\x0d\xb7\xb4\x0d\x0d\x0d\x0d\x9e\x28\x0d\x26\x22\x29\x22"
-  "\x29\x22\x29\x21\x17\x02\x49\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
-  "\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
-  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
+  "\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d"
+  "\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f"
+  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
   "\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f"
   "\x62\x61\x73\x65\x2f\x70\x6d\x6c\x6f\x6f\x6b\x2e\x69\x6e\x66\x15"
   "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
@@ -1385,19 +1386,19 @@ static const unsigned char prog_pmlook_so_data_0e221b829373fcf0 [748] =
   "\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-pmlook_so_data_0e221b829373fcf0 (entry_count_t dispatch_base)
+pmlook_so_data_37005b77bdc6b23a (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_pmlook_so_data_0e221b829373fcf0 [0]))), (sizeof (prog_pmlook_so_data_0e221b829373fcf0)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_pmlook_so_data_37005b77bdc6b23a [0]))), (sizeof (prog_pmlook_so_data_37005b77bdc6b23a)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("pmlook.so", pmlook_so_data_0e221b829373fcf0)
+DECLARE_COMPILED_DATA_NS ("pmlook.so", pmlook_so_data_37005b77bdc6b23a)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("pmlook.so", "731bb3c77d6c35eb")
+DECLARE_DYNAMIC_INITIALIZATION ("pmlook.so", "4922a6ab2e0d3f86")
