@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:23-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:32-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -3385,7 +3385,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-pmpars_so_1ce703c6d630a1f2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+pmpars_so_326d3b5d1c641909 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3471,7 +3471,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_pmpars_so_1ce703c6d630a1f2 [9] =
+static const struct liarc_code_S arr_decl_pmpars_so_326d3b5d1c641909 [9] =
   {
     { "pmpars_so_code_1", 8, pmpars_so_code_1 },
     { "pmpars_so_code_2", 23, pmpars_so_code_2 },
@@ -3485,19 +3485,19 @@ static const struct liarc_code_S arr_decl_pmpars_so_1ce703c6d630a1f2 [9] =
   };
 
 int
-decl_pmpars_so_1ce703c6d630a1f2 (void)
+decl_pmpars_so_326d3b5d1c641909 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_pmpars_so_1ce703c6d630a1f2);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_pmpars_so_326d3b5d1c641909);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("pmpars.so", 3, decl_pmpars_so_1ce703c6d630a1f2, pmpars_so_1ce703c6d630a1f2)
+DECLARE_COMPILED_CODE ("pmpars.so", 3, decl_pmpars_so_326d3b5d1c641909, pmpars_so_326d3b5d1c641909)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_pmpars_so_data_1ce703c6d630a1f2 [1592] =
+static const unsigned char prog_pmpars_so_data_326d3b5d1c641909 [1608] =
   "\x56\x17\xb6\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28"
   "\x0d\xba\x28\x0d\x28\x0d\xbb\x23\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x82\x88"
@@ -3525,10 +3525,11 @@ static const unsigned char prog_pmpars_so_data_1ce703c6d630a1f2 [1592] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c\x88"
   "\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
   "\x2a\xb4\x2a\x17\x1b\x1b\x1b\x0d\xb3\xb2\x1b\xb1\x1b\x17\x28\x0d"
-  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x49\x2f\x55\x73\x65\x72"
-  "\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73"
-  "\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
+  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72"
+  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73"
+  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
   "\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f\x70\x6d\x70\x61\x72\x73\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x03\x12\x65\x78\x74\x72\x61"
@@ -3600,19 +3601,19 @@ static const unsigned char prog_pmpars_so_data_1ce703c6d630a1f2 [1592] =
   "\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-pmpars_so_data_1ce703c6d630a1f2 (entry_count_t dispatch_base)
+pmpars_so_data_326d3b5d1c641909 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_pmpars_so_data_1ce703c6d630a1f2 [0]))), (sizeof (prog_pmpars_so_data_1ce703c6d630a1f2)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_pmpars_so_data_326d3b5d1c641909 [0]))), (sizeof (prog_pmpars_so_data_326d3b5d1c641909)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("pmpars.so", pmpars_so_data_1ce703c6d630a1f2)
+DECLARE_COMPILED_DATA_NS ("pmpars.so", pmpars_so_data_326d3b5d1c641909)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("pmpars.so", "7dfcad31307d42ac")
+DECLARE_DYNAMIC_INITIALIZATION ("pmpars.so", "2d0b2ba9879c879c")
