@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:24-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:33-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2067,7 +2067,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-scode_so_4bbd6beda12d5d15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+scode_so_e3bde7c1d860f73c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2162,7 +2162,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_scode_so_4bbd6beda12d5d15 [18] =
+static const struct liarc_code_S arr_decl_scode_so_e3bde7c1d860f73c [18] =
   {
     { "scode_so_code_1", 1, scode_so_code_1 },
     { "scode_so_code_2", 1, scode_so_code_2 },
@@ -2185,19 +2185,19 @@ static const struct liarc_code_S arr_decl_scode_so_4bbd6beda12d5d15 [18] =
   };
 
 int
-decl_scode_so_4bbd6beda12d5d15 (void)
+decl_scode_so_e3bde7c1d860f73c (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_scode_so_4bbd6beda12d5d15);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_scode_so_e3bde7c1d860f73c);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("scode.so", 3, decl_scode_so_4bbd6beda12d5d15, scode_so_4bbd6beda12d5d15)
+DECLARE_COMPILED_CODE ("scode.so", 3, decl_scode_so_e3bde7c1d860f73c, scode_so_e3bde7c1d860f73c)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_scode_so_data_4bbd6beda12d5d15 [2126] =
+static const unsigned char prog_scode_so_data_e3bde7c1d860f73c [2142] =
   "\x4d\x23\xec\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0\x83\x88"
   "\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x84\x88\x08"
@@ -2229,9 +2229,10 @@ static const unsigned char prog_scode_so_data_4bbd6beda12d5d15 [2126] =
   "\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a\x0d\xb3\x2a\xb2\x2a\xb1\x2a\x17"
   "\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\xb5\x0d\xb4"
   "\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02"
-  "\x48\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63"
+  "\x58\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
+  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
+  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
   "\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61\x73\x65\x2f\x73"
   "\x63\x6f\x64\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x04"
@@ -2333,19 +2334,19 @@ static const unsigned char prog_scode_so_data_4bbd6beda12d5d15 [2126] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-scode_so_data_4bbd6beda12d5d15 (entry_count_t dispatch_base)
+scode_so_data_e3bde7c1d860f73c (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_scode_so_data_4bbd6beda12d5d15 [0]))), (sizeof (prog_scode_so_data_4bbd6beda12d5d15)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_scode_so_data_e3bde7c1d860f73c [0]))), (sizeof (prog_scode_so_data_e3bde7c1d860f73c)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("scode.so", scode_so_data_4bbd6beda12d5d15)
+DECLARE_COMPILED_DATA_NS ("scode.so", scode_so_data_e3bde7c1d860f73c)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("scode.so", "805ad530041eb905")
+DECLARE_DYNAMIC_INITIALIZATION ("scode.so", "bfe638471865dbd3")
