@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:24-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:34-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -16,7 +16,7 @@
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-switch_so_7077f3857c5705b7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+switch_so_055d1f72062c8b11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -66,26 +66,27 @@ INVOKE_INTERFACE_TARGET_4
 }
 
 int
-decl_switch_so_7077f3857c5705b7 (void)
+decl_switch_so_055d1f72062c8b11 (void)
 {
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("switch.so", 2, decl_switch_so_7077f3857c5705b7, switch_so_7077f3857c5705b7)
+DECLARE_COMPILED_CODE ("switch.so", 2, decl_switch_so_055d1f72062c8b11, switch_so_055d1f72062c8b11)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_switch_so_data_7077f3857c5705b7 [1125] =
+static const unsigned char prog_switch_so_data_055d1f72062c8b11 [1141] =
   "\x23\x01\x51\x1d\x0c\x06\x0d\x0d\x08\x89\x08\x88\x0d\x07\x07\x06"
   "\x06\x06\x06\x06\x07\x07\x07\x07\x06\x06\x07\x07\x07\x07\x07\x07"
   "\x07\x06\x06\x06\x06\x06\x07\x07\x07\x17\x0d\x0d\x0d\x0d\x0d\x0d"
   "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
   "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22"
-  "\x29\x21\x17\x02\x49\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
-  "\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f"
-  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
+  "\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
+  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
+  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
   "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61"
   "\x73\x65\x2f\x73\x77\x69\x74\x63\x68\x2e\x69\x6e\x66\x09\x75\x75"
   "\x6f\x2d\x6c\x69\x6e\x6b\x04\x61\x6c\x6c\x07\x68\x79\x62\x72\x69"
@@ -151,19 +152,19 @@ static const unsigned char prog_switch_so_data_7077f3857c5705b7 [1125] =
   "\x81\x81\x02\x05\x0d";
 
 SCHEME_OBJECT *
-switch_so_data_7077f3857c5705b7 (entry_count_t dispatch_base)
+switch_so_data_055d1f72062c8b11 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_switch_so_data_7077f3857c5705b7 [0]))), (sizeof (prog_switch_so_data_7077f3857c5705b7)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_switch_so_data_055d1f72062c8b11 [0]))), (sizeof (prog_switch_so_data_055d1f72062c8b11)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_6]));
 }
 
-DECLARE_COMPILED_DATA_NS ("switch.so", switch_so_data_7077f3857c5705b7)
+DECLARE_COMPILED_DATA_NS ("switch.so", switch_so_data_055d1f72062c8b11)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("switch.so", "8390eb5e55521968")
+DECLARE_DYNAMIC_INITIALIZATION ("switch.so", "eefd98481537b2be")
