@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:27-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:37-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1787,7 +1787,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-conect_so_f7da2daa61513893 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+conect_so_b13172cafef20853 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1870,7 +1870,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_conect_so_f7da2daa61513893 [6] =
+static const struct liarc_code_S arr_decl_conect_so_b13172cafef20853 [6] =
   {
     { "conect_so_code_1", 9, conect_so_code_1 },
     { "conect_so_code_2", 5, conect_so_code_2 },
@@ -1881,19 +1881,19 @@ static const struct liarc_code_S arr_decl_conect_so_f7da2daa61513893 [6] =
   };
 
 int
-decl_conect_so_f7da2daa61513893 (void)
+decl_conect_so_b13172cafef20853 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_conect_so_f7da2daa61513893);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_conect_so_b13172cafef20853);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("conect.so", 3, decl_conect_so_f7da2daa61513893, conect_so_f7da2daa61513893)
+DECLARE_COMPILED_CODE ("conect.so", 3, decl_conect_so_b13172cafef20853, conect_so_b13172cafef20853)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_conect_so_data_f7da2daa61513893 [1254] =
+static const unsigned char prog_conect_so_data_b13172cafef20853 [1270] =
   "\x68\x10\xb4\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x02\xc2\xb9\x84"
   "\x28\x0d\x28\x0d\xba\x28\x0d\xbb\x28\x0d\xbc\x23\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
@@ -1913,10 +1913,11 @@ static const unsigned char prog_conect_so_data_f7da2daa61513893 [1254] =
   "\x1d\x28\x1b\x28\xb3\x28\xb4\x23\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x2b\x1c\x9d\xbb\x88\xb3\x1b\x2a\xb6\x2a\x1b\x2a\x1b\x2a"
   "\x1b\x2a\xb5\x2a\x9d\xb7\x1b\x1b\x1b\xb4\x0d\x9d\x28\x0d\x26\x22"
-  "\x29\x22\x29\x22\x29\x21\x17\x02\x4a\x2f\x55\x73\x65\x72\x73\x2f"
-  "\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
-  "\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
-  "\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
+  "\x29\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55\x73\x65\x72\x73\x2f"
+  "\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68"
+  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e"
+  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
   "\x72\x2f\x66\x67\x6f\x70\x74\x2f\x63\x6f\x6e\x65\x63\x74\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
   "\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0b\x0b\x76\x65\x63\x74\x6f\x72"
@@ -1975,19 +1976,19 @@ static const unsigned char prog_conect_so_data_f7da2daa61513893 [1254] =
   "\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-conect_so_data_f7da2daa61513893 (entry_count_t dispatch_base)
+conect_so_data_b13172cafef20853 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_conect_so_data_f7da2daa61513893 [0]))), (sizeof (prog_conect_so_data_f7da2daa61513893)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_conect_so_data_b13172cafef20853 [0]))), (sizeof (prog_conect_so_data_b13172cafef20853)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("conect.so", conect_so_data_f7da2daa61513893)
+DECLARE_COMPILED_DATA_NS ("conect.so", conect_so_data_b13172cafef20853)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("conect.so", "0b386724ae408733")
+DECLARE_DYNAMIC_INITIALIZATION ("conect.so", "1820a5b2485010bb")
