@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:28-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:37-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -3232,7 +3232,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-contan_so_6a63d38e8b26945c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+contan_so_99eeab531c897de5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3316,7 +3316,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_contan_so_6a63d38e8b26945c [7] =
+static const struct liarc_code_S arr_decl_contan_so_99eeab531c897de5 [7] =
   {
     { "contan_so_code_1", 11, contan_so_code_1 },
     { "contan_so_code_2", 24, contan_so_code_2 },
@@ -3328,19 +3328,19 @@ static const struct liarc_code_S arr_decl_contan_so_6a63d38e8b26945c [7] =
   };
 
 int
-decl_contan_so_6a63d38e8b26945c (void)
+decl_contan_so_99eeab531c897de5 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_contan_so_6a63d38e8b26945c);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_contan_so_99eeab531c897de5);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("contan.so", 3, decl_contan_so_6a63d38e8b26945c, contan_so_6a63d38e8b26945c)
+DECLARE_COMPILED_CODE ("contan.so", 3, decl_contan_so_99eeab531c897de5, contan_so_99eeab531c897de5)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_contan_so_data_6a63d38e8b26945c [1909] =
+static const unsigned char prog_contan_so_data_99eeab531c897de5 [1925] =
   "\x5c\x14\xd9\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x02\x06\xc1\xb9"
   "\xc1\xba\x08\x02\xc3\xbb\x02\x1d\xc2\xbc\x82\x0d\xbd\x24\x28\x0d"
   "\xbe\x28\x0d\xbf\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -3370,10 +3370,11 @@ static const unsigned char prog_contan_so_data_6a63d38e8b26945c [1909] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x21\x17\x2b\x1c\x9e\x1c\x88\x1b\x1b\x2a\x1b\x2a\x1b\x2a"
   "\x1b\x2a\xb3\x2a\x1b\x2a\x1b\x2a\x9e\x1b\x1b\x0d\xb6\x0d\xb7\x0d"
-  "\x9e\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4a\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f"
+  "\x9e\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
+  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f"
   "\x6d\x70\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74\x2f\x63\x6f\x6e"
   "\x74\x61\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
   "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x14\x04\x63"
@@ -3463,19 +3464,19 @@ static const unsigned char prog_contan_so_data_6a63d38e8b26945c [1909] =
   "\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-contan_so_data_6a63d38e8b26945c (entry_count_t dispatch_base)
+contan_so_data_99eeab531c897de5 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_contan_so_data_6a63d38e8b26945c [0]))), (sizeof (prog_contan_so_data_6a63d38e8b26945c)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_contan_so_data_99eeab531c897de5 [0]))), (sizeof (prog_contan_so_data_99eeab531c897de5)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("contan.so", contan_so_data_6a63d38e8b26945c)
+DECLARE_COMPILED_DATA_NS ("contan.so", contan_so_data_99eeab531c897de5)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("contan.so", "7b5ad48806f7b46f")
+DECLARE_DYNAMIC_INITIALIZATION ("contan.so", "60b64df49c6b6747")
