@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:28-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:38-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1921,7 +1921,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-delint_so_ce51c1d399fa16cf (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+delint_so_06cc4fe940cc3240 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2002,7 +2002,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_delint_so_ce51c1d399fa16cf [4] =
+static const struct liarc_code_S arr_decl_delint_so_06cc4fe940cc3240 [4] =
   {
     { "delint_so_code_1", 4, delint_so_code_1 },
     { "delint_so_code_2", 30, delint_so_code_2 },
@@ -2011,19 +2011,19 @@ static const struct liarc_code_S arr_decl_delint_so_ce51c1d399fa16cf [4] =
   };
 
 int
-decl_delint_so_ce51c1d399fa16cf (void)
+decl_delint_so_06cc4fe940cc3240 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_delint_so_ce51c1d399fa16cf);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_delint_so_06cc4fe940cc3240);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("delint.so", 3, decl_delint_so_ce51c1d399fa16cf, delint_so_ce51c1d399fa16cf)
+DECLARE_COMPILED_CODE ("delint.so", 3, decl_delint_so_06cc4fe940cc3240, delint_so_06cc4fe940cc3240)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_delint_so_data_ce51c1d399fa16cf [1001] =
+static const unsigned char prog_delint_so_data_06cc4fe940cc3240 [1017] =
   "\x5e\x0c\xf7\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\xc2\xb9\x82"
   "\x0d\x24\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x2b\xbb\x1d\xb0\x82\x88\x1d\xc1\xbc\xc2\x85\x02\x02\xc3"
@@ -2039,10 +2039,11 @@ static const unsigned char prog_delint_so_data_ce51c1d399fa16cf [1001] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x9b\xbe\x88"
   "\xb6\x1b\x2a\x1b\x2a\x1b\x2a\xb3\x2a\x9b\xb7\xb5\xb2\x0d\x9b\x28"
-  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4a\x2f\x55\x73\x65"
-  "\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70"
+  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55\x73\x65"
+  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
+  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70"
   "\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74\x2f\x64\x65\x6c\x69\x6e"
   "\x74\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x02\x0b\x76\x65\x63"
@@ -2089,19 +2090,19 @@ static const unsigned char prog_delint_so_data_ce51c1d399fa16cf [1001] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-delint_so_data_ce51c1d399fa16cf (entry_count_t dispatch_base)
+delint_so_data_06cc4fe940cc3240 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_delint_so_data_ce51c1d399fa16cf [0]))), (sizeof (prog_delint_so_data_ce51c1d399fa16cf)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_delint_so_data_06cc4fe940cc3240 [0]))), (sizeof (prog_delint_so_data_06cc4fe940cc3240)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("delint.so", delint_so_data_ce51c1d399fa16cf)
+DECLARE_COMPILED_DATA_NS ("delint.so", delint_so_data_06cc4fe940cc3240)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("delint.so", "df0fa244dbfb4a26")
+DECLARE_DYNAMIC_INITIALIZATION ("delint.so", "e70872860b5036bb")
