@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:28-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:38-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1877,7 +1877,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-desenv_so_a87d288a73dac4e2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+desenv_so_750970c2d8965362 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1959,7 +1959,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_desenv_so_a87d288a73dac4e2 [5] =
+static const struct liarc_code_S arr_decl_desenv_so_750970c2d8965362 [5] =
   {
     { "desenv_so_code_1", 16, desenv_so_code_1 },
     { "desenv_so_code_2", 10, desenv_so_code_2 },
@@ -1969,19 +1969,19 @@ static const struct liarc_code_S arr_decl_desenv_so_a87d288a73dac4e2 [5] =
   };
 
 int
-decl_desenv_so_a87d288a73dac4e2 (void)
+decl_desenv_so_750970c2d8965362 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_desenv_so_a87d288a73dac4e2);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_desenv_so_750970c2d8965362);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("desenv.so", 3, decl_desenv_so_a87d288a73dac4e2, desenv_so_a87d288a73dac4e2)
+DECLARE_COMPILED_CODE ("desenv.so", 3, decl_desenv_so_750970c2d8965362, desenv_so_750970c2d8965362)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_desenv_so_data_a87d288a73dac4e2 [1079] =
+static const unsigned char prog_desenv_so_data_750970c2d8965362 [1095] =
   "\x45\x0c\x8d\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x02\x08\x02"
   "\xc3\xb9\x0c\x1d\x86\x02\x80\x02\xc2\xba\x82\x0d\x0d\x0d\x0d\x0d"
   "\x24\x28\x0d\x28\x0d\xbb\x28\x0d\x28\x0d\x28\x0d\xbc\x23\x22\x29"
@@ -1999,9 +1999,10 @@ static const unsigned char prog_desenv_so_data_a87d288a73dac4e2 [1079] =
   "\x85\x88\xb1\x02\xb2\x02\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xba"
   "\x9c\xb9\x88\xb1\xb2\x2a\xb6\x2a\x1b\x2a\x1b\x2a\xb5\x2a\x9c\x1b"
   "\xb7\xb4\xb3\x0d\x9c\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17"
-  "\x02\x4a\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70"
-  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74"
-  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72"
+  "\x02\x5a\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66"
+  "\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72"
   "\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74"
   "\x2f\x64\x65\x73\x65\x6e\x76\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
   "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
@@ -2052,19 +2053,19 @@ static const unsigned char prog_desenv_so_data_a87d288a73dac4e2 [1079] =
   "\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-desenv_so_data_a87d288a73dac4e2 (entry_count_t dispatch_base)
+desenv_so_data_750970c2d8965362 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_desenv_so_data_a87d288a73dac4e2 [0]))), (sizeof (prog_desenv_so_data_a87d288a73dac4e2)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_desenv_so_data_750970c2d8965362 [0]))), (sizeof (prog_desenv_so_data_750970c2d8965362)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("desenv.so", desenv_so_data_a87d288a73dac4e2)
+DECLARE_COMPILED_DATA_NS ("desenv.so", desenv_so_data_750970c2d8965362)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("desenv.so", "58e9b27008c292fe")
+DECLARE_DYNAMIC_INITIALIZATION ("desenv.so", "8cc3ef14d7353d94")
