@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:28-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:38-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -3098,7 +3098,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-folcon_so_5383f74b7e5753eb (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+folcon_so_8fc84afd89943e50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3184,7 +3184,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_folcon_so_5383f74b7e5753eb [9] =
+static const struct liarc_code_S arr_decl_folcon_so_8fc84afd89943e50 [9] =
   {
     { "folcon_so_code_1", 7, folcon_so_code_1 },
     { "folcon_so_code_2", 15, folcon_so_code_2 },
@@ -3198,19 +3198,19 @@ static const struct liarc_code_S arr_decl_folcon_so_5383f74b7e5753eb [9] =
   };
 
 int
-decl_folcon_so_5383f74b7e5753eb (void)
+decl_folcon_so_8fc84afd89943e50 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_folcon_so_5383f74b7e5753eb);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_folcon_so_8fc84afd89943e50);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("folcon.so", 3, decl_folcon_so_5383f74b7e5753eb, folcon_so_5383f74b7e5753eb)
+DECLARE_COMPILED_CODE ("folcon.so", 3, decl_folcon_so_8fc84afd89943e50, folcon_so_8fc84afd89943e50)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_folcon_so_data_5383f74b7e5753eb [2240] =
+static const unsigned char prog_folcon_so_data_8fc84afd89943e50 [2256] =
   "\x64\x17\xf7\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\x24\x28\x0d"
   "\x28\x0d\xb9\x28\x0d\xba\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\x07"
@@ -3242,10 +3242,11 @@ static const unsigned char prog_folcon_so_data_5383f74b7e5753eb [2240] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\xbf"
   "\x88\xb7\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
   "\x1b\x2a\xb3\x2a\x17\x1b\x1b\x1b\x1b\x1b\x1b\xb2\xb1\x0d\x17\x28"
-  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4a\x2f\x55\x73\x65"
-  "\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70"
+  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55\x73\x65"
+  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
+  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70"
   "\x69\x6c\x65\x72\x2f\x66\x67\x6f\x70\x74\x2f\x66\x6f\x6c\x63\x6f"
   "\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x19\x61\x70\x70\x6c"
@@ -3353,19 +3354,19 @@ static const unsigned char prog_folcon_so_data_5383f74b7e5753eb [2240] =
   "\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-folcon_so_data_5383f74b7e5753eb (entry_count_t dispatch_base)
+folcon_so_data_8fc84afd89943e50 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_folcon_so_data_5383f74b7e5753eb [0]))), (sizeof (prog_folcon_so_data_5383f74b7e5753eb)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_folcon_so_data_8fc84afd89943e50 [0]))), (sizeof (prog_folcon_so_data_8fc84afd89943e50)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("folcon.so", folcon_so_data_5383f74b7e5753eb)
+DECLARE_COMPILED_DATA_NS ("folcon.so", folcon_so_data_8fc84afd89943e50)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("folcon.so", "8de295b377af6ecd")
+DECLARE_DYNAMIC_INITIALIZATION ("folcon.so", "89d23c2ade262f05")
