@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:28-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:38-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1825,7 +1825,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-operan_so_0b5575480c8c187d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+operan_so_2e213af527440038 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1909,7 +1909,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_operan_so_0b5575480c8c187d [7] =
+static const struct liarc_code_S arr_decl_operan_so_2e213af527440038 [7] =
   {
     { "operan_so_code_1", 13, operan_so_code_1 },
     { "operan_so_code_2", 6, operan_so_code_2 },
@@ -1921,19 +1921,19 @@ static const struct liarc_code_S arr_decl_operan_so_0b5575480c8c187d [7] =
   };
 
 int
-decl_operan_so_0b5575480c8c187d (void)
+decl_operan_so_2e213af527440038 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_operan_so_0b5575480c8c187d);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_operan_so_2e213af527440038);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("operan.so", 3, decl_operan_so_0b5575480c8c187d, operan_so_0b5575480c8c187d)
+DECLARE_COMPILED_CODE ("operan.so", 3, decl_operan_so_2e213af527440038, operan_so_2e213af527440038)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_operan_so_data_0b5575480c8c187d [1129] =
+static const unsigned char prog_operan_so_data_2e213af527440038 [1145] =
   "\x38\x11\xb3\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc3\xb9\x02\x81"
   "\x82\x1d\x0d\xc2\xba\x85\x0d\x24\x28\x0d\xbb\x28\x0d\xbc\x28\x0d"
   "\xbd\x28\x0d\xbe\x28\x0d\xbf\x23\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -1953,10 +1953,11 @@ static const unsigned char prog_operan_so_data_0b5575480c8c187d [1129] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
   "\x9e\x1c\x88\x1b\x1b\x2a\x1b\x2a\xb1\x2a\x1b\x2a\x1b\x2a\xb3\x2a"
   "\x1b\x2a\x9e\xb6\x1b\x1b\xb7\xb5\xb4\x0d\x9e\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x4a\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72"
+  "\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72"
   "\x2f\x66\x67\x6f\x70\x74\x2f\x6f\x70\x65\x72\x61\x6e\x2e\x69\x6e"
   "\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"
   "\x2d\x72\x6f\x6f\x74\x5d\x02\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73"
@@ -2007,19 +2008,19 @@ static const unsigned char prog_operan_so_data_0b5575480c8c187d [1129] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-operan_so_data_0b5575480c8c187d (entry_count_t dispatch_base)
+operan_so_data_2e213af527440038 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_operan_so_data_0b5575480c8c187d [0]))), (sizeof (prog_operan_so_data_0b5575480c8c187d)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_operan_so_data_2e213af527440038 [0]))), (sizeof (prog_operan_so_data_2e213af527440038)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("operan.so", operan_so_data_0b5575480c8c187d)
+DECLARE_COMPILED_DATA_NS ("operan.so", operan_so_data_2e213af527440038)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("operan.so", "3a1574036913feaf")
+DECLARE_DYNAMIC_INITIALIZATION ("operan.so", "c7ebbcfa0984942d")
