@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:30-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:40-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2798,7 +2798,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-simple_so_a9488ee89c82fa37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+simple_so_036b8cad8f45e8a8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2884,7 +2884,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_simple_so_a9488ee89c82fa37 [9] =
+static const struct liarc_code_S arr_decl_simple_so_036b8cad8f45e8a8 [9] =
   {
     { "simple_so_code_1", 8, simple_so_code_1 },
     { "simple_so_code_2", 3, simple_so_code_2 },
@@ -2898,19 +2898,19 @@ static const struct liarc_code_S arr_decl_simple_so_a9488ee89c82fa37 [9] =
   };
 
 int
-decl_simple_so_a9488ee89c82fa37 (void)
+decl_simple_so_036b8cad8f45e8a8 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_simple_so_a9488ee89c82fa37);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_simple_so_036b8cad8f45e8a8);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("simple.so", 3, decl_simple_so_a9488ee89c82fa37, simple_so_a9488ee89c82fa37)
+DECLARE_COMPILED_CODE ("simple.so", 3, decl_simple_so_036b8cad8f45e8a8, simple_so_036b8cad8f45e8a8)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_simple_so_data_a9488ee89c82fa37 [1625] =
+static const unsigned char prog_simple_so_data_036b8cad8f45e8a8 [1641] =
   "\x95\x01\x12\xa3\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc3\xb9\x1d"
   "\x0d\xba\x84\xc2\xbb\x86\x0d\xbc\x24\x28\x0d\x23\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbd"
@@ -2937,10 +2937,11 @@ static const unsigned char prog_simple_so_data_a9488ee89c82fa37 [1625] =
   "\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x17\xb8\x88\xb0\xb3"
   "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb7\x2a\xb5"
   "\x2a\x17\x1b\xb1\x1b\x1b\xb2\xb6\x0d\xb4\x0d\x17\x28\x0d\x26\x22"
-  "\x29\x22\x29\x22\x29\x21\x17\x02\x4a\x2f\x55\x73\x65\x72\x73\x2f"
-  "\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
-  "\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
-  "\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
+  "\x29\x22\x29\x22\x29\x21\x17\x02\x5a\x2f\x55\x73\x65\x72\x73\x2f"
+  "\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68"
+  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e"
+  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65"
   "\x72\x2f\x66\x67\x6f\x70\x74\x2f\x73\x69\x6d\x70\x6c\x65\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
   "\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0d\x25\x72\x65\x63\x6f\x72\x64"
@@ -3015,19 +3016,19 @@ static const unsigned char prog_simple_so_data_a9488ee89c82fa37 [1625] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-simple_so_data_a9488ee89c82fa37 (entry_count_t dispatch_base)
+simple_so_data_036b8cad8f45e8a8 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_simple_so_data_a9488ee89c82fa37 [0]))), (sizeof (prog_simple_so_data_a9488ee89c82fa37)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_simple_so_data_036b8cad8f45e8a8 [0]))), (sizeof (prog_simple_so_data_036b8cad8f45e8a8)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("simple.so", simple_so_data_a9488ee89c82fa37)
+DECLARE_COMPILED_DATA_NS ("simple.so", simple_so_data_036b8cad8f45e8a8)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("simple.so", "5b0019d7556a4169")
+DECLARE_DYNAMIC_INITIALIZATION ("simple.so", "3df88a0255ce5ce6")
