@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:33-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:43-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1391,7 +1391,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rules2_so_8453a56336ecdc8e (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rules2_so_07ebe4ca6487f17d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1611,7 +1611,7 @@ DEFLABEL (continuation_8)
 INVOKE_INTERFACE_TARGET_1
 }
 
-static const struct liarc_code_S arr_decl_rules2_so_8453a56336ecdc8e [13] =
+static const struct liarc_code_S arr_decl_rules2_so_07ebe4ca6487f17d [13] =
   {
     { "rules2_so_code_1", 5, rules2_so_code_1 },
     { "rules2_so_code_2", 3, rules2_so_code_2 },
@@ -1629,19 +1629,19 @@ static const struct liarc_code_S arr_decl_rules2_so_8453a56336ecdc8e [13] =
   };
 
 int
-decl_rules2_so_8453a56336ecdc8e (void)
+decl_rules2_so_07ebe4ca6487f17d (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rules2_so_8453a56336ecdc8e);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rules2_so_07ebe4ca6487f17d);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rules2.so", 12, decl_rules2_so_8453a56336ecdc8e, rules2_so_8453a56336ecdc8e)
+DECLARE_COMPILED_CODE ("rules2.so", 12, decl_rules2_so_07ebe4ca6487f17d, rules2_so_07ebe4ca6487f17d)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rules2_so_data_8453a56336ecdc8e [1517] =
+static const unsigned char prog_rules2_so_data_07ebe4ca6487f17d [1533] =
   "\x38\x1d\x96\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x0d\xba"
   "\x0d\xbb\x0d\xbc\x0d\x88\x08\x89\xb3\xb4\x0d\x88\x08\x89\x08\x8a"
   "\xbd\x28\x0d\xbe\x28\x0d\xbf\x28\x0d\x1c\x23\x22\x29\x22\x29\x22"
@@ -1675,10 +1675,11 @@ static const unsigned char prog_rules2_so_data_8453a56336ecdc8e [1517] =
   "\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a"
   "\x1b\x1b\x2a\x1b\x1b\x2a\xb5\x1b\x2a\x28\x0d\x26\x28\x0d\x23\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4f\x2f\x55\x73\x65\x72"
-  "\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73"
-  "\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
+  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5f\x2f\x55\x73\x65\x72"
+  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73"
+  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
   "\x6c\x65\x72\x2f\x6d\x61\x63\x68\x69\x6e\x65\x73\x2f\x43\x2f\x72"
   "\x75\x6c\x65\x73\x32\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
   "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0e"
@@ -1739,19 +1740,19 @@ static const unsigned char prog_rules2_so_data_8453a56336ecdc8e [1517] =
   "\x02\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\x19\x38";
 
 SCHEME_OBJECT *
-rules2_so_data_8453a56336ecdc8e (entry_count_t dispatch_base)
+rules2_so_data_07ebe4ca6487f17d (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rules2_so_data_8453a56336ecdc8e [0]))), (sizeof (prog_rules2_so_data_8453a56336ecdc8e)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rules2_so_data_07ebe4ca6487f17d [0]))), (sizeof (prog_rules2_so_data_07ebe4ca6487f17d)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_17]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rules2.so", rules2_so_data_8453a56336ecdc8e)
+DECLARE_COMPILED_DATA_NS ("rules2.so", rules2_so_data_07ebe4ca6487f17d)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rules2.so", "ed23de4ef4f8f5ac")
+DECLARE_DYNAMIC_INITIALIZATION ("rules2.so", "1b8f9a3079068790")
