@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:34-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:43-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1693,7 +1693,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rules4_so_0e5690cd1fe19262 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rules4_so_d9fe8e2a2ecbe3cb (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1929,7 +1929,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_rules4_so_0e5690cd1fe19262 [11] =
+static const struct liarc_code_S arr_decl_rules4_so_d9fe8e2a2ecbe3cb [11] =
   {
     { "rules4_so_code_1", 8, rules4_so_code_1 },
     { "rules4_so_code_2", 9, rules4_so_code_2 },
@@ -1945,19 +1945,19 @@ static const struct liarc_code_S arr_decl_rules4_so_0e5690cd1fe19262 [11] =
   };
 
 int
-decl_rules4_so_0e5690cd1fe19262 (void)
+decl_rules4_so_d9fe8e2a2ecbe3cb (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rules4_so_0e5690cd1fe19262);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rules4_so_d9fe8e2a2ecbe3cb);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rules4.so", 13, decl_rules4_so_0e5690cd1fe19262, rules4_so_0e5690cd1fe19262)
+DECLARE_COMPILED_CODE ("rules4.so", 13, decl_rules4_so_d9fe8e2a2ecbe3cb, rules4_so_d9fe8e2a2ecbe3cb)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rules4_so_data_0e5690cd1fe19262 [1876] =
+static const unsigned char prog_rules4_so_data_d9fe8e2a2ecbe3cb [1892] =
   "\x3a\x24\xcf\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x02\x02\x08\x0d"
   "\xb9\x0d\x0d\xba\x0d\xbb\x88\x0d\xbc\xb2\x0d\xbd\x88\x08\x89\xb2"
   "\x0d\xbe\x88\x08\x8b\xbf\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28"
@@ -1995,9 +1995,10 @@ static const unsigned char prog_rules4_so_data_0e5690cd1fe19262 [1876] =
   "\x2a\x1b\x1b\x2a\xb6\x1b\x2a\x1b\x1b\x2a\xb5\xb1\x2a\x1b\x1b\x2a"
   "\xb7\x1b\x2a\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x21\x17\x02\x4f\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74"
-  "\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d"
-  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f"
+  "\x21\x17\x02\x5f\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53"
+  "\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72"
+  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74"
+  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f"
   "\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x6d\x61\x63"
   "\x68\x69\x6e\x65\x73\x2f\x43\x2f\x72\x75\x6c\x65\x73\x34\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
@@ -2078,19 +2079,19 @@ static const unsigned char prog_rules4_so_data_0e5690cd1fe19262 [1876] =
   "\x83\x02\x1b\x3a";
 
 SCHEME_OBJECT *
-rules4_so_data_0e5690cd1fe19262 (entry_count_t dispatch_base)
+rules4_so_data_d9fe8e2a2ecbe3cb (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rules4_so_data_0e5690cd1fe19262 [0]))), (sizeof (prog_rules4_so_data_0e5690cd1fe19262)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rules4_so_data_d9fe8e2a2ecbe3cb [0]))), (sizeof (prog_rules4_so_data_d9fe8e2a2ecbe3cb)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_17]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rules4.so", rules4_so_data_0e5690cd1fe19262)
+DECLARE_COMPILED_DATA_NS ("rules4.so", rules4_so_data_d9fe8e2a2ecbe3cb)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rules4.so", "5fb5c302eb8ed6fa")
+DECLARE_DYNAMIC_INITIALIZATION ("rules4.so", "e75139a54000daef")
