@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:35-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:45-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2693,7 +2693,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rgraph_so_588939f807ac5fed (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rgraph_so_a607e77d8d9c1473 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2979,7 +2979,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_rgraph_so_588939f807ac5fed [35] =
+static const struct liarc_code_S arr_decl_rgraph_so_a607e77d8d9c1473 [35] =
   {
     { "rgraph_so_code_1", 1, rgraph_so_code_1 },
     { "rgraph_so_code_2", 1, rgraph_so_code_2 },
@@ -3019,19 +3019,19 @@ static const struct liarc_code_S arr_decl_rgraph_so_588939f807ac5fed [35] =
   };
 
 int
-decl_rgraph_so_588939f807ac5fed (void)
+decl_rgraph_so_a607e77d8d9c1473 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rgraph_so_588939f807ac5fed);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rgraph_so_a607e77d8d9c1473);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rgraph.so", 10, decl_rgraph_so_588939f807ac5fed, rgraph_so_588939f807ac5fed)
+DECLARE_COMPILED_CODE ("rgraph.so", 10, decl_rgraph_so_a607e77d8d9c1473, rgraph_so_a607e77d8d9c1473)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rgraph_so_data_588939f807ac5fed [2322] =
+static const unsigned char prog_rgraph_so_data_a607e77d8d9c1473 [2338] =
   "\x3c\x26\xf9\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x08\x22\x29\x21\x9d\x2b\xba\x1d\xb0\x83"
   "\x88\x08\x22\x29\x21\x9d\x2b\xbb\x1d\xb0\x84\x88\x22\x29\x21\x9c"
@@ -3071,10 +3071,11 @@ static const unsigned char prog_rgraph_so_data_588939f807ac5fed [2322] =
   "\x02\x86\x85\x84\x83\x82\x81\x80\x17\x1b\x2a\x1b\x2a\x1b\x2a\xb7"
   "\x2a\xb6\x2a\xb5\x2a\xb4\x2a\xb3\x2a\xb2\x2a\xb1\x2a\x02\x28\x0d"
   "\x28\x0d\x26\x1b\x1b\x24\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4c\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5c\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
+  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f"
   "\x6d\x70\x69\x6c\x65\x72\x2f\x72\x74\x6c\x62\x61\x73\x65\x2f\x72"
   "\x67\x72\x61\x70\x68\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
   "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0b"
@@ -3180,19 +3181,19 @@ static const unsigned char prog_rgraph_so_data_588939f807ac5fed [2322] =
   "\x15\x39";
 
 SCHEME_OBJECT *
-rgraph_so_data_588939f807ac5fed (entry_count_t dispatch_base)
+rgraph_so_data_a607e77d8d9c1473 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rgraph_so_data_588939f807ac5fed [0]))), (sizeof (prog_rgraph_so_data_588939f807ac5fed)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rgraph_so_data_a607e77d8d9c1473 [0]))), (sizeof (prog_rgraph_so_data_a607e77d8d9c1473)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_15]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rgraph.so", rgraph_so_data_588939f807ac5fed)
+DECLARE_COMPILED_DATA_NS ("rgraph.so", rgraph_so_data_a607e77d8d9c1473)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rgraph.so", "ad58339dde2c1b1f")
+DECLARE_DYNAMIC_INITIALIZATION ("rgraph.so", "f1a7536ea9039e1b")
