@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:38-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:48-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2602,7 +2602,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-fndblk_so_c7b7feba181ad8dd (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+fndblk_so_abb57aaf9c5d8945 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2690,7 +2690,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_fndblk_so_c7b7feba181ad8dd [11] =
+static const struct liarc_code_S arr_decl_fndblk_so_abb57aaf9c5d8945 [11] =
   {
     { "fndblk_so_code_1", 3, fndblk_so_code_1 },
     { "fndblk_so_code_2", 8, fndblk_so_code_2 },
@@ -2706,19 +2706,19 @@ static const struct liarc_code_S arr_decl_fndblk_so_c7b7feba181ad8dd [11] =
   };
 
 int
-decl_fndblk_so_c7b7feba181ad8dd (void)
+decl_fndblk_so_abb57aaf9c5d8945 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_fndblk_so_c7b7feba181ad8dd);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_fndblk_so_abb57aaf9c5d8945);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("fndblk.so", 3, decl_fndblk_so_c7b7feba181ad8dd, fndblk_so_c7b7feba181ad8dd)
+DECLARE_COMPILED_CODE ("fndblk.so", 3, decl_fndblk_so_abb57aaf9c5d8945, fndblk_so_abb57aaf9c5d8945)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_fndblk_so_data_c7b7feba181ad8dd [1988] =
+static const unsigned char prog_fndblk_so_data_abb57aaf9c5d8945 [2004] =
   "\x58\x17\xb0\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28"
   "\x0d\xba\x28\x0d\xbb\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc"
   "\x1d\xb0\x82\x88\x0d\x0c\x0d\xbd\x08\x0d\xc2\xbe\x82\x0c\x0d\xbf"
@@ -2746,9 +2746,10 @@ static const unsigned char prog_fndblk_so_data_c7b7feba181ad8dd [1988] =
   "\xbd\x17\xb8\x88\xb0\xb5\x2a\x1b\x2a\x1b\x2a\xb6\x2a\x1b\x2a\x1b"
   "\x2a\xb1\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb4\x2a\x17\x1b\xb7\x1b\x1b"
   "\x1b\x1b\x1b\x1b\xb3\xb2\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22"
-  "\x29\x21\x17\x02\x4b\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
-  "\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f"
-  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
+  "\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
+  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
+  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
   "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x72\x74"
   "\x6c\x67\x65\x6e\x2f\x66\x6e\x64\x62\x6c\x6b\x2e\x69\x6e\x66\x15"
   "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
@@ -2846,19 +2847,19 @@ static const unsigned char prog_fndblk_so_data_c7b7feba181ad8dd [1988] =
   "\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-fndblk_so_data_c7b7feba181ad8dd (entry_count_t dispatch_base)
+fndblk_so_data_abb57aaf9c5d8945 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_fndblk_so_data_c7b7feba181ad8dd [0]))), (sizeof (prog_fndblk_so_data_c7b7feba181ad8dd)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_fndblk_so_data_abb57aaf9c5d8945 [0]))), (sizeof (prog_fndblk_so_data_abb57aaf9c5d8945)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("fndblk.so", fndblk_so_data_c7b7feba181ad8dd)
+DECLARE_COMPILED_DATA_NS ("fndblk.so", fndblk_so_data_abb57aaf9c5d8945)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("fndblk.so", "194dc85778d4b00e")
+DECLARE_DYNAMIC_INITIALIZATION ("fndblk.so", "c856f87876f6ee1c")
