@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:42-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:52-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1100,7 +1100,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rcseep_so_c15173d7e18db9fc (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rcseep_so_8f7c838e42be1d36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1181,7 +1181,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_rcseep_so_c15173d7e18db9fc [4] =
+static const struct liarc_code_S arr_decl_rcseep_so_8f7c838e42be1d36 [4] =
   {
     { "rcseep_so_code_1", 22, rcseep_so_code_1 },
     { "rcseep_so_code_2", 4, rcseep_so_code_2 },
@@ -1190,19 +1190,19 @@ static const struct liarc_code_S arr_decl_rcseep_so_c15173d7e18db9fc [4] =
   };
 
 int
-decl_rcseep_so_c15173d7e18db9fc (void)
+decl_rcseep_so_8f7c838e42be1d36 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcseep_so_c15173d7e18db9fc);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcseep_so_8f7c838e42be1d36);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rcseep.so", 3, decl_rcseep_so_c15173d7e18db9fc, rcseep_so_c15173d7e18db9fc)
+DECLARE_COMPILED_CODE ("rcseep.so", 3, decl_rcseep_so_8f7c838e42be1d36, rcseep_so_8f7c838e42be1d36)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rcseep_so_data_c15173d7e18db9fc [905] =
+static const unsigned char prog_rcseep_so_data_8f7c838e42be1d36 [921] =
   "\x4a\x0b\xc8\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x84\xc2\x85\x07"
   "\x86\x0d\xb9\x0d\xba\x08\x89\x0d\xc1\xbb\x0d\x24\x28\x0d\xbc\x28"
   "\x0d\xbd\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22"
@@ -1215,10 +1215,11 @@ static const unsigned char prog_rcseep_so_data_c15173d7e18db9fc [905] =
   "\xb2\x0d\x0d\x08\x8b\x0d\xbb\x24\x28\x0d\xba\x28\xb4\x28\x1b\x23"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x9b\xbc"
   "\x88\xb4\x1b\x2a\xb5\x2a\x1b\x2a\xb6\x2a\x9b\xb3\xb2\x0d\xb7\x9b"
-  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4b\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
+  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d"
   "\x70\x69\x6c\x65\x72\x2f\x72\x74\x6c\x6f\x70\x74\x2f\x72\x63\x73"
   "\x65\x65\x70\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
   "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0b\x76\x65"
@@ -1262,19 +1263,19 @@ static const unsigned char prog_rcseep_so_data_c15173d7e18db9fc [905] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-rcseep_so_data_c15173d7e18db9fc (entry_count_t dispatch_base)
+rcseep_so_data_8f7c838e42be1d36 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rcseep_so_data_c15173d7e18db9fc [0]))), (sizeof (prog_rcseep_so_data_c15173d7e18db9fc)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rcseep_so_data_8f7c838e42be1d36 [0]))), (sizeof (prog_rcseep_so_data_8f7c838e42be1d36)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rcseep.so", rcseep_so_data_c15173d7e18db9fc)
+DECLARE_COMPILED_DATA_NS ("rcseep.so", rcseep_so_data_8f7c838e42be1d36)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rcseep.so", "cf3778f5b08c16ec")
+DECLARE_DYNAMIC_INITIALIZATION ("rcseep.so", "e3269b8de97d6876")
