@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:42-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:52-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2335,7 +2335,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rcsesr_so_667df8e8a36c702a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rcsesr_so_cf24852381b55d8c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2591,7 +2591,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_rcsesr_so_667df8e8a36c702a [11] =
+static const struct liarc_code_S arr_decl_rcsesr_so_cf24852381b55d8c [11] =
   {
     { "rcsesr_so_code_1", 1, rcsesr_so_code_1 },
     { "rcsesr_so_code_2", 8, rcsesr_so_code_2 },
@@ -2607,19 +2607,19 @@ static const struct liarc_code_S arr_decl_rcsesr_so_667df8e8a36c702a [11] =
   };
 
 int
-decl_rcsesr_so_667df8e8a36c702a (void)
+decl_rcsesr_so_cf24852381b55d8c (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcsesr_so_667df8e8a36c702a);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rcsesr_so_cf24852381b55d8c);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rcsesr.so", 12, decl_rcsesr_so_667df8e8a36c702a, rcsesr_so_667df8e8a36c702a)
+DECLARE_COMPILED_CODE ("rcsesr.so", 12, decl_rcsesr_so_cf24852381b55d8c, rcsesr_so_cf24852381b55d8c)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rcsesr_so_data_667df8e8a36c702a [1683] =
+static const unsigned char prog_rcsesr_so_data_cf24852381b55d8c [1699] =
   "\x33\x12\xb5\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x07\x87\xc1\xba\x0d\xc1\xbb\x28\x0d\xbc"
   "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
@@ -2647,10 +2647,11 @@ static const unsigned char prog_rcsesr_so_data_667df8e8a36c702a [1683] =
   "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb4\x2a\xb6\x2a\xb5\x2a\xb1\x2a\x1e"
   "\x1e\x17\x28\x0d\x26\x0d\x0d\x0d\x24\x28\x0d\x28\x0d\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4b\x2f\x55\x73\x65\x72\x73"
-  "\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65"
-  "\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
-  "\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
+  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72\x73"
+  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63"
+  "\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
+  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c"
   "\x65\x72\x2f\x72\x74\x6c\x6f\x70\x74\x2f\x72\x63\x73\x65\x73\x72"
   "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
   "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0d\x04\x83\x04\x03\x02"
@@ -2728,19 +2729,19 @@ static const unsigned char prog_rcsesr_so_data_667df8e8a36c702a [1683] =
   "\x02\x19\x2f";
 
 SCHEME_OBJECT *
-rcsesr_so_data_667df8e8a36c702a (entry_count_t dispatch_base)
+rcsesr_so_data_cf24852381b55d8c (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rcsesr_so_data_667df8e8a36c702a [0]))), (sizeof (prog_rcsesr_so_data_667df8e8a36c702a)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rcsesr_so_data_cf24852381b55d8c [0]))), (sizeof (prog_rcsesr_so_data_cf24852381b55d8c)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_18]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rcsesr.so", rcsesr_so_data_667df8e8a36c702a)
+DECLARE_COMPILED_DATA_NS ("rcsesr.so", rcsesr_so_data_cf24852381b55d8c)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rcsesr.so", "bd456cd1dae98e4d")
+DECLARE_DYNAMIC_INITIALIZATION ("rcsesr.so", "b98eb9f8903e4026")
