@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:42-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:52-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1598,7 +1598,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-rdebug_so_4c4b040c17adb407 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+rdebug_so_64002c58cfa55a4b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1677,26 +1677,26 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_rdebug_so_4c4b040c17adb407 [2] =
+static const struct liarc_code_S arr_decl_rdebug_so_64002c58cfa55a4b [2] =
   {
     { "rdebug_so_code_1", 39, rdebug_so_code_1 },
     { "rdebug_so_code_2", 25, rdebug_so_code_2 }
   };
 
 int
-decl_rdebug_so_4c4b040c17adb407 (void)
+decl_rdebug_so_64002c58cfa55a4b (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_rdebug_so_4c4b040c17adb407);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_rdebug_so_64002c58cfa55a4b);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("rdebug.so", 3, decl_rdebug_so_4c4b040c17adb407, rdebug_so_4c4b040c17adb407)
+DECLARE_COMPILED_CODE ("rdebug.so", 3, decl_rdebug_so_64002c58cfa55a4b, rdebug_so_64002c58cfa55a4b)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_rdebug_so_data_4c4b040c17adb407 [1171] =
+static const unsigned char prog_rdebug_so_data_64002c58cfa55a4b [1187] =
   "\x77\x09\xf6\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0c\x0c\x0c"
   "\x0d\x85\x0c\x86\x0c\x0c\x83\x0c\xc2\xb9\x84\x1d\x0d\xba\x25\xb2"
   "\x24\x28\x0d\xbb\x28\x0d\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\xbe\x28"
@@ -1712,10 +1712,11 @@ static const unsigned char prog_rdebug_so_data_4c4b040c17adb407 [1171] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
   "\x2b\xbe\x99\xbd\x88\xb5\xb6\x2a\xb7\x2a\x99\x0d\x0d\x99\x28\x0d"
-  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4b\x2f\x55\x73\x65\x72"
-  "\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73"
-  "\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
+  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5b\x2f\x55\x73\x65\x72"
+  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73"
+  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69"
   "\x6c\x65\x72\x2f\x72\x74\x6c\x6f\x70\x74\x2f\x72\x64\x65\x62\x75"
   "\x67\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x10\x3b\x20\x63\x72"
@@ -1773,19 +1774,19 @@ static const unsigned char prog_rdebug_so_data_4c4b040c17adb407 [1171] =
   "\x02\x07\x11";
 
 SCHEME_OBJECT *
-rdebug_so_data_4c4b040c17adb407 (entry_count_t dispatch_base)
+rdebug_so_data_64002c58cfa55a4b (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_rdebug_so_data_4c4b040c17adb407 [0]))), (sizeof (prog_rdebug_so_data_4c4b040c17adb407)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_rdebug_so_data_64002c58cfa55a4b [0]))), (sizeof (prog_rdebug_so_data_64002c58cfa55a4b)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("rdebug.so", rdebug_so_data_4c4b040c17adb407)
+DECLARE_COMPILED_DATA_NS ("rdebug.so", rdebug_so_data_64002c58cfa55a4b)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("rdebug.so", "5c9f208ed095198c")
+DECLARE_DYNAMIC_INITIALIZATION ("rdebug.so", "6182f8e98104cd11")
