@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:32:53-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:02-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -469,7 +469,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-mset_so_f5f26bdb809aee31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+mset_so_1b81b937a3117016 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -548,35 +548,36 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_mset_so_f5f26bdb809aee31 [2] =
+static const struct liarc_code_S arr_decl_mset_so_1b81b937a3117016 [2] =
   {
     { "mset_so_code_1", 6, mset_so_code_1 },
     { "mset_so_code_2", 8, mset_so_code_2 }
   };
 
 int
-decl_mset_so_f5f26bdb809aee31 (void)
+decl_mset_so_1b81b937a3117016 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_mset_so_f5f26bdb809aee31);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_mset_so_1b81b937a3117016);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("mset.so", 3, decl_mset_so_f5f26bdb809aee31, mset_so_f5f26bdb809aee31)
+DECLARE_COMPILED_CODE ("mset.so", 3, decl_mset_so_1b81b937a3117016, mset_so_1b81b937a3117016)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_mset_so_data_f5f26bdb809aee31 [339] =
+static const unsigned char prog_mset_so_data_1b81b937a3117016 [355] =
   "\x1e\x07\x5a\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\xc1\xba\x08"
   "\x28\x0d\xbb\x28\x0d\xbc\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x82\x88\xb2\xb1\x08\x28\xb4"
   "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x21\x17\x2b\xbc\x99\xba\x88\xb2\xb4\x2a\xb5\x2a\x99\x0d\xb3"
-  "\x99\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x3e\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x63\x72"
+  "\x99\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4e\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
+  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x63\x72"
   "\x65\x66\x2f\x6d\x73\x65\x74\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
   "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
   "\x02\x04\x63\x61\x72\x04\x63\x64\x72\x03\x0e\x6d\x75\x6c\x74\x69"
@@ -592,19 +593,19 @@ static const unsigned char prog_mset_so_data_f5f26bdb809aee31 [339] =
   "\x02\x07\x11";
 
 SCHEME_OBJECT *
-mset_so_data_f5f26bdb809aee31 (entry_count_t dispatch_base)
+mset_so_data_1b81b937a3117016 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_mset_so_data_f5f26bdb809aee31 [0]))), (sizeof (prog_mset_so_data_f5f26bdb809aee31)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_mset_so_data_1b81b937a3117016 [0]))), (sizeof (prog_mset_so_data_1b81b937a3117016)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("mset.so", mset_so_data_f5f26bdb809aee31)
+DECLARE_COMPILED_DATA_NS ("mset.so", mset_so_data_1b81b937a3117016)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("mset.so", "8867ae1bb4247b3e")
+DECLARE_DYNAMIC_INITIALIZATION ("mset.so", "2fe44a0fd75bd368")
