@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:05-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:15-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1049,7 +1049,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-apply_so_b7df3bf61bb95e3b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+apply_so_5936e05ab1ed7eb5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1129,7 +1129,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_apply_so_b7df3bf61bb95e3b [3] =
+static const struct liarc_code_S arr_decl_apply_so_5936e05ab1ed7eb5 [3] =
   {
     { "apply_so_code_1", 12, apply_so_code_1 },
     { "apply_so_code_2", 10, apply_so_code_2 },
@@ -1137,19 +1137,19 @@ static const struct liarc_code_S arr_decl_apply_so_b7df3bf61bb95e3b [3] =
   };
 
 int
-decl_apply_so_b7df3bf61bb95e3b (void)
+decl_apply_so_5936e05ab1ed7eb5 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_apply_so_b7df3bf61bb95e3b);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_apply_so_5936e05ab1ed7eb5);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("apply.so", 3, decl_apply_so_b7df3bf61bb95e3b, apply_so_b7df3bf61bb95e3b)
+DECLARE_COMPILED_CODE ("apply.so", 3, decl_apply_so_5936e05ab1ed7eb5, apply_so_5936e05ab1ed7eb5)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_apply_so_data_b7df3bf61bb95e3b [655] =
+static const unsigned char prog_apply_so_data_5936e05ab1ed7eb5 [671] =
   "\x2c\x07\x9c\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x08\xc2\xc1"
   "\xb9\xc1\xba\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
@@ -1160,9 +1160,10 @@ static const unsigned char prog_apply_so_data_b7df3bf61bb95e3b [655] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x21\x17\x2b\xb8\x9a\xbd\x88\xb5\xb0\x2a\xb1\x2a\xb3\x2a\x9a"
   "\x0d\xb4\xb2\x9a\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02"
-  "\x42\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63"
+  "\x52\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
+  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
+  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
   "\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x61\x70\x70\x6c\x79\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
   "\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x1e\x61\x70\x70\x6c\x79\x3a\x20"
@@ -1193,19 +1194,19 @@ static const unsigned char prog_apply_so_data_b7df3bf61bb95e3b [655] =
   "\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-apply_so_data_b7df3bf61bb95e3b (entry_count_t dispatch_base)
+apply_so_data_5936e05ab1ed7eb5 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_apply_so_data_b7df3bf61bb95e3b [0]))), (sizeof (prog_apply_so_data_b7df3bf61bb95e3b)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_apply_so_data_5936e05ab1ed7eb5 [0]))), (sizeof (prog_apply_so_data_5936e05ab1ed7eb5)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("apply.so", apply_so_data_b7df3bf61bb95e3b)
+DECLARE_COMPILED_DATA_NS ("apply.so", apply_so_data_5936e05ab1ed7eb5)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("apply.so", "3f8f6b1872c46897")
+DECLARE_DYNAMIC_INITIALIZATION ("apply.so", "e571ffc7ff63dd61")
