@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:05-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:15-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -888,7 +888,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-apropos_so_73fae511b255f920 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+apropos_so_e9f50011a28458b3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -970,7 +970,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_apropos_so_73fae511b255f920 [5] =
+static const struct liarc_code_S arr_decl_apropos_so_e9f50011a28458b3 [5] =
   {
     { "apropos_so_code_1", 4, apropos_so_code_1 },
     { "apropos_so_code_2", 5, apropos_so_code_2 },
@@ -980,19 +980,19 @@ static const struct liarc_code_S arr_decl_apropos_so_73fae511b255f920 [5] =
   };
 
 int
-decl_apropos_so_73fae511b255f920 (void)
+decl_apropos_so_e9f50011a28458b3 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_apropos_so_73fae511b255f920);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_apropos_so_e9f50011a28458b3);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("apropos.so", 3, decl_apropos_so_73fae511b255f920, apropos_so_73fae511b255f920)
+DECLARE_COMPILED_CODE ("apropos.so", 3, decl_apropos_so_e9f50011a28458b3, apropos_so_e9f50011a28458b3)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_apropos_so_data_73fae511b255f920 [788] =
+static const unsigned char prog_apropos_so_data_e9f50011a28458b3 [804] =
   "\x3e\x0b\xc8\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x1d\x0d\xb9"
   "\x0d\xba\x24\x28\x0d\xbb\x28\x0d\xbc\x28\x0d\xbd\x23\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x21\x17\x2b\xbe\x1d\xb0\x82\x88\x1d\x08\x07"
@@ -1005,10 +1005,11 @@ static const unsigned char prog_apropos_so_data_73fae511b255f920 [788] =
   "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x85\x88\x28\x0d\x28\xb7\x28\x1b"
   "\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x9c\xbf\x88\xb7\x1b"
   "\x2a\x1b\x2a\xb3\x2a\xb4\x2a\xb6\x2a\x9c\xb1\xb2\xb5\x0d\x0d\x9c"
-  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x44\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
+  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x54\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
   "\x74\x69\x6d\x65\x2f\x61\x70\x72\x6f\x70\x6f\x73\x2e\x69\x6e\x66"
   "\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d"
   "\x72\x6f\x6f\x74\x5d\x02\x08\x15\x61\x70\x72\x6f\x70\x6f\x73\x2d"
@@ -1045,19 +1046,19 @@ static const unsigned char prog_apropos_so_data_73fae511b255f920 [788] =
   "\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-apropos_so_data_73fae511b255f920 (entry_count_t dispatch_base)
+apropos_so_data_e9f50011a28458b3 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_apropos_so_data_73fae511b255f920 [0]))), (sizeof (prog_apropos_so_data_73fae511b255f920)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_apropos_so_data_e9f50011a28458b3 [0]))), (sizeof (prog_apropos_so_data_e9f50011a28458b3)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("apropos.so", apropos_so_data_73fae511b255f920)
+DECLARE_COMPILED_DATA_NS ("apropos.so", apropos_so_data_e9f50011a28458b3)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("apropos.so", "10c1d947b895a9c3")
+DECLARE_DYNAMIC_INITIALIZATION ("apropos.so", "238330a0fd65e74a")
