@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:08-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:18-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -3016,7 +3016,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-bitstr_so_65c6f53f41f22b7b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+bitstr_so_f159704909b1a17f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3127,7 +3127,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_bitstr_so_65c6f53f41f22b7b [34] =
+static const struct liarc_code_S arr_decl_bitstr_so_f159704909b1a17f [34] =
   {
     { "bitstr_so_code_1", 1, bitstr_so_code_1 },
     { "bitstr_so_code_2", 1, bitstr_so_code_2 },
@@ -3166,19 +3166,19 @@ static const struct liarc_code_S arr_decl_bitstr_so_65c6f53f41f22b7b [34] =
   };
 
 int
-decl_bitstr_so_65c6f53f41f22b7b (void)
+decl_bitstr_so_f159704909b1a17f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_bitstr_so_65c6f53f41f22b7b);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_bitstr_so_f159704909b1a17f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("bitstr.so", 3, decl_bitstr_so_65c6f53f41f22b7b, bitstr_so_65c6f53f41f22b7b)
+DECLARE_COMPILED_CODE ("bitstr.so", 3, decl_bitstr_so_f159704909b1a17f, bitstr_so_f159704909b1a17f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_bitstr_so_data_65c6f53f41f22b7b [2526] =
+static const unsigned char prog_bitstr_so_data_f159704909b1a17f [2542] =
   "\x49\x27\x97\x05\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\x22\x29"
   "\x21\x9d\x2b\xba\x1d\xb0\x82\x88\xc2\xbb\x22\x29\x21\x9d\x2b\xbc"
   "\x1d\xb0\x83\x88\x07\x22\x29\x21\x9d\x2b\xbd\x1d\xb0\x84\x88\xc1"
@@ -3220,10 +3220,11 @@ static const unsigned char prog_bitstr_so_data_65c6f53f41f22b7b [2526] =
   "\x2a\x1b\x2a\xb7\x2a\xb5\x2a\xb4\x2a\xb2\x2a\x17\x0d\x0d\x0d\x0d"
   "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
   "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x28"
-  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65"
-  "\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
+  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65"
+  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
+  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
   "\x69\x6d\x65\x2f\x62\x69\x74\x73\x74\x72\x2e\x69\x6e\x66\x15\x23"
   "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
   "\x6f\x74\x5d\x02\x14\x62\x69\x74\x2d\x73\x74\x72\x69\x6e\x67\x2d"
@@ -3339,19 +3340,19 @@ static const unsigned char prog_bitstr_so_data_65c6f53f41f22b7b [2526] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-bitstr_so_data_65c6f53f41f22b7b (entry_count_t dispatch_base)
+bitstr_so_data_f159704909b1a17f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_bitstr_so_data_65c6f53f41f22b7b [0]))), (sizeof (prog_bitstr_so_data_65c6f53f41f22b7b)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_bitstr_so_data_f159704909b1a17f [0]))), (sizeof (prog_bitstr_so_data_f159704909b1a17f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("bitstr.so", bitstr_so_data_65c6f53f41f22b7b)
+DECLARE_COMPILED_DATA_NS ("bitstr.so", bitstr_so_data_f159704909b1a17f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("bitstr.so", "4a75e9588c93e32e")
+DECLARE_DYNAMIC_INITIALIZATION ("bitstr.so", "c2af9161040b19ad")
