@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:08-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:18-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1345,7 +1345,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-blowfish_so_c2f96c51d0d86a37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+blowfish_so_e8690f424b49e446 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1428,7 +1428,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_blowfish_so_c2f96c51d0d86a37 [6] =
+static const struct liarc_code_S arr_decl_blowfish_so_e8690f424b49e446 [6] =
   {
     { "blowfish_so_code_1", 3, blowfish_so_code_1 },
     { "blowfish_so_code_2", 12, blowfish_so_code_2 },
@@ -1439,19 +1439,19 @@ static const struct liarc_code_S arr_decl_blowfish_so_c2f96c51d0d86a37 [6] =
   };
 
 int
-decl_blowfish_so_c2f96c51d0d86a37 (void)
+decl_blowfish_so_e8690f424b49e446 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_blowfish_so_c2f96c51d0d86a37);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_blowfish_so_e8690f424b49e446);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("blowfish.so", 3, decl_blowfish_so_c2f96c51d0d86a37, blowfish_so_c2f96c51d0d86a37)
+DECLARE_COMPILED_CODE ("blowfish.so", 3, decl_blowfish_so_e8690f424b49e446, blowfish_so_e8690f424b49e446)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_blowfish_so_data_c2f96c51d0d86a37 [1565] =
+static const unsigned char prog_blowfish_so_data_e8690f424b49e446 [1581] =
   "\x35\x0f\xa9\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0d\xb9\x24"
   "\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xba\x1d"
   "\xb0\x82\x88\x0f\x80\x1d\xc1\xbb\x02\x28\x0d\xbc\x28\x0d\x28\x0d"
@@ -1470,10 +1470,11 @@ static const unsigned char prog_blowfish_so_data_c2f96c51d0d86a37 [1565] =
   "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x9d\x1c\x88\x1b\x0c"
   "\x0c\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a\xb5\x2a\xb2\x2a\x1f\x1f\xc5"
   "\xc4\xc1\x17\xb7\x1b\x0d\xb3\x0d\x1b\x0d\x0d\x0d\xb1\x0d\x0d\xb4"
-  "\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x45\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
+  "\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x55\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
+  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
   "\x6e\x74\x69\x6d\x65\x2f\x62\x6c\x6f\x77\x66\x69\x73\x68\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
   "\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x08\x70\x72\x62\x66\x69\x73\x68"
@@ -1552,19 +1553,19 @@ static const unsigned char prog_blowfish_so_data_c2f96c51d0d86a37 [1565] =
   "\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-blowfish_so_data_c2f96c51d0d86a37 (entry_count_t dispatch_base)
+blowfish_so_data_e8690f424b49e446 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_blowfish_so_data_c2f96c51d0d86a37 [0]))), (sizeof (prog_blowfish_so_data_c2f96c51d0d86a37)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_blowfish_so_data_e8690f424b49e446 [0]))), (sizeof (prog_blowfish_so_data_e8690f424b49e446)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("blowfish.so", blowfish_so_data_c2f96c51d0d86a37)
+DECLARE_COMPILED_DATA_NS ("blowfish.so", blowfish_so_data_e8690f424b49e446)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("blowfish.so", "5fa15ffddd270d0f")
+DECLARE_DYNAMIC_INITIALIZATION ("blowfish.so", "0d8033a669bc0585")
