@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:08-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:18-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -828,7 +828,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-boole_so_df7730f11726d94b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+boole_so_1e835d82a3216d5f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -912,7 +912,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_boole_so_df7730f11726d94b [7] =
+static const struct liarc_code_S arr_decl_boole_so_1e835d82a3216d5f [7] =
   {
     { "boole_so_code_1", 1, boole_so_code_1 },
     { "boole_so_code_2", 1, boole_so_code_2 },
@@ -924,19 +924,19 @@ static const struct liarc_code_S arr_decl_boole_so_df7730f11726d94b [7] =
   };
 
 int
-decl_boole_so_df7730f11726d94b (void)
+decl_boole_so_1e835d82a3216d5f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_boole_so_df7730f11726d94b);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_boole_so_1e835d82a3216d5f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("boole.so", 3, decl_boole_so_df7730f11726d94b, boole_so_df7730f11726d94b)
+DECLARE_COMPILED_CODE ("boole.so", 3, decl_boole_so_1e835d82a3216d5f, boole_so_1e835d82a3216d5f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_boole_so_data_df7730f11726d94b [556] =
+static const unsigned char prog_boole_so_data_1e835d82a3216d5f [572] =
   "\x21\x0c\xb3\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x22\x29\x21"
   "\x9d\x2b\xb9\x1d\xb0\x82\x88\x07\x22\x29\x21\x9d\x2b\xba\x1d\xb0"
   "\x83\x88\x07\x22\x29\x21\x9d\x2b\xbb\x1d\xb0\x84\x88\x07\xc1\xbc"
@@ -948,10 +948,11 @@ static const unsigned char prog_boole_so_data_df7730f11726d94b [556] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x9e\xbd\x88\xb5"
   "\x1b\x2a\x1b\x2a\xb7\x2a\xb6\x2a\xb3\x2a\xb2\x2a\x07\x06\xb1\x2a"
   "\x17\xb4\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x42\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x52\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x62\x6f\x6f\x6c\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
   "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04"
   "\x04\x83\x04\x03\x02\x05\x04\x83\x04\x03\x02\x06\x04\x84\x06\x03"
@@ -974,19 +975,19 @@ static const unsigned char prog_boole_so_data_df7730f11726d94b [556] =
   "\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-boole_so_data_df7730f11726d94b (entry_count_t dispatch_base)
+boole_so_data_1e835d82a3216d5f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_boole_so_data_df7730f11726d94b [0]))), (sizeof (prog_boole_so_data_df7730f11726d94b)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_boole_so_data_1e835d82a3216d5f [0]))), (sizeof (prog_boole_so_data_1e835d82a3216d5f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("boole.so", boole_so_data_df7730f11726d94b)
+DECLARE_COMPILED_DATA_NS ("boole.so", boole_so_data_1e835d82a3216d5f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("boole.so", "f92a2be286e12256")
+DECLARE_DYNAMIC_INITIALIZATION ("boole.so", "ceefbdf2619af5cb")
