@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:08-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:18-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2697,7 +2697,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-boot_so_c23699f976c20857 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+boot_so_a74df8434497ef8c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2795,7 +2795,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_boot_so_c23699f976c20857 [21] =
+static const struct liarc_code_S arr_decl_boot_so_a74df8434497ef8c [21] =
   {
     { "boot_so_code_1", 3, boot_so_code_1 },
     { "boot_so_code_2", 5, boot_so_code_2 },
@@ -2821,19 +2821,19 @@ static const struct liarc_code_S arr_decl_boot_so_c23699f976c20857 [21] =
   };
 
 int
-decl_boot_so_c23699f976c20857 (void)
+decl_boot_so_a74df8434497ef8c (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_boot_so_c23699f976c20857);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_boot_so_a74df8434497ef8c);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("boot.so", 3, decl_boot_so_c23699f976c20857, boot_so_c23699f976c20857)
+DECLARE_COMPILED_CODE ("boot.so", 3, decl_boot_so_a74df8434497ef8c, boot_so_a74df8434497ef8c)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_boot_so_data_c23699f976c20857 [2498] =
+static const unsigned char prog_boot_so_data_a74df8434497ef8c [2514] =
   "\x44\x1e\xce\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28"
   "\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82"
   "\x88\x0f\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\xbe\x28\x0d\xbf\x23\x22"
@@ -2871,9 +2871,10 @@ static const unsigned char prog_boot_so_data_c23699f976c20857 [2498] =
   "\x17\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x0d\x0d"
   "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x0d\xb2"
   "\xb1\x0d\x0d\x0d\xb4\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21"
-  "\x17\x02\x41\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d"
-  "\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69"
-  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73"
+  "\x17\x02\x51\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f"
+  "\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65"
+  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d"
+  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73"
   "\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x62\x6f\x6f\x74\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x0c\x6d\x61\x6b\x65\x2d"
@@ -2993,19 +2994,19 @@ static const unsigned char prog_boot_so_data_c23699f976c20857 [2498] =
   "\x07\x11";
 
 SCHEME_OBJECT *
-boot_so_data_c23699f976c20857 (entry_count_t dispatch_base)
+boot_so_data_a74df8434497ef8c (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_boot_so_data_c23699f976c20857 [0]))), (sizeof (prog_boot_so_data_c23699f976c20857)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_boot_so_data_a74df8434497ef8c [0]))), (sizeof (prog_boot_so_data_a74df8434497ef8c)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("boot.so", boot_so_data_c23699f976c20857)
+DECLARE_COMPILED_DATA_NS ("boot.so", boot_so_data_a74df8434497ef8c)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("boot.so", "27bc1056cce51267")
+DECLARE_DYNAMIC_INITIALIZATION ("boot.so", "bcd1958c7223ec6c")
