@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:09-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:19-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2927,7 +2927,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-chrsyn_so_27488bbb5015e382 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+chrsyn_so_fc0ad339c36d6a94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3209,7 +3209,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_chrsyn_so_27488bbb5015e382 [14] =
+static const struct liarc_code_S arr_decl_chrsyn_so_fc0ad339c36d6a94 [14] =
   {
     { "chrsyn_so_code_1", 1, chrsyn_so_code_1 },
     { "chrsyn_so_code_2", 1, chrsyn_so_code_2 },
@@ -3228,19 +3228,19 @@ static const struct liarc_code_S arr_decl_chrsyn_so_27488bbb5015e382 [14] =
   };
 
 int
-decl_chrsyn_so_27488bbb5015e382 (void)
+decl_chrsyn_so_fc0ad339c36d6a94 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_chrsyn_so_27488bbb5015e382);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_chrsyn_so_fc0ad339c36d6a94);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("chrsyn.so", 13, decl_chrsyn_so_27488bbb5015e382, chrsyn_so_27488bbb5015e382)
+DECLARE_COMPILED_CODE ("chrsyn.so", 13, decl_chrsyn_so_fc0ad339c36d6a94, chrsyn_so_fc0ad339c36d6a94)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_chrsyn_so_data_27488bbb5015e382 [2506] =
+static const unsigned char prog_chrsyn_so_data_fc0ad339c36d6a94 [2522] =
   "\x9b\x01\x1f\x90\x05\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21"
   "\x9c\x2b\xb9\x1d\xb0\x82\x88\xc2\xba\x81\x22\x29\x21\x9e\x2b\xbb"
   "\x1d\xb0\x83\x88\x07\xb2\x80\x0e\xbc\x24\x22\x29\x22\x29\x21\x17"
@@ -3282,9 +3282,10 @@ static const unsigned char prog_chrsyn_so_data_27488bbb5015e382 [2506] =
   "\x17\x1b\x0d\xb3\x2a\xc3\x0d\x1c\x0c\x0d\x08\x88\x08\xb1\x2a\x28"
   "\x0d\x28\x0d\x28\x0d\x26\x1b\x24\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
-  "\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
-  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
+  "\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65"
+  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d"
+  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e"
   "\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x63\x68"
   "\x72\x73\x79\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0e\x04"
@@ -3400,19 +3401,19 @@ static const unsigned char prog_chrsyn_so_data_27488bbb5015e382 [2506] =
   "\x81\x87\x02\x01\x04\x81\x83\x02\x1b\x35";
 
 SCHEME_OBJECT *
-chrsyn_so_data_27488bbb5015e382 (entry_count_t dispatch_base)
+chrsyn_so_data_fc0ad339c36d6a94 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_chrsyn_so_data_27488bbb5015e382 [0]))), (sizeof (prog_chrsyn_so_data_27488bbb5015e382)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_chrsyn_so_data_fc0ad339c36d6a94 [0]))), (sizeof (prog_chrsyn_so_data_fc0ad339c36d6a94)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_20]));
 }
 
-DECLARE_COMPILED_DATA_NS ("chrsyn.so", chrsyn_so_data_27488bbb5015e382)
+DECLARE_COMPILED_DATA_NS ("chrsyn.so", chrsyn_so_data_fc0ad339c36d6a94)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("chrsyn.so", "4154461bca5e30dd")
+DECLARE_DYNAMIC_INITIALIZATION ("chrsyn.so", "d1c4920f71af015a")
