@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:10-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:20-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1638,7 +1638,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-contin_so_4ef5ed74b5b93a08 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+contin_so_29761b29908368ea (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1957,7 +1957,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_contin_so_4ef5ed74b5b93a08 [17] =
+static const struct liarc_code_S arr_decl_contin_so_29761b29908368ea [17] =
   {
     { "contin_so_code_1", 6, contin_so_code_1 },
     { "contin_so_code_2", 2, contin_so_code_2 },
@@ -1979,19 +1979,19 @@ static const struct liarc_code_S arr_decl_contin_so_4ef5ed74b5b93a08 [17] =
   };
 
 int
-decl_contin_so_4ef5ed74b5b93a08 (void)
+decl_contin_so_29761b29908368ea (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_contin_so_4ef5ed74b5b93a08);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_contin_so_29761b29908368ea);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("contin.so", 14, decl_contin_so_4ef5ed74b5b93a08, contin_so_4ef5ed74b5b93a08)
+DECLARE_COMPILED_CODE ("contin.so", 14, decl_contin_so_29761b29908368ea, contin_so_29761b29908368ea)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_contin_so_data_4ef5ed74b5b93a08 [1732] =
+static const unsigned char prog_contin_so_data_29761b29908368ea [1748] =
   "\x3b\x1c\xb0\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\x28\x0d\x28"
   "\x0d\xb9\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\x0d\xbc\x28\x0d"
@@ -2019,9 +2019,10 @@ static const unsigned char prog_contin_so_data_4ef5ed74b5b93a08 [1732] =
   "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a\xb3\x2a\x17\x28\x0d\x28\x0d"
   "\x28\x0d\x26\x1b\x24\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
-  "\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f"
-  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
+  "\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
+  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
+  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
   "\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x63\x6f\x6e"
   "\x74\x69\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
   "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x1f\x63\x61"
@@ -2103,19 +2104,19 @@ static const unsigned char prog_contin_so_data_4ef5ed74b5b93a08 [1732] =
   "\x83\x02\x1d\x3b";
 
 SCHEME_OBJECT *
-contin_so_data_4ef5ed74b5b93a08 (entry_count_t dispatch_base)
+contin_so_data_29761b29908368ea (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_contin_so_data_4ef5ed74b5b93a08 [0]))), (sizeof (prog_contin_so_data_4ef5ed74b5b93a08)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_contin_so_data_29761b29908368ea [0]))), (sizeof (prog_contin_so_data_29761b29908368ea)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_21]));
 }
 
-DECLARE_COMPILED_DATA_NS ("contin.so", contin_so_data_4ef5ed74b5b93a08)
+DECLARE_COMPILED_DATA_NS ("contin.so", contin_so_data_29761b29908368ea)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("contin.so", "ba4156110c0719a0")
+DECLARE_DYNAMIC_INITIALIZATION ("contin.so", "37f0dbbd9c2c9858")
