@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:10-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:20-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1847,7 +1847,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-cpoint_so_b9cdf38491cca227 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+cpoint_so_c06366d5080b11ca (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1936,7 +1936,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_cpoint_so_b9cdf38491cca227 [12] =
+static const struct liarc_code_S arr_decl_cpoint_so_c06366d5080b11ca [12] =
   {
     { "cpoint_so_code_1", 1, cpoint_so_code_1 },
     { "cpoint_so_code_2", 1, cpoint_so_code_2 },
@@ -1953,19 +1953,19 @@ static const struct liarc_code_S arr_decl_cpoint_so_b9cdf38491cca227 [12] =
   };
 
 int
-decl_cpoint_so_b9cdf38491cca227 (void)
+decl_cpoint_so_c06366d5080b11ca (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_cpoint_so_b9cdf38491cca227);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_cpoint_so_c06366d5080b11ca);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("cpoint.so", 3, decl_cpoint_so_b9cdf38491cca227, cpoint_so_b9cdf38491cca227)
+DECLARE_COMPILED_CODE ("cpoint.so", 3, decl_cpoint_so_c06366d5080b11ca, cpoint_so_c06366d5080b11ca)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_cpoint_so_data_b9cdf38491cca227 [1344] =
+static const unsigned char prog_cpoint_so_data_c06366d5080b11ca [1360] =
   "\x4c\x10\xb6\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\x07\x02\x22"
   "\x29\x21\x9f\x2b\xb9\x1d\xb0\x82\x88\xc2\xba\x83\x22\x29\x21\x9e"
   "\x2b\xbb\x1d\xb0\x83\x88\xb2\x85\x22\x29\x21\x9e\x2b\xbc\x1d\xb0"
@@ -1985,10 +1985,11 @@ static const unsigned char prog_cpoint_so_data_b9cdf38491cca227 [1344] =
   "\x2b\x1c\x17\xba\x88\xb2\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
   "\x02\x1b\x2a\xb7\x2a\xb6\x2a\xb5\x2a\xb4\x2a\xb3\x2a\xb1\x2a\x17"
   "\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x28\x0d"
-  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72"
-  "\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73"
-  "\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69"
+  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72"
+  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73"
+  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69"
   "\x6d\x65\x2f\x63\x70\x6f\x69\x6e\x74\x2e\x69\x6e\x66\x15\x23\x5b"
   "\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f"
   "\x74\x5d\x02\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f"
@@ -2052,19 +2053,19 @@ static const unsigned char prog_cpoint_so_data_b9cdf38491cca227 [1344] =
   "\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-cpoint_so_data_b9cdf38491cca227 (entry_count_t dispatch_base)
+cpoint_so_data_c06366d5080b11ca (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_cpoint_so_data_b9cdf38491cca227 [0]))), (sizeof (prog_cpoint_so_data_b9cdf38491cca227)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_cpoint_so_data_c06366d5080b11ca [0]))), (sizeof (prog_cpoint_so_data_c06366d5080b11ca)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("cpoint.so", cpoint_so_data_b9cdf38491cca227)
+DECLARE_COMPILED_DATA_NS ("cpoint.so", cpoint_so_data_c06366d5080b11ca)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("cpoint.so", "312e793a3b0cb780")
+DECLARE_DYNAMIC_INITIALIZATION ("cpoint.so", "54b9912899585742")
