@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:12-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:22-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2612,7 +2612,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-dbgcmd_so_e98e82eec209f179 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+dbgcmd_so_37b3977d16cdba19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2702,7 +2702,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_dbgcmd_so_e98e82eec209f179 [13] =
+static const struct liarc_code_S arr_decl_dbgcmd_so_37b3977d16cdba19 [13] =
   {
     { "dbgcmd_so_code_1", 13, dbgcmd_so_code_1 },
     { "dbgcmd_so_code_2", 11, dbgcmd_so_code_2 },
@@ -2720,19 +2720,19 @@ static const struct liarc_code_S arr_decl_dbgcmd_so_e98e82eec209f179 [13] =
   };
 
 int
-decl_dbgcmd_so_e98e82eec209f179 (void)
+decl_dbgcmd_so_37b3977d16cdba19 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_dbgcmd_so_e98e82eec209f179);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_dbgcmd_so_37b3977d16cdba19);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("dbgcmd.so", 3, decl_dbgcmd_so_e98e82eec209f179, dbgcmd_so_e98e82eec209f179)
+DECLARE_COMPILED_CODE ("dbgcmd.so", 3, decl_dbgcmd_so_37b3977d16cdba19, dbgcmd_so_37b3977d16cdba19)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_dbgcmd_so_data_e98e82eec209f179 [2065] =
+static const unsigned char prog_dbgcmd_so_data_37b3977d16cdba19 [2081] =
   "\x64\x15\xe8\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\xc1\xba"
   "\x08\x0d\xbb\x24\x28\x0d\xbc\x28\xb3\x28\x0d\xbd\x23\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
@@ -2763,10 +2763,11 @@ static const unsigned char prog_dbgcmd_so_data_e98e82eec209f179 [2065] =
   "\xb8\x17\x1c\x88\x1b\xb0\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e"
   "\x1b\x2a\x1b\x2a\xb2\x2a\xb7\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a"
   "\x17\x0d\x0d\x0d\x0d\x1b\xb1\xb4\x0d\x0d\xb3\x1b\x0d\xb5\x0d\x17"
-  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
+  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
   "\x74\x69\x6d\x65\x2f\x64\x62\x67\x63\x6d\x64\x2e\x69\x6e\x66\x15"
   "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
   "\x6f\x6f\x74\x5d\x02\x04\x63\x64\x72\x04\x63\x61\x72\x16\x73\x74"
@@ -2865,19 +2866,19 @@ static const unsigned char prog_dbgcmd_so_data_e98e82eec209f179 [2065] =
   "\x11";
 
 SCHEME_OBJECT *
-dbgcmd_so_data_e98e82eec209f179 (entry_count_t dispatch_base)
+dbgcmd_so_data_37b3977d16cdba19 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_dbgcmd_so_data_e98e82eec209f179 [0]))), (sizeof (prog_dbgcmd_so_data_e98e82eec209f179)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_dbgcmd_so_data_37b3977d16cdba19 [0]))), (sizeof (prog_dbgcmd_so_data_37b3977d16cdba19)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("dbgcmd.so", dbgcmd_so_data_e98e82eec209f179)
+DECLARE_COMPILED_DATA_NS ("dbgcmd.so", dbgcmd_so_data_37b3977d16cdba19)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("dbgcmd.so", "108e45597b29aad6")
+DECLARE_DYNAMIC_INITIALIZATION ("dbgcmd.so", "c9cc3a5355498b2a")
