@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:12-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:22-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2969,7 +2969,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-dbgutl_so_9a2a0b4d5c041357 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+dbgutl_so_44f32d33c199782d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3061,7 +3061,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_dbgutl_so_9a2a0b4d5c041357 [15] =
+static const struct liarc_code_S arr_decl_dbgutl_so_44f32d33c199782d [15] =
   {
     { "dbgutl_so_code_1", 7, dbgutl_so_code_1 },
     { "dbgutl_so_code_2", 3, dbgutl_so_code_2 },
@@ -3081,19 +3081,19 @@ static const struct liarc_code_S arr_decl_dbgutl_so_9a2a0b4d5c041357 [15] =
   };
 
 int
-decl_dbgutl_so_9a2a0b4d5c041357 (void)
+decl_dbgutl_so_44f32d33c199782d (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_dbgutl_so_9a2a0b4d5c041357);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_dbgutl_so_44f32d33c199782d);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("dbgutl.so", 3, decl_dbgutl_so_9a2a0b4d5c041357, dbgutl_so_9a2a0b4d5c041357)
+DECLARE_COMPILED_CODE ("dbgutl.so", 3, decl_dbgutl_so_44f32d33c199782d, dbgutl_so_44f32d33c199782d)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_dbgutl_so_data_9a2a0b4d5c041357 [2990] =
+static const unsigned char prog_dbgutl_so_data_44f32d33c199782d [3006] =
   "\x5f\x1e\x96\x05\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0c\x0c\x0c"
   "\x28\x0d\x28\x0d\xb9\x28\x0d\x28\x0d\xba\x28\x0d\xbb\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc"
@@ -3135,10 +3135,11 @@ static const unsigned char prog_dbgutl_so_data_9a2a0b4d5c041357 [2990] =
   "\x2a\x1b\x2a\xb1\x2a\x1b\x2a\x02\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
   "\x1b\x2a\xb2\x2a\x1b\x2a\x1b\x2a\xb7\x2a\xb4\x2a\x17\xb6\x1b\x1b"
   "\xb5\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x0d\xb3\x1b\x0d\x1b\x17\x28\x0d"
-  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72"
-  "\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73"
-  "\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69"
+  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72"
+  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73"
+  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69"
   "\x6d\x65\x2f\x64\x62\x67\x75\x74\x6c\x2e\x69\x6e\x66\x15\x23\x5b"
   "\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f"
   "\x74\x5d\x02\x0e\x20\x73\x70\x65\x63\x69\x61\x6c\x20\x66\x6f\x72"
@@ -3283,19 +3284,19 @@ static const unsigned char prog_dbgutl_so_data_9a2a0b4d5c041357 [2990] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-dbgutl_so_data_9a2a0b4d5c041357 (entry_count_t dispatch_base)
+dbgutl_so_data_44f32d33c199782d (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_dbgutl_so_data_9a2a0b4d5c041357 [0]))), (sizeof (prog_dbgutl_so_data_9a2a0b4d5c041357)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_dbgutl_so_data_44f32d33c199782d [0]))), (sizeof (prog_dbgutl_so_data_44f32d33c199782d)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("dbgutl.so", dbgutl_so_data_9a2a0b4d5c041357)
+DECLARE_COMPILED_DATA_NS ("dbgutl.so", dbgutl_so_data_44f32d33c199782d)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("dbgutl.so", "b6fce003bbc4e7e6")
+DECLARE_DYNAMIC_INITIALIZATION ("dbgutl.so", "931049f1a14c059c")
