@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:15-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:25-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -15,7 +15,7 @@
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-ed_ffi_so_4ed824ccabd38534 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+ed_ffi_so_c07047e8100cc04f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -58,18 +58,18 @@ INVOKE_INTERFACE_TARGET_4
 }
 
 int
-decl_ed_ffi_so_4ed824ccabd38534 (void)
+decl_ed_ffi_so_c07047e8100cc04f (void)
 {
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("ed-ffi.so", 2, decl_ed_ffi_so_4ed824ccabd38534, ed_ffi_so_4ed824ccabd38534)
+DECLARE_COMPILED_CODE ("ed-ffi.so", 2, decl_ed_ffi_so_c07047e8100cc04f, ed_ffi_so_c07047e8100cc04f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_ed_ffi_so_data_4ed824ccabd38534 [4453] =
+static const unsigned char prog_ed_ffi_so_data_c07047e8100cc04f [4469] =
   "\xac\x01\x07\xb1\x09\x1d\x0c\x0c\x0d\xb8\x0d\x08\x89\x08\x89\x0c"
   "\xb0\x0d\x08\x89\x08\x89\x0c\xb0\x0d\x08\x89\x08\x89\x0c\xb0\x0d"
   "\x08\x89\x08\x89\x0c\xb0\x0d\x08\x89\x08\x89\x0c\xb0\x0d\x08\x89"
@@ -145,9 +145,10 @@ static const unsigned char prog_ed_ffi_so_data_4ed824ccabd38534 [4453] =
   "\x89\x0c\xb0\x0d\x08\x89\x08\x89\x0c\xb0\x0d\x08\x89\x08\x89\x0c"
   "\xb0\xb4\x08\x89\x08\x89\x0c\xb0\x0d\x08\x89\x08\x89\x0c\xb0\x0d"
   "\x08\x89\x08\x89\x0c\xb0\x0d\x08\x89\x08\x89\x17\x28\x0d\x23\x22"
-  "\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
-  "\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
-  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
+  "\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d"
+  "\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f"
+  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
   "\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x65"
   "\x64\x2d\x66\x66\x69\x2e\x69\x6e\x66\x06\x79\x73\x74\x65\x70\x08"
   "\x72\x75\x6e\x74\x69\x6d\x65\x08\x73\x74\x65\x70\x70\x65\x72\x06"
@@ -351,19 +352,19 @@ static const unsigned char prog_ed_ffi_so_data_4ed824ccabd38534 [4453] =
   "\x81\x81\x02\x05\x0c";
 
 SCHEME_OBJECT *
-ed_ffi_so_data_4ed824ccabd38534 (entry_count_t dispatch_base)
+ed_ffi_so_data_c07047e8100cc04f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_ed_ffi_so_data_4ed824ccabd38534 [0]))), (sizeof (prog_ed_ffi_so_data_4ed824ccabd38534)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_ed_ffi_so_data_c07047e8100cc04f [0]))), (sizeof (prog_ed_ffi_so_data_c07047e8100cc04f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_6]));
 }
 
-DECLARE_COMPILED_DATA_NS ("ed-ffi.so", ed_ffi_so_data_4ed824ccabd38534)
+DECLARE_COMPILED_DATA_NS ("ed-ffi.so", ed_ffi_so_data_c07047e8100cc04f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("ed-ffi.so", "37dc2755c530b4a0")
+DECLARE_DYNAMIC_INITIALIZATION ("ed-ffi.so", "a145f66b6ba622fd")
