@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:15-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:25-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2281,7 +2281,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-equals_so_70e7bc69b443f756 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+equals_so_a9fb60843c56f5e9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2360,26 +2360,26 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_equals_so_70e7bc69b443f756 [2] =
+static const struct liarc_code_S arr_decl_equals_so_a9fb60843c56f5e9 [2] =
   {
     { "equals_so_code_1", 26, equals_so_code_1 },
     { "equals_so_code_2", 41, equals_so_code_2 }
   };
 
 int
-decl_equals_so_70e7bc69b443f756 (void)
+decl_equals_so_a9fb60843c56f5e9 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_equals_so_70e7bc69b443f756);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_equals_so_a9fb60843c56f5e9);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("equals.so", 3, decl_equals_so_70e7bc69b443f756, equals_so_70e7bc69b443f756)
+DECLARE_COMPILED_CODE ("equals.so", 3, decl_equals_so_a9fb60843c56f5e9, equals_so_a9fb60843c56f5e9)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_equals_so_data_70e7bc69b443f756 [879] =
+static const unsigned char prog_equals_so_data_a9fb60843c56f5e9 [895] =
   "\x7b\x07\xe7\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\x02\x06"
   "\x07\x02\x86\x02\x02\x02\xc2\xba\x28\x0d\xbb\x28\x0d\xbc\x23\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
@@ -2394,10 +2394,11 @@ static const unsigned char prog_equals_so_data_70e7bc69b443f756 [879] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
   "\x17\x2b\xbc\x99\xbb\x88\xb3\xb4\x2a\xb5\x2a\x99\xb2\x0d\x99\x28"
-  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65"
-  "\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
+  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65"
+  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
+  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
   "\x69\x6d\x65\x2f\x65\x71\x75\x61\x6c\x73\x2e\x69\x6e\x66\x15\x23"
   "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
   "\x6f\x74\x5d\x02\x0e\x76\x65\x63\x74\x6f\x72\x2d\x6c\x65\x6e\x67"
@@ -2437,19 +2438,19 @@ static const unsigned char prog_equals_so_data_70e7bc69b443f756 [879] =
   "\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-equals_so_data_70e7bc69b443f756 (entry_count_t dispatch_base)
+equals_so_data_a9fb60843c56f5e9 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_equals_so_data_70e7bc69b443f756 [0]))), (sizeof (prog_equals_so_data_70e7bc69b443f756)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_equals_so_data_a9fb60843c56f5e9 [0]))), (sizeof (prog_equals_so_data_a9fb60843c56f5e9)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("equals.so", equals_so_data_70e7bc69b443f756)
+DECLARE_COMPILED_DATA_NS ("equals.so", equals_so_data_a9fb60843c56f5e9)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("equals.so", "a9b83e675bfb6251")
+DECLARE_DYNAMIC_INITIALIZATION ("equals.so", "1cbe3fb9a1eac83b")
