@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:16-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:26-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1992,7 +1992,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-events_so_c5fcc9931f21ccbd (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+events_so_d6e02d8d73c0d4c9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2371,7 +2371,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_events_so_c5fcc9931f21ccbd [14] =
+static const struct liarc_code_S arr_decl_events_so_d6e02d8d73c0d4c9 [14] =
   {
     { "events_so_code_1", 5, events_so_code_1 },
     { "events_so_code_2", 1, events_so_code_2 },
@@ -2390,19 +2390,19 @@ static const struct liarc_code_S arr_decl_events_so_c5fcc9931f21ccbd [14] =
   };
 
 int
-decl_events_so_c5fcc9931f21ccbd (void)
+decl_events_so_d6e02d8d73c0d4c9 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_events_so_c5fcc9931f21ccbd);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_events_so_d6e02d8d73c0d4c9);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("events.so", 18, decl_events_so_c5fcc9931f21ccbd, events_so_c5fcc9931f21ccbd)
+DECLARE_COMPILED_CODE ("events.so", 18, decl_events_so_d6e02d8d73c0d4c9, events_so_d6e02d8d73c0d4c9)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_events_so_data_c5fcc9931f21ccbd [1673] =
+static const unsigned char prog_events_so_data_d6e02d8d73c0d4c9 [1689] =
   "\x5c\x1b\xa3\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\x0d\xb9\x0d"
   "\xba\x0d\xbb\x0d\xbc\x25\x28\x0d\xbd\x23\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x21\x17\x2b\xbe\x1d\xb0\x82\x88\x28\x0d\x23\x22"
@@ -2429,10 +2429,11 @@ static const unsigned char prog_events_so_data_c5fcc9931f21ccbd [1673] =
   "\x2a\xc3\x0d\xb6\x2a\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x26\x1b\x24"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x65\x76\x65\x6e\x74\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
   "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
   "\x02\x10\x72\x65\x6d\x6f\x76\x65\x2d\x72\x65\x63\x65\x69\x76\x65"
@@ -2510,19 +2511,19 @@ static const unsigned char prog_events_so_data_c5fcc9931f21ccbd [1673] =
   "\x83\x02\x01\x04\x81\x83\x02\x25\x47";
 
 SCHEME_OBJECT *
-events_so_data_c5fcc9931f21ccbd (entry_count_t dispatch_base)
+events_so_data_d6e02d8d73c0d4c9 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_events_so_data_c5fcc9931f21ccbd [0]))), (sizeof (prog_events_so_data_c5fcc9931f21ccbd)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_events_so_data_d6e02d8d73c0d4c9 [0]))), (sizeof (prog_events_so_data_d6e02d8d73c0d4c9)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_26]));
 }
 
-DECLARE_COMPILED_DATA_NS ("events.so", events_so_data_c5fcc9931f21ccbd)
+DECLARE_COMPILED_DATA_NS ("events.so", events_so_data_d6e02d8d73c0d4c9)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("events.so", "5084d12f3fbb6556")
+DECLARE_DYNAMIC_INITIALIZATION ("events.so", "200491c76e32a38b")
