@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:18-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:27-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1150,7 +1150,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-gcdemn_so_0557b7647b3f574a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+gcdemn_so_ee7f5f3cc3ded241 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1232,7 +1232,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_gcdemn_so_0557b7647b3f574a [5] =
+static const struct liarc_code_S arr_decl_gcdemn_so_ee7f5f3cc3ded241 [5] =
   {
     { "gcdemn_so_code_1", 28, gcdemn_so_code_1 },
     { "gcdemn_so_code_2", 3, gcdemn_so_code_2 },
@@ -1242,19 +1242,19 @@ static const struct liarc_code_S arr_decl_gcdemn_so_0557b7647b3f574a [5] =
   };
 
 int
-decl_gcdemn_so_0557b7647b3f574a (void)
+decl_gcdemn_so_ee7f5f3cc3ded241 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_gcdemn_so_0557b7647b3f574a);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_gcdemn_so_ee7f5f3cc3ded241);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("gcdemn.so", 3, decl_gcdemn_so_0557b7647b3f574a, gcdemn_so_0557b7647b3f574a)
+DECLARE_COMPILED_CODE ("gcdemn.so", 3, decl_gcdemn_so_ee7f5f3cc3ded241, gcdemn_so_ee7f5f3cc3ded241)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_gcdemn_so_data_0557b7647b3f574a [1120] =
+static const unsigned char prog_gcdemn_so_data_ee7f5f3cc3ded241 [1136] =
   "\x59\x12\xf8\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xc3\x02\xc0"
   "\x0d\xb9\x0d\xba\x0d\xbb\x0d\xbc\x0d\xbd\x0d\xbe\x0d\xbf\x0d\x1c"
   "\x0d\x1c\x25\xb1\xb4\xb7\xb2\x24\x28\x0d\x28\x0d\x1c\x28\x0d\x1c"
@@ -1270,10 +1270,11 @@ static const unsigned char prog_gcdemn_so_data_0557b7647b3f574a [1120] =
   "\x29\x22\x29\x22\x29\x21\x17\x2b\xb8\x9c\x1c\x88\x1b\xb0\x2a\x1b"
   "\x2a\x1b\x2a\x1e\x1e\x1e\x1b\x2a\x1e\x1e\x1e\x1e\x1e\x1e\x1b\x2a"
   "\x17\x0d\x1b\x1b\x1b\x1b\xb7\x0d\xb6\xb5\xb4\xb3\xb2\xb1\x0d\x17"
-  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
+  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
   "\x74\x69\x6d\x65\x2f\x67\x63\x64\x65\x6d\x6e\x2e\x69\x6e\x66\x15"
   "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
   "\x6f\x6f\x74\x5d\x02\x1a\x73\x65\x74\x2d\x66\x69\x78\x65\x64\x2d"
@@ -1327,19 +1328,19 @@ static const unsigned char prog_gcdemn_so_data_0557b7647b3f574a [1120] =
   "\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-gcdemn_so_data_0557b7647b3f574a (entry_count_t dispatch_base)
+gcdemn_so_data_ee7f5f3cc3ded241 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_gcdemn_so_data_0557b7647b3f574a [0]))), (sizeof (prog_gcdemn_so_data_0557b7647b3f574a)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_gcdemn_so_data_ee7f5f3cc3ded241 [0]))), (sizeof (prog_gcdemn_so_data_ee7f5f3cc3ded241)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("gcdemn.so", gcdemn_so_data_0557b7647b3f574a)
+DECLARE_COMPILED_DATA_NS ("gcdemn.so", gcdemn_so_data_ee7f5f3cc3ded241)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("gcdemn.so", "4c731dee474fd852")
+DECLARE_DYNAMIC_INITIALIZATION ("gcdemn.so", "d88f643abcd65f4a")
