@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:18-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:28-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2385,7 +2385,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-gcnote_so_ff53f44f7bf9854d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+gcnote_so_cbd8d9524cba59dd (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2469,7 +2469,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_gcnote_so_ff53f44f7bf9854d [7] =
+static const struct liarc_code_S arr_decl_gcnote_so_cbd8d9524cba59dd [7] =
   {
     { "gcnote_so_code_1", 8, gcnote_so_code_1 },
     { "gcnote_so_code_2", 8, gcnote_so_code_2 },
@@ -2481,19 +2481,19 @@ static const struct liarc_code_S arr_decl_gcnote_so_ff53f44f7bf9854d [7] =
   };
 
 int
-decl_gcnote_so_ff53f44f7bf9854d (void)
+decl_gcnote_so_cbd8d9524cba59dd (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_gcnote_so_ff53f44f7bf9854d);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_gcnote_so_cbd8d9524cba59dd);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("gcnote.so", 3, decl_gcnote_so_ff53f44f7bf9854d, gcnote_so_ff53f44f7bf9854d)
+DECLARE_COMPILED_CODE ("gcnote.so", 3, decl_gcnote_so_cbd8d9524cba59dd, gcnote_so_cbd8d9524cba59dd)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_gcnote_so_data_ff53f44f7bf9854d [1970] =
+static const unsigned char prog_gcnote_so_data_cbd8d9524cba59dd [1986] =
   "\x7e\x10\xbc\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x1d\x0d\xb9"
   "\x25\xb1\x0d\xba\x0d\xbb\x24\x28\x0d\xbc\x23\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbd\x1d"
@@ -2522,9 +2522,10 @@ static const unsigned char prog_gcnote_so_data_ff53f44f7bf9854d [1970] =
   "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x9e\x1c\x88\x1b\x1b\x2a\x1b"
   "\x2a\x1b\x2a\xb6\x2a\xb3\x2a\xb4\x2a\xb5\x2a\x9e\x1b\xb1\x0d\xb2"
   "\x0d\x0d\x0d\x9e\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02"
-  "\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63"
+  "\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
+  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
+  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
   "\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x67\x63\x6e\x6f\x74\x65\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x1e\x43\x61\x6e\x27\x74\x20"
@@ -2620,19 +2621,19 @@ static const unsigned char prog_gcnote_so_data_ff53f44f7bf9854d [1970] =
   "\x07\x11";
 
 SCHEME_OBJECT *
-gcnote_so_data_ff53f44f7bf9854d (entry_count_t dispatch_base)
+gcnote_so_data_cbd8d9524cba59dd (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_gcnote_so_data_ff53f44f7bf9854d [0]))), (sizeof (prog_gcnote_so_data_ff53f44f7bf9854d)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_gcnote_so_data_cbd8d9524cba59dd [0]))), (sizeof (prog_gcnote_so_data_cbd8d9524cba59dd)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("gcnote.so", gcnote_so_data_ff53f44f7bf9854d)
+DECLARE_COMPILED_DATA_NS ("gcnote.so", gcnote_so_data_cbd8d9524cba59dd)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("gcnote.so", "81adf56c520bc1ac")
+DECLARE_DYNAMIC_INITIALIZATION ("gcnote.so", "75ca99e557136c2a")
