@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:18-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:28-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2130,7 +2130,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-gdbm_so_dea6ff440b1edc52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+gdbm_so_14ce8435a2573f1a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2453,7 +2453,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_gdbm_so_dea6ff440b1edc52 [22] =
+static const struct liarc_code_S arr_decl_gdbm_so_14ce8435a2573f1a [22] =
   {
     { "gdbm_so_code_1", 10, gdbm_so_code_1 },
     { "gdbm_so_code_2", 10, gdbm_so_code_2 },
@@ -2480,19 +2480,19 @@ static const struct liarc_code_S arr_decl_gdbm_so_dea6ff440b1edc52 [22] =
   };
 
 int
-decl_gdbm_so_dea6ff440b1edc52 (void)
+decl_gdbm_so_14ce8435a2573f1a (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_gdbm_so_dea6ff440b1edc52);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_gdbm_so_14ce8435a2573f1a);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("gdbm.so", 15, decl_gdbm_so_dea6ff440b1edc52, gdbm_so_dea6ff440b1edc52)
+DECLARE_COMPILED_CODE ("gdbm.so", 15, decl_gdbm_so_14ce8435a2573f1a, gdbm_so_14ce8435a2573f1a)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_gdbm_so_data_dea6ff440b1edc52 [2389] =
+static const unsigned char prog_gdbm_so_data_14ce8435a2573f1a [2405] =
   "\x41\x2d\xeb\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\x07\xc4\xb9"
   "\x0c\x0d\xba\x0d\xbb\x25\xb3\x0d\xbc\x0d\xbd\x0d\xbe\x24\x28\x0d"
   "\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
@@ -2531,10 +2531,11 @@ static const unsigned char prog_gdbm_so_data_dea6ff440b1edc52 [2389] =
   "\x1b\x2a\x81\x80\x1b\x2a\x1b\x2a\x02\x83\x82\x81\x80\xb7\x2a\x1e"
   "\x06\x17\x28\x0d\x28\x0d\x28\x0d\x26\x1b\x24\x28\x0d\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x41"
-  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72"
-  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
-  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x51"
+  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77"
+  "\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61"
+  "\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
+  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f"
   "\x72\x75\x6e\x74\x69\x6d\x65\x2f\x67\x64\x62\x6d\x2e\x69\x6e\x66"
   "\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d"
   "\x72\x6f\x6f\x74\x5d\x02\x0b\x67\x64\x62\x6d\x2d\x63\x6c\x6f\x73"
@@ -2645,19 +2646,19 @@ static const unsigned char prog_gdbm_so_data_dea6ff440b1edc52 [2389] =
   "\x81\x83\x02\x1f\x41";
 
 SCHEME_OBJECT *
-gdbm_so_data_dea6ff440b1edc52 (entry_count_t dispatch_base)
+gdbm_so_data_14ce8435a2573f1a (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_gdbm_so_data_dea6ff440b1edc52 [0]))), (sizeof (prog_gdbm_so_data_dea6ff440b1edc52)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_gdbm_so_data_14ce8435a2573f1a [0]))), (sizeof (prog_gdbm_so_data_14ce8435a2573f1a)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_23]));
 }
 
-DECLARE_COMPILED_DATA_NS ("gdbm.so", gdbm_so_data_dea6ff440b1edc52)
+DECLARE_COMPILED_DATA_NS ("gdbm.so", gdbm_so_data_14ce8435a2573f1a)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("gdbm.so", "e7b26439016a8b40")
+DECLARE_DYNAMIC_INITIALIZATION ("gdbm.so", "24d9f06d6edd45af")
