@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:22-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:32-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -559,7 +559,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-gensym_so_b1e2e864d020f296 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+gensym_so_bf2f34e3c8c524aa (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -638,26 +638,26 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_gensym_so_b1e2e864d020f296 [2] =
+static const struct liarc_code_S arr_decl_gensym_so_bf2f34e3c8c524aa [2] =
   {
     { "gensym_so_code_1", 14, gensym_so_code_1 },
     { "gensym_so_code_2", 3, gensym_so_code_2 }
   };
 
 int
-decl_gensym_so_b1e2e864d020f296 (void)
+decl_gensym_so_bf2f34e3c8c524aa (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_gensym_so_b1e2e864d020f296);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_gensym_so_bf2f34e3c8c524aa);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("gensym.so", 3, decl_gensym_so_b1e2e864d020f296, gensym_so_b1e2e864d020f296)
+DECLARE_COMPILED_CODE ("gensym.so", 3, decl_gensym_so_bf2f34e3c8c524aa, gensym_so_bf2f34e3c8c524aa)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_gensym_so_data_b1e2e864d020f296 [572] =
+static const unsigned char prog_gensym_so_data_bf2f34e3c8c524aa [588] =
   "\x3d\x07\x75\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x06\x07\x85\xc2\x02"
   "\x1d\x0c\x0d\xb9\x0d\xba\x25\x0d\xbb\xb2\x24\x28\x0d\x28\x0d\x28"
   "\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -665,10 +665,11 @@ static const unsigned char prog_gensym_so_data_b1e2e864d020f296 [572] =
   "\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x82\x88\x1d\x0c\x80\xb2"
   "\xb3\x25\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xb8\x99\xbd\x88\xb5"
   "\xb0\x2a\x1e\x1e\xb4\x2a\x9b\x0d\xb3\xb2\xb1\x9b\x28\x0d\x26\x22"
-  "\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f"
-  "\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
-  "\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
-  "\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65"
+  "\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f"
+  "\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68"
+  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e"
+  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65"
   "\x2f\x67\x65\x6e\x73\x79\x6d\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
   "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
   "\x02\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x1e\x08"
@@ -696,19 +697,19 @@ static const unsigned char prog_gensym_so_data_b1e2e864d020f296 [572] =
   "\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-gensym_so_data_b1e2e864d020f296 (entry_count_t dispatch_base)
+gensym_so_data_bf2f34e3c8c524aa (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_gensym_so_data_b1e2e864d020f296 [0]))), (sizeof (prog_gensym_so_data_b1e2e864d020f296)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_gensym_so_data_bf2f34e3c8c524aa [0]))), (sizeof (prog_gensym_so_data_bf2f34e3c8c524aa)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("gensym.so", gensym_so_data_b1e2e864d020f296)
+DECLARE_COMPILED_DATA_NS ("gensym.so", gensym_so_data_bf2f34e3c8c524aa)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("gensym.so", "5724ce382cd905b9")
+DECLARE_DYNAMIC_INITIALIZATION ("gensym.so", "ec08966e6443e847")
