@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:22-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:32-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1058,7 +1058,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-gentag_so_e45dad87ef8261bd (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+gentag_so_401673fdbe03aff3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1143,7 +1143,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_gentag_so_e45dad87ef8261bd [8] =
+static const struct liarc_code_S arr_decl_gentag_so_401673fdbe03aff3 [8] =
   {
     { "gentag_so_code_1", 8, gentag_so_code_1 },
     { "gentag_so_code_2", 2, gentag_so_code_2 },
@@ -1156,19 +1156,19 @@ static const struct liarc_code_S arr_decl_gentag_so_e45dad87ef8261bd [8] =
   };
 
 int
-decl_gentag_so_e45dad87ef8261bd (void)
+decl_gentag_so_401673fdbe03aff3 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_gentag_so_e45dad87ef8261bd);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_gentag_so_401673fdbe03aff3);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("gentag.so", 3, decl_gentag_so_e45dad87ef8261bd, gentag_so_e45dad87ef8261bd)
+DECLARE_COMPILED_CODE ("gentag.so", 3, decl_gentag_so_401673fdbe03aff3, gentag_so_401673fdbe03aff3)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_gentag_so_data_e45dad87ef8261bd [991] =
+static const unsigned char prog_gentag_so_data_401673fdbe03aff3 [1007] =
   "\x28\x0d\xe1\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\x02\x82\x81"
   "\xc3\xb9\x80\x0d\xba\xc2\x02\x28\x0d\xbb\x23\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d"
@@ -1183,9 +1183,10 @@ static const unsigned char prog_gentag_so_data_e45dad87ef8261bd [991] =
   "\xbd\x9f\xb8\x88\xb0\xb5\x2a\x1e\x84\x1b\x2a\x1b\x2a\x1b\x2a\xb1"
   "\x2a\xb7\x2a\x02\x82\xb2\xb6\x2a\xb4\x2a\x17\x0d\xb3\x0d\x0d\x0d"
   "\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22\x29"
-  "\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
-  "\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
-  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
+  "\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65"
+  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d"
+  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e"
   "\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x67\x65"
   "\x6e\x74\x61\x67\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x10\x6f"
@@ -1233,19 +1234,19 @@ static const unsigned char prog_gentag_so_data_e45dad87ef8261bd [991] =
   "\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-gentag_so_data_e45dad87ef8261bd (entry_count_t dispatch_base)
+gentag_so_data_401673fdbe03aff3 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_gentag_so_data_e45dad87ef8261bd [0]))), (sizeof (prog_gentag_so_data_e45dad87ef8261bd)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_gentag_so_data_401673fdbe03aff3 [0]))), (sizeof (prog_gentag_so_data_401673fdbe03aff3)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("gentag.so", gentag_so_data_e45dad87ef8261bd)
+DECLARE_COMPILED_DATA_NS ("gentag.so", gentag_so_data_401673fdbe03aff3)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("gentag.so", "58b4ebc9bcf55464")
+DECLARE_DYNAMIC_INITIALIZATION ("gentag.so", "ebd49267b0774066")
