@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:26-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:36-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1987,7 +1987,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-html_form_codec_so_6e3282c7cd3ee45a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+html_form_codec_so_aa932baccabed1d6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2071,7 +2071,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_html_form_codec_so_6e3282c7cd3ee45a [7] =
+static const struct liarc_code_S arr_decl_html_form_codec_so_aa932baccabed1d6 [7] =
   {
     { "html_form_codec_so_code_1", 10, html_form_codec_so_code_1 },
     { "html_form_codec_so_code_2", 23, html_form_codec_so_code_2 },
@@ -2083,19 +2083,19 @@ static const struct liarc_code_S arr_decl_html_form_codec_so_6e3282c7cd3ee45a [7
   };
 
 int
-decl_html_form_codec_so_6e3282c7cd3ee45a (void)
+decl_html_form_codec_so_aa932baccabed1d6 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_html_form_codec_so_6e3282c7cd3ee45a);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_html_form_codec_so_aa932baccabed1d6);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("html-form-codec.so", 3, decl_html_form_codec_so_6e3282c7cd3ee45a, html_form_codec_so_6e3282c7cd3ee45a)
+DECLARE_COMPILED_CODE ("html-form-codec.so", 3, decl_html_form_codec_so_aa932baccabed1d6, html_form_codec_so_aa932baccabed1d6)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_html_form_codec_so_data_6e3282c7cd3ee45a [1845] =
+static const unsigned char prog_html_form_codec_so_data_aa932baccabed1d6 [1861] =
   "\x59\x0f\x8b\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x08\x0d\xb9"
   "\x0d\xba\x28\x0d\x28\x0d\xbb\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\xbe"
   "\x28\x0d\x28\x0d\x28\x0d\xbf\x23\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -2120,10 +2120,11 @@ static const unsigned char prog_html_form_codec_so_data_6e3282c7cd3ee45a [1845]
   "\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x21\x17\x2b\xb8\x9e\x1c\x88\x1b\xb0\x2a\x1e\x1b\x2a\x1b"
   "\x2a\x1b\x2a\xb3\x2a\xb5\x2a\x1b\x2a\x9f\x0d\x1b\xb6\xb1\xb4\xb2"
-  "\xb7\x0d\x9f\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4c"
-  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72"
-  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
-  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f"
+  "\xb7\x0d\x9f\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5c"
+  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77"
+  "\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61"
+  "\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
+  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f"
   "\x72\x75\x6e\x74\x69\x6d\x65\x2f\x68\x74\x6d\x6c\x2d\x66\x6f\x72"
   "\x6d\x2d\x63\x6f\x64\x65\x63\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
   "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
@@ -2214,19 +2215,19 @@ static const unsigned char prog_html_form_codec_so_data_6e3282c7cd3ee45a [1845]
   "\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-html_form_codec_so_data_6e3282c7cd3ee45a (entry_count_t dispatch_base)
+html_form_codec_so_data_aa932baccabed1d6 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_html_form_codec_so_data_6e3282c7cd3ee45a [0]))), (sizeof (prog_html_form_codec_so_data_6e3282c7cd3ee45a)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_html_form_codec_so_data_aa932baccabed1d6 [0]))), (sizeof (prog_html_form_codec_so_data_aa932baccabed1d6)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("html-form-codec.so", html_form_codec_so_data_6e3282c7cd3ee45a)
+DECLARE_COMPILED_DATA_NS ("html-form-codec.so", html_form_codec_so_data_aa932baccabed1d6)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("html-form-codec.so", "ce72480a351cbd56")
+DECLARE_DYNAMIC_INITIALIZATION ("html-form-codec.so", "4e00b8b04fb65502")
