@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:26-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:36-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -907,7 +907,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-http_client_so_91ebc6387f177c81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+http_client_so_9a5a25eff069b71a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2027,7 +2027,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_http_client_so_91ebc6387f177c81 [7] =
+static const struct liarc_code_S arr_decl_http_client_so_9a5a25eff069b71a [7] =
   {
     { "http_client_so_code_1", 1, http_client_so_code_1 },
     { "http_client_so_code_2", 1, http_client_so_code_2 },
@@ -2039,19 +2039,19 @@ static const struct liarc_code_S arr_decl_http_client_so_91ebc6387f177c81 [7] =
   };
 
 int
-decl_http_client_so_91ebc6387f177c81 (void)
+decl_http_client_so_9a5a25eff069b71a (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_http_client_so_91ebc6387f177c81);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_http_client_so_9a5a25eff069b71a);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("http-client.so", 53, decl_http_client_so_91ebc6387f177c81, http_client_so_91ebc6387f177c81)
+DECLARE_COMPILED_CODE ("http-client.so", 53, decl_http_client_so_9a5a25eff069b71a, http_client_so_9a5a25eff069b71a)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_http_client_so_data_91ebc6387f177c81 [1803] =
+static const unsigned char prog_http_client_so_data_9a5a25eff069b71a [1819] =
   "\xa8\x01\x14\x9c\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0c\x28"
   "\x0d\xb9\x23\x22\x29\x21\x17\x2b\xba\x1d\xb0\x82\x88\x0c\x0c\x28"
   "\xb1\x23\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x83\x88\x0c\x28\xb1\x23"
@@ -2078,9 +2078,10 @@ static const unsigned char prog_http_client_so_data_91ebc6387f177c81 [1803] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
-  "\x02\x48\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70"
-  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74"
-  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72"
+  "\x02\x58\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66"
+  "\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72"
   "\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x68\x74\x74\x70\x2d\x63"
   "\x6c\x69\x65\x6e\x74\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
   "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x01"
@@ -2167,19 +2168,19 @@ static const unsigned char prog_http_client_so_data_91ebc6387f177c81 [1803] =
   "\x81\x87\x02\x01\x04\x81\x83\x02\x6b\xa8\x01";
 
 SCHEME_OBJECT *
-http_client_so_data_91ebc6387f177c81 (entry_count_t dispatch_base)
+http_client_so_data_9a5a25eff069b71a (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_http_client_so_data_91ebc6387f177c81 [0]))), (sizeof (prog_http_client_so_data_91ebc6387f177c81)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_http_client_so_data_9a5a25eff069b71a [0]))), (sizeof (prog_http_client_so_data_9a5a25eff069b71a)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_74]));
 }
 
-DECLARE_COMPILED_DATA_NS ("http-client.so", http_client_so_data_91ebc6387f177c81)
+DECLARE_COMPILED_DATA_NS ("http-client.so", http_client_so_data_9a5a25eff069b71a)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("http-client.so", "14c00bb8da7872f9")
+DECLARE_DYNAMIC_INITIALIZATION ("http-client.so", "60847010d2078fc2")
