@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:30-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:40-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -111,7 +111,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-kryptdum_so_d86964ab0628e3a9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+kryptdum_so_950da2da72c59201 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -190,32 +190,33 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_kryptdum_so_d86964ab0628e3a9 [2] =
+static const struct liarc_code_S arr_decl_kryptdum_so_950da2da72c59201 [2] =
   {
     { "kryptdum_so_code_1", 1, kryptdum_so_code_1 },
     { "kryptdum_so_code_2", 1, kryptdum_so_code_2 }
   };
 
 int
-decl_kryptdum_so_d86964ab0628e3a9 (void)
+decl_kryptdum_so_950da2da72c59201 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_kryptdum_so_d86964ab0628e3a9);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_kryptdum_so_950da2da72c59201);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("kryptdum.so", 3, decl_kryptdum_so_d86964ab0628e3a9, kryptdum_so_d86964ab0628e3a9)
+DECLARE_COMPILED_CODE ("kryptdum.so", 3, decl_kryptdum_so_950da2da72c59201, kryptdum_so_950da2da72c59201)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_kryptdum_so_data_d86964ab0628e3a9 [206] =
+static const unsigned char prog_kryptdum_so_data_950da2da72c59201 [222] =
   "\x11\x04\x30\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c\x2b"
   "\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xb8\x99\xba\x88\xb2\xb0"
   "\x2a\xb1\x2a\x99\x0d\x0d\x99\x28\x0d\x26\x22\x29\x22\x29\x22\x29"
-  "\x21\x17\x02\x45\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74"
-  "\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d"
-  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f"
+  "\x21\x17\x02\x55\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53"
+  "\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72"
+  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74"
+  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f"
   "\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x6b\x72\x79\x70"
   "\x74\x64\x75\x6d\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x04"
@@ -225,19 +226,19 @@ static const unsigned char prog_kryptdum_so_data_d86964ab0628e3a9 [206] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-kryptdum_so_data_d86964ab0628e3a9 (entry_count_t dispatch_base)
+kryptdum_so_data_950da2da72c59201 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_kryptdum_so_data_d86964ab0628e3a9 [0]))), (sizeof (prog_kryptdum_so_data_d86964ab0628e3a9)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_kryptdum_so_data_950da2da72c59201 [0]))), (sizeof (prog_kryptdum_so_data_950da2da72c59201)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("kryptdum.so", kryptdum_so_data_d86964ab0628e3a9)
+DECLARE_COMPILED_DATA_NS ("kryptdum.so", kryptdum_so_data_950da2da72c59201)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("kryptdum.so", "36f9bf848546e5d3")
+DECLARE_DYNAMIC_INITIALIZATION ("kryptdum.so", "92f87444b443f573")
