@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:31-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:41-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1429,7 +1429,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-lambdx_so_d421359e1a7f4f46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+lambdx_so_8802e2716a54dca2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1755,7 +1755,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_lambdx_so_d421359e1a7f4f46 [13] =
+static const struct liarc_code_S arr_decl_lambdx_so_8802e2716a54dca2 [13] =
   {
     { "lambdx_so_code_1", 2, lambdx_so_code_1 },
     { "lambdx_so_code_2", 3, lambdx_so_code_2 },
@@ -1773,19 +1773,19 @@ static const struct liarc_code_S arr_decl_lambdx_so_d421359e1a7f4f46 [13] =
   };
 
 int
-decl_lambdx_so_d421359e1a7f4f46 (void)
+decl_lambdx_so_8802e2716a54dca2 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_lambdx_so_d421359e1a7f4f46);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_lambdx_so_8802e2716a54dca2);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("lambdx.so", 14, decl_lambdx_so_d421359e1a7f4f46, lambdx_so_d421359e1a7f4f46)
+DECLARE_COMPILED_CODE ("lambdx.so", 14, decl_lambdx_so_8802e2716a54dca2, lambdx_so_8802e2716a54dca2)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_lambdx_so_data_d421359e1a7f4f46 [1146] =
+static const unsigned char prog_lambdx_so_data_8802e2716a54dca2 [1162] =
   "\x3c\x13\xbd\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\x28\x0d"
   "\x23\x22\x29\x22\x29\x21\x17\x2b\xb9\x1d\xb0\x82\x88\x28\x0d\x28"
   "\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xba\x1d\xb0\x83\x88"
@@ -1806,9 +1806,10 @@ static const unsigned char prog_lambdx_so_data_d421359e1a7f4f46 [1146] =
   "\x1b\x9a\xb5\x2a\xb2\x2a\xb1\x2a\x9a\x28\x0d\x28\x0d\x28\x0d\x26"
   "\x1b\x24\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
-  "\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70"
-  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74"
-  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72"
+  "\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66"
+  "\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72"
   "\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x6c\x61\x6d\x62\x64\x78"
   "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
   "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x0d\x73\x63\x61\x6e"
@@ -1860,19 +1861,19 @@ static const unsigned char prog_lambdx_so_data_d421359e1a7f4f46 [1146] =
   "\x81\x83\x02\x01\x04\x81\x83\x02\x1d\x3c";
 
 SCHEME_OBJECT *
-lambdx_so_data_d421359e1a7f4f46 (entry_count_t dispatch_base)
+lambdx_so_data_8802e2716a54dca2 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_lambdx_so_data_d421359e1a7f4f46 [0]))), (sizeof (prog_lambdx_so_data_d421359e1a7f4f46)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_lambdx_so_data_8802e2716a54dca2 [0]))), (sizeof (prog_lambdx_so_data_8802e2716a54dca2)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_21]));
 }
 
-DECLARE_COMPILED_DATA_NS ("lambdx.so", lambdx_so_data_d421359e1a7f4f46)
+DECLARE_COMPILED_DATA_NS ("lambdx.so", lambdx_so_data_8802e2716a54dca2)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("lambdx.so", "66f3801da1a44bb8")
+DECLARE_DYNAMIC_INITIALIZATION ("lambdx.so", "05395ab4c642171a")
