@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:35-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:45-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -808,7 +808,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-msort_so_dac4c332b8466cce (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+msort_so_85fc91ae8e48b16f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -964,26 +964,26 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_msort_so_dac4c332b8466cce [2] =
+static const struct liarc_code_S arr_decl_msort_so_85fc91ae8e48b16f [2] =
   {
     { "msort_so_code_1", 4, msort_so_code_1 },
     { "msort_so_code_2", 16, msort_so_code_2 }
   };
 
 int
-decl_msort_so_dac4c332b8466cce (void)
+decl_msort_so_85fc91ae8e48b16f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_msort_so_dac4c332b8466cce);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_msort_so_85fc91ae8e48b16f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("msort.so", 7, decl_msort_so_dac4c332b8466cce, msort_so_dac4c332b8466cce)
+DECLARE_COMPILED_CODE ("msort.so", 7, decl_msort_so_85fc91ae8e48b16f, msort_so_85fc91ae8e48b16f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_msort_so_data_dac4c332b8466cce [542] =
+static const unsigned char prog_msort_so_data_85fc91ae8e48b16f [558] =
   "\x34\x05\x7a\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28\x0d"
   "\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
   "\x2b\xbb\x1d\xb0\x82\x88\xc3\xc2\x1d\x0c\xb2\x80\xc1\x28\xb1\x28"
@@ -991,10 +991,11 @@ static const unsigned char prog_msort_so_data_dac4c332b8466cce [542] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x21\x17\x2b\xb9\x99\xb8\x88\xb0\x0d\xc3\x0d\xb2\x0d\xb8"
   "\x99\xb1\x2a\xb3\x2a\x99\x28\x0d\x26\xb0\xb2\x24\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x42\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x52\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
+  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
   "\x6e\x74\x69\x6d\x65\x2f\x6d\x73\x6f\x72\x74\x2e\x69\x6e\x66\x15"
   "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
   "\x6f\x6f\x74\x5d\x02\x03\x0c\x76\x65\x63\x74\x6f\x72\x2d\x63\x6f"
@@ -1020,19 +1021,19 @@ static const unsigned char prog_msort_so_data_dac4c332b8466cce [542] =
   "\x83\x02\x02\x06\x81\x85\x02\x01\x04\x81\x83\x02\x0f\x1f";
 
 SCHEME_OBJECT *
-msort_so_data_dac4c332b8466cce (entry_count_t dispatch_base)
+msort_so_data_85fc91ae8e48b16f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_msort_so_data_dac4c332b8466cce [0]))), (sizeof (prog_msort_so_data_dac4c332b8466cce)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_msort_so_data_85fc91ae8e48b16f [0]))), (sizeof (prog_msort_so_data_85fc91ae8e48b16f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_11]));
 }
 
-DECLARE_COMPILED_DATA_NS ("msort.so", msort_so_data_dac4c332b8466cce)
+DECLARE_COMPILED_DATA_NS ("msort.so", msort_so_data_85fc91ae8e48b16f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("msort.so", "dfc001c54a792eb2")
+DECLARE_DYNAMIC_INITIALIZATION ("msort.so", "a560f2368ebf8996")
