@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:35-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:45-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1417,7 +1417,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-ntdir_so_57a0e44183132cf6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+ntdir_so_a8cdc8cd00914d1b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1501,7 +1501,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_ntdir_so_57a0e44183132cf6 [7] =
+static const struct liarc_code_S arr_decl_ntdir_so_a8cdc8cd00914d1b [7] =
   {
     { "ntdir_so_code_1", 6, ntdir_so_code_1 },
     { "ntdir_so_code_2", 3, ntdir_so_code_2 },
@@ -1513,19 +1513,19 @@ static const struct liarc_code_S arr_decl_ntdir_so_57a0e44183132cf6 [7] =
   };
 
 int
-decl_ntdir_so_57a0e44183132cf6 (void)
+decl_ntdir_so_a8cdc8cd00914d1b (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_ntdir_so_57a0e44183132cf6);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_ntdir_so_a8cdc8cd00914d1b);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("ntdir.so", 3, decl_ntdir_so_57a0e44183132cf6, ntdir_so_57a0e44183132cf6)
+DECLARE_COMPILED_CODE ("ntdir.so", 3, decl_ntdir_so_a8cdc8cd00914d1b, ntdir_so_a8cdc8cd00914d1b)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_ntdir_so_data_57a0e44183132cf6 [1222] =
+static const unsigned char prog_ntdir_so_data_a8cdc8cd00914d1b [1238] =
   "\x45\x14\xb3\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\x07\x1d"
   "\x0d\xba\x24\x28\x0d\xbb\x28\x0d\xbc\x28\x0d\x28\xb2\x23\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0"
@@ -1545,10 +1545,11 @@ static const unsigned char prog_ntdir_so_data_57a0e44183132cf6 [1222] =
   "\x02\x88\xc1\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x9e\x1c"
   "\x88\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a\xb5\x2a"
   "\x07\x9f\x1b\x1b\xb4\x1b\xb3\xb2\x0d\xb7\x9f\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x42\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x52\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x6e\x74\x64\x69\x72\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
   "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04"
   "\x63\x61\x72\x08\x0b\x70\x61\x74\x68\x6e\x61\x6d\x65\x3c\x3f\x02"
@@ -1605,19 +1606,19 @@ static const unsigned char prog_ntdir_so_data_57a0e44183132cf6 [1222] =
   "\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-ntdir_so_data_57a0e44183132cf6 (entry_count_t dispatch_base)
+ntdir_so_data_a8cdc8cd00914d1b (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_ntdir_so_data_57a0e44183132cf6 [0]))), (sizeof (prog_ntdir_so_data_57a0e44183132cf6)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_ntdir_so_data_a8cdc8cd00914d1b [0]))), (sizeof (prog_ntdir_so_data_a8cdc8cd00914d1b)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("ntdir.so", ntdir_so_data_57a0e44183132cf6)
+DECLARE_COMPILED_DATA_NS ("ntdir.so", ntdir_so_data_a8cdc8cd00914d1b)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("ntdir.so", "9819e9fbac9f7cef")
+DECLARE_DYNAMIC_INITIALIZATION ("ntdir.so", "e6c26e235f8989bc")
