@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:36-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:46-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2214,7 +2214,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-option_so_d80f00e0f2c32bbb (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+option_so_10612e1e42765245 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2361,7 +2361,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_option_so_d80f00e0f2c32bbb [11] =
+static const struct liarc_code_S arr_decl_option_so_10612e1e42765245 [11] =
   {
     { "option_so_code_1", 35, option_so_code_1 },
     { "option_so_code_2", 3, option_so_code_2 },
@@ -2377,19 +2377,19 @@ static const struct liarc_code_S arr_decl_option_so_d80f00e0f2c32bbb [11] =
   };
 
 int
-decl_option_so_d80f00e0f2c32bbb (void)
+decl_option_so_10612e1e42765245 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_option_so_d80f00e0f2c32bbb);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_option_so_10612e1e42765245);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("option.so", 6, decl_option_so_d80f00e0f2c32bbb, option_so_d80f00e0f2c32bbb)
+DECLARE_COMPILED_CODE ("option.so", 6, decl_option_so_10612e1e42765245, option_so_10612e1e42765245)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_option_so_data_d80f00e0f2c32bbb [2040] =
+static const unsigned char prog_option_so_data_10612e1e42765245 [2056] =
   "\x71\x17\xc7\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\x0c\x1d\x07"
   "\x08\xc1\x1d\x0d\xb9\x0d\xba\x0d\xbb\x0d\xbc\x25\xb1\xb3\xb2\xb4"
   "\x24\x28\x0d\x28\x0d\x28\x0d\xbc\x28\x0d\x28\x0d\xbd\x28\x0d\xbe"
@@ -2418,10 +2418,11 @@ static const unsigned char prog_option_so_data_d80f00e0f2c32bbb [2040] =
   "\x9b\xb5\x0d\x0d\x1b\x9b\xc3\xb3\xb2\xb1\x1b\x1b\x1b\x1b\x0d\x1c"
   "\x0d\x0d\x0d\x17\x08\x08\x1b\x2a\x1b\x2a\xb6\x2a\x1b\x2a\x1b\x2a"
   "\x1b\x2a\x1b\x2a\x1b\x2a\x17\x28\x0d\x26\x1b\x24\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65"
-  "\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65"
+  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
+  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
   "\x69\x6d\x65\x2f\x6f\x70\x74\x69\x6f\x6e\x2e\x69\x6e\x66\x15\x23"
   "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
   "\x6f\x74\x5d\x02\x1f\x2a\x70\x61\x72\x73\x65\x72\x2d\x63\x61\x6e"
@@ -2520,19 +2521,19 @@ static const unsigned char prog_option_so_data_d80f00e0f2c32bbb [2040] =
   "\x02\x01\x04\x81\x83\x02\x0d\x1d";
 
 SCHEME_OBJECT *
-option_so_data_d80f00e0f2c32bbb (entry_count_t dispatch_base)
+option_so_data_10612e1e42765245 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_option_so_data_d80f00e0f2c32bbb [0]))), (sizeof (prog_option_so_data_d80f00e0f2c32bbb)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_option_so_data_10612e1e42765245 [0]))), (sizeof (prog_option_so_data_10612e1e42765245)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_10]));
 }
 
-DECLARE_COMPILED_DATA_NS ("option.so", option_so_data_d80f00e0f2c32bbb)
+DECLARE_COMPILED_DATA_NS ("option.so", option_so_data_10612e1e42765245)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("option.so", "2901da676bd8be24")
+DECLARE_DYNAMIC_INITIALIZATION ("option.so", "43ea8216078272fb")
