@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:36-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:46-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -193,7 +193,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-optiondb_so_5835a1eae2833ef5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+optiondb_so_4e6690d32d1659c9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -432,19 +432,19 @@ INVOKE_INTERFACE_TARGET_1
 }
 
 int
-decl_optiondb_so_5835a1eae2833ef5 (void)
+decl_optiondb_so_4e6690d32d1659c9 (void)
 {
   DECLARE_SUBCODE ("optiondb_so_code_1", 5, optiondb_so_code_1);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("optiondb.so", 12, decl_optiondb_so_5835a1eae2833ef5, optiondb_so_5835a1eae2833ef5)
+DECLARE_COMPILED_CODE ("optiondb.so", 12, decl_optiondb_so_4e6690d32d1659c9, optiondb_so_4e6690d32d1659c9)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_optiondb_so_data_5835a1eae2833ef5 [922] =
+static const unsigned char prog_optiondb_so_data_4e6690d32d1659c9 [938] =
   "\x39\x06\xf2\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\xc1\xc1\x0d"
   "\xb8\x24\x28\x0d\xb9\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x2b\xba\x98\x88\xb2\x0d\xbb\x0d\xbc\x0d\x08\x89\x0c\xb4"
@@ -460,9 +460,10 @@ static const unsigned char prog_optiondb_so_data_5835a1eae2833ef5 [922] =
   "\xb4\xb3\x08\x89\x06\x0c\x08\x8b\x08\x14\xb4\x0d\x0d\x08\x8a\x0c"
   "\x0d\x24\x28\xb0\x28\x0d\x28\xb1\x28\xb1\x23\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x21\x17\x02\x45\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
-  "\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
-  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x29\x22\x29\x21\x17\x02\x55\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
+  "\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d"
+  "\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f"
+  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
   "\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x6f"
   "\x70\x74\x69\x6f\x6e\x64\x62\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75"
   "\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d"
@@ -505,19 +506,19 @@ static const unsigned char prog_optiondb_so_data_5835a1eae2833ef5 [922] =
   "\x81\x87\x02\x01\x04\x81\x83\x02\x19\x39";
 
 SCHEME_OBJECT *
-optiondb_so_data_5835a1eae2833ef5 (entry_count_t dispatch_base)
+optiondb_so_data_4e6690d32d1659c9 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_optiondb_so_data_5835a1eae2833ef5 [0]))), (sizeof (prog_optiondb_so_data_5835a1eae2833ef5)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_optiondb_so_data_4e6690d32d1659c9 [0]))), (sizeof (prog_optiondb_so_data_4e6690d32d1659c9)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_19]));
 }
 
-DECLARE_COMPILED_DATA_NS ("optiondb.so", optiondb_so_data_5835a1eae2833ef5)
+DECLARE_COMPILED_DATA_NS ("optiondb.so", optiondb_so_data_4e6690d32d1659c9)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("optiondb.so", "218e9318d03ce920")
+DECLARE_DYNAMIC_INITIALIZATION ("optiondb.so", "bed2715a8cc847b1")
