@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:36-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:46-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1948,7 +1948,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-ordvec_so_978a9cdf9ab6f2b9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+ordvec_so_897d016b6686d6f8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2033,7 +2033,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_ordvec_so_978a9cdf9ab6f2b9 [8] =
+static const struct liarc_code_S arr_decl_ordvec_so_897d016b6686d6f8 [8] =
   {
     { "ordvec_so_code_1", 2, ordvec_so_code_1 },
     { "ordvec_so_code_2", 6, ordvec_so_code_2 },
@@ -2046,19 +2046,19 @@ static const struct liarc_code_S arr_decl_ordvec_so_978a9cdf9ab6f2b9 [8] =
   };
 
 int
-decl_ordvec_so_978a9cdf9ab6f2b9 (void)
+decl_ordvec_so_897d016b6686d6f8 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_ordvec_so_978a9cdf9ab6f2b9);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_ordvec_so_897d016b6686d6f8);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("ordvec.so", 3, decl_ordvec_so_978a9cdf9ab6f2b9, ordvec_so_978a9cdf9ab6f2b9)
+DECLARE_COMPILED_CODE ("ordvec.so", 3, decl_ordvec_so_897d016b6686d6f8, ordvec_so_897d016b6686d6f8)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_ordvec_so_data_978a9cdf9ab6f2b9 [928] =
+static const unsigned char prog_ordvec_so_data_897d016b6686d6f8 [944] =
   "\x46\x0e\xfd\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9\x80\x28"
   "\x0d\xba\x23\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\xc2"
   "\xbc\x28\x0d\xbd\x28\x0d\xbe\x23\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -2075,9 +2075,10 @@ static const unsigned char prog_ordvec_so_data_978a9cdf9ab6f2b9 [928] =
   "\x29\x22\x29\x21\x17\x2b\xbc\x9f\xb8\x88\xb0\xb4\x2a\xb1\x2a\x1b"
   "\x2a\x1b\x2a\xb6\x2a\x1b\x2a\xb7\x2a\xb3\x2a\x9f\x1b\x0d\xb5\x0d"
   "\x1b\x0d\xb2\x0d\x9f\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17"
-  "\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70"
-  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74"
-  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72"
+  "\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66"
+  "\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72"
   "\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x6f\x72\x64\x76\x65\x63"
   "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
   "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0e\x76\x65\x63\x74\x6f"
@@ -2119,19 +2120,19 @@ static const unsigned char prog_ordvec_so_data_978a9cdf9ab6f2b9 [928] =
   "\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-ordvec_so_data_978a9cdf9ab6f2b9 (entry_count_t dispatch_base)
+ordvec_so_data_897d016b6686d6f8 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_ordvec_so_data_978a9cdf9ab6f2b9 [0]))), (sizeof (prog_ordvec_so_data_978a9cdf9ab6f2b9)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_ordvec_so_data_897d016b6686d6f8 [0]))), (sizeof (prog_ordvec_so_data_897d016b6686d6f8)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("ordvec.so", ordvec_so_data_978a9cdf9ab6f2b9)
+DECLARE_COMPILED_DATA_NS ("ordvec.so", ordvec_so_data_897d016b6686d6f8)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("ordvec.so", "3ed6beb995d13176")
+DECLARE_DYNAMIC_INITIALIZATION ("ordvec.so", "8fa91afc6290a760")
