@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:37-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:46-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -658,7 +658,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-os2dir_so_65b6efd5eca30cde (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+os2dir_so_b11d71b7d07f7cd3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -739,7 +739,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_os2dir_so_65b6efd5eca30cde [4] =
+static const struct liarc_code_S arr_decl_os2dir_so_b11d71b7d07f7cd3 [4] =
   {
     { "os2dir_so_code_1", 3, os2dir_so_code_1 },
     { "os2dir_so_code_2", 12, os2dir_so_code_2 },
@@ -748,19 +748,19 @@ static const struct liarc_code_S arr_decl_os2dir_so_65b6efd5eca30cde [4] =
   };
 
 int
-decl_os2dir_so_65b6efd5eca30cde (void)
+decl_os2dir_so_b11d71b7d07f7cd3 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_os2dir_so_65b6efd5eca30cde);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_os2dir_so_b11d71b7d07f7cd3);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("os2dir.so", 3, decl_os2dir_so_65b6efd5eca30cde, os2dir_so_65b6efd5eca30cde)
+DECLARE_COMPILED_CODE ("os2dir.so", 3, decl_os2dir_so_b11d71b7d07f7cd3, os2dir_so_b11d71b7d07f7cd3)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_os2dir_so_data_65b6efd5eca30cde [738] =
+static const unsigned char prog_os2dir_so_data_b11d71b7d07f7cd3 [754] =
   "\x33\x0a\xa3\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\x0d\xb9\x24"
   "\x28\x0d\xba\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb"
   "\x1d\xb0\x82\x88\x1d\x0d\xbc\x25\x0d\xb4\x24\x28\x0d\xbd\x28\xb5"
@@ -771,10 +771,11 @@ static const unsigned char prog_os2dir_so_data_65b6efd5eca30cde [738] =
   "\x21\x17\x2b\xbf\x1d\xb0\x84\x88\x28\x0d\x28\x0d\x23\x22\x29\x22"
   "\x29\x22\x29\x21\x17\x2b\xb8\x9b\x1c\x88\x1b\xb0\x2a\xb7\x2a\xb6"
   "\x2a\xb3\x2a\x07\x9c\xb1\xb5\xb2\x0d\xb4\x9c\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x6f\x73\x32\x64\x69\x72\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
   "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
   "\x08\x0b\x70\x61\x74\x68\x6e\x61\x6d\x65\x3c\x3f\x02\x03\x16\x64"
@@ -810,19 +811,19 @@ static const unsigned char prog_os2dir_so_data_65b6efd5eca30cde [738] =
   "\x07\x11";
 
 SCHEME_OBJECT *
-os2dir_so_data_65b6efd5eca30cde (entry_count_t dispatch_base)
+os2dir_so_data_b11d71b7d07f7cd3 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_os2dir_so_data_65b6efd5eca30cde [0]))), (sizeof (prog_os2dir_so_data_65b6efd5eca30cde)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_os2dir_so_data_b11d71b7d07f7cd3 [0]))), (sizeof (prog_os2dir_so_data_b11d71b7d07f7cd3)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("os2dir.so", os2dir_so_data_65b6efd5eca30cde)
+DECLARE_COMPILED_DATA_NS ("os2dir.so", os2dir_so_data_b11d71b7d07f7cd3)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("os2dir.so", "c1972d487cb156f0")
+DECLARE_DYNAMIC_INITIALIZATION ("os2dir.so", "4737484e33b4a4a6")
