@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:41-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:50-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1664,7 +1664,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-partab_so_391fe66185bac152 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+partab_so_dde18eb2a152a87f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1954,7 +1954,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_partab_so_391fe66185bac152 [12] =
+static const struct liarc_code_S arr_decl_partab_so_dde18eb2a152a87f [12] =
   {
     { "partab_so_code_1", 1, partab_so_code_1 },
     { "partab_so_code_2", 1, partab_so_code_2 },
@@ -1971,19 +1971,19 @@ static const struct liarc_code_S arr_decl_partab_so_391fe66185bac152 [12] =
   };
 
 int
-decl_partab_so_391fe66185bac152 (void)
+decl_partab_so_dde18eb2a152a87f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_partab_so_391fe66185bac152);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_partab_so_dde18eb2a152a87f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("partab.so", 13, decl_partab_so_391fe66185bac152, partab_so_391fe66185bac152)
+DECLARE_COMPILED_CODE ("partab.so", 13, decl_partab_so_dde18eb2a152a87f, partab_so_dde18eb2a152a87f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_partab_so_data_391fe66185bac152 [1316] =
+static const unsigned char prog_partab_so_data_dde18eb2a152a87f [1332] =
   "\x39\x17\xd3\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x22\x29\x21\x9c"
   "\x2b\xb9\x1d\xb0\x82\x88\x22\x29\x21\x9c\x2b\xba\x1d\xb0\x83\x88"
   "\xc2\xbb\x81\x22\x29\x21\x9e\x2b\xbc\x1d\xb0\x84\x88\xb3\x82\x22"
@@ -2005,10 +2005,11 @@ static const unsigned char prog_partab_so_data_391fe66185bac152 [1316] =
   "\x2a\xb4\x2a\x99\xc3\x0d\x1c\x0c\x0d\x0d\x08\x89\xb1\x2a\x08\xb2"
   "\x2a\x28\x0d\x28\x0d\x28\x0d\x26\x1b\x24\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x70\x61\x72\x74\x61\x62\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
   "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
   "\x0e\x04\x82\x02\x03\x02\x0f\x04\x82\x02\x03\x02\x0c\x25\x72\x65"
@@ -2069,19 +2070,19 @@ static const unsigned char prog_partab_so_data_391fe66185bac152 [1316] =
   "\x83\x02\x1b\x36";
 
 SCHEME_OBJECT *
-partab_so_data_391fe66185bac152 (entry_count_t dispatch_base)
+partab_so_data_dde18eb2a152a87f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_partab_so_data_391fe66185bac152 [0]))), (sizeof (prog_partab_so_data_391fe66185bac152)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_partab_so_data_dde18eb2a152a87f [0]))), (sizeof (prog_partab_so_data_dde18eb2a152a87f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_20]));
 }
 
-DECLARE_COMPILED_DATA_NS ("partab.so", partab_so_data_391fe66185bac152)
+DECLARE_COMPILED_DATA_NS ("partab.so", partab_so_data_dde18eb2a152a87f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("partab.so", "ebb2464c1edaa8a8")
+DECLARE_DYNAMIC_INITIALIZATION ("partab.so", "b2e279143b67ab81")
