@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:42-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:52-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2314,7 +2314,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-poplat_so_1ade153649b4c63c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+poplat_so_168ae88a70b67e05 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2406,7 +2406,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_poplat_so_1ade153649b4c63c [15] =
+static const struct liarc_code_S arr_decl_poplat_so_168ae88a70b67e05 [15] =
   {
     { "poplat_so_code_1", 4, poplat_so_code_1 },
     { "poplat_so_code_2", 3, poplat_so_code_2 },
@@ -2426,19 +2426,19 @@ static const struct liarc_code_S arr_decl_poplat_so_1ade153649b4c63c [15] =
   };
 
 int
-decl_poplat_so_1ade153649b4c63c (void)
+decl_poplat_so_168ae88a70b67e05 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_poplat_so_1ade153649b4c63c);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_poplat_so_168ae88a70b67e05);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("poplat.so", 3, decl_poplat_so_1ade153649b4c63c, poplat_so_1ade153649b4c63c)
+DECLARE_COMPILED_CODE ("poplat.so", 3, decl_poplat_so_168ae88a70b67e05, poplat_so_168ae88a70b67e05)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_poplat_so_data_1ade153649b4c63c [1546] =
+static const unsigned char prog_poplat_so_data_168ae88a70b67e05 [1562] =
   "\x27\x1a\xb3\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x08\x0d\xb9\x25"
   "\x0d\xba\x0d\xbb\x24\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x2b\xbc\x1d\xb0\x82\x88\x0d\xbd\xb2\x24\x28\x0d\x28\x0d"
@@ -2466,10 +2466,11 @@ static const unsigned char prog_poplat_so_data_1ade153649b4c63c [1546] =
   "\x1b\x2a\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x02\xb5\x08\x88\xb7"
   "\x08\x88\xb6\x2a\xb4\x2a\x17\x0d\x0d\x1b\x0d\x0d\x1b\x0d\x0d\x0d"
   "\xb1\xb3\x1b\x0d\x0d\x0d\xb2\xb7\x0d\x0d\x17\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x70\x6f\x70\x6c\x61\x74\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
   "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
   "\x1a\x70\x6f\x70\x75\x6c\x61\x74\x69\x6f\x6e\x2d\x6f\x66\x2d\x70"
@@ -2538,19 +2539,19 @@ static const unsigned char prog_poplat_so_data_1ade153649b4c63c [1546] =
   "\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-poplat_so_data_1ade153649b4c63c (entry_count_t dispatch_base)
+poplat_so_data_168ae88a70b67e05 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_poplat_so_data_1ade153649b4c63c [0]))), (sizeof (prog_poplat_so_data_1ade153649b4c63c)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_poplat_so_data_168ae88a70b67e05 [0]))), (sizeof (prog_poplat_so_data_168ae88a70b67e05)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("poplat.so", poplat_so_data_1ade153649b4c63c)
+DECLARE_COMPILED_DATA_NS ("poplat.so", poplat_so_data_168ae88a70b67e05)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("poplat.so", "a4b8fe325569c9c7")
+DECLARE_DYNAMIC_INITIALIZATION ("poplat.so", "40ae16d4c8f6717a")
