@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:44-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:54-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2246,7 +2246,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-prop1d_so_ed41fe277874c781 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+prop1d_so_154c4a99088320cf (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2337,7 +2337,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_prop1d_so_ed41fe277874c781 [14] =
+static const struct liarc_code_S arr_decl_prop1d_so_154c4a99088320cf [14] =
   {
     { "prop1d_so_code_1", 4, prop1d_so_code_1 },
     { "prop1d_so_code_2", 3, prop1d_so_code_2 },
@@ -2356,19 +2356,19 @@ static const struct liarc_code_S arr_decl_prop1d_so_ed41fe277874c781 [14] =
   };
 
 int
-decl_prop1d_so_ed41fe277874c781 (void)
+decl_prop1d_so_154c4a99088320cf (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_prop1d_so_ed41fe277874c781);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_prop1d_so_154c4a99088320cf);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("prop1d.so", 3, decl_prop1d_so_ed41fe277874c781, prop1d_so_ed41fe277874c781)
+DECLARE_COMPILED_CODE ("prop1d.so", 3, decl_prop1d_so_154c4a99088320cf, prop1d_so_154c4a99088320cf)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_prop1d_so_data_ed41fe277874c781 [1486] =
+static const unsigned char prog_prop1d_so_data_154c4a99088320cf [1502] =
   "\x2b\x18\x99\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x25\x0d"
   "\xba\x24\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21"
   "\x17\x2b\xbb\x1d\xb0\x82\x88\x0d\x0d\xbc\x24\x28\x0d\x28\x0d\x23"
@@ -2394,10 +2394,11 @@ static const unsigned char prog_prop1d_so_data_ed41fe277874c781 [1486] =
   "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
   "\x2a\x0c\x0c\x1b\x2a\x1b\x2a\xb7\x2a\x1e\xb5\x2a\xb3\x2a\x17\x0d"
   "\x0d\xb6\x0d\x0d\x0d\x0d\x1b\x0d\x1b\xb4\x0d\x0d\xb2\xb1\x0d\x0d"
-  "\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
+  "\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
+  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
   "\x6e\x74\x69\x6d\x65\x2f\x70\x72\x6f\x70\x31\x64\x2e\x69\x6e\x66"
   "\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d"
   "\x72\x6f\x6f\x74\x5d\x02\x18\x70\x6f\x70\x75\x6c\x61\x74\x69\x6f"
@@ -2464,19 +2465,19 @@ static const unsigned char prog_prop1d_so_data_ed41fe277874c781 [1486] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-prop1d_so_data_ed41fe277874c781 (entry_count_t dispatch_base)
+prop1d_so_data_154c4a99088320cf (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_prop1d_so_data_ed41fe277874c781 [0]))), (sizeof (prog_prop1d_so_data_ed41fe277874c781)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_prop1d_so_data_154c4a99088320cf [0]))), (sizeof (prog_prop1d_so_data_154c4a99088320cf)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("prop1d.so", prop1d_so_data_ed41fe277874c781)
+DECLARE_COMPILED_DATA_NS ("prop1d.so", prop1d_so_data_154c4a99088320cf)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("prop1d.so", "158a907349b0e04a")
+DECLARE_DYNAMIC_INITIALIZATION ("prop1d.so", "88b47005a1c5fba5")
