@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:44-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:54-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1490,7 +1490,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-qsort_so_9edd5b6999fd5c74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+qsort_so_0ebd2104f4792fd3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1569,26 +1569,26 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_qsort_so_9edd5b6999fd5c74 [2] =
+static const struct liarc_code_S arr_decl_qsort_so_0ebd2104f4792fd3 [2] =
   {
     { "qsort_so_code_1", 4, qsort_so_code_1 },
     { "qsort_so_code_2", 32, qsort_so_code_2 }
   };
 
 int
-decl_qsort_so_9edd5b6999fd5c74 (void)
+decl_qsort_so_0ebd2104f4792fd3 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_qsort_so_9edd5b6999fd5c74);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_qsort_so_0ebd2104f4792fd3);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("qsort.so", 3, decl_qsort_so_9edd5b6999fd5c74, qsort_so_9edd5b6999fd5c74)
+DECLARE_COMPILED_CODE ("qsort.so", 3, decl_qsort_so_0ebd2104f4792fd3, qsort_so_0ebd2104f4792fd3)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_qsort_so_data_9edd5b6999fd5c74 [587] =
+static const unsigned char prog_qsort_so_data_0ebd2104f4792fd3 [603] =
   "\x52\x05\x88\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\x28\x0d"
   "\x28\x0d\x28\x0d\xb9\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
   "\x2b\xba\x1d\xb0\x82\x88\xc3\x1d\xc2\x0c\xb1\x80\xc1\x28\x0d\x23"
@@ -1597,10 +1597,11 @@ static const unsigned char prog_qsort_so_data_9edd5b6999fd5c74 [587] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x2b\xb8\x99\xbb\x88\xb3\xb0\x2a\xb2\x2a\x99\xb1\x0d\x99"
-  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x42\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
+  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x52\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
   "\x74\x69\x6d\x65\x2f\x71\x73\x6f\x72\x74\x2e\x69\x6e\x66\x15\x23"
   "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
   "\x6f\x74\x5d\x02\x03\x0c\x76\x65\x63\x74\x6f\x72\x2d\x63\x6f\x70"
@@ -1628,19 +1629,19 @@ static const unsigned char prog_qsort_so_data_9edd5b6999fd5c74 [587] =
   "\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-qsort_so_data_9edd5b6999fd5c74 (entry_count_t dispatch_base)
+qsort_so_data_0ebd2104f4792fd3 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_qsort_so_data_9edd5b6999fd5c74 [0]))), (sizeof (prog_qsort_so_data_9edd5b6999fd5c74)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_qsort_so_data_0ebd2104f4792fd3 [0]))), (sizeof (prog_qsort_so_data_0ebd2104f4792fd3)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("qsort.so", qsort_so_data_9edd5b6999fd5c74)
+DECLARE_COMPILED_DATA_NS ("qsort.so", qsort_so_data_0ebd2104f4792fd3)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("qsort.so", "772226be48b0d79b")
+DECLARE_DYNAMIC_INITIALIZATION ("qsort.so", "f313def6c9e4d914")
