@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:44-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:54-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1499,7 +1499,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-queue_so_bf54a8e58a072fe8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+queue_so_dffc4a5a42c72e0f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1588,7 +1588,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_queue_so_bf54a8e58a072fe8 [12] =
+static const struct liarc_code_S arr_decl_queue_so_dffc4a5a42c72e0f [12] =
   {
     { "queue_so_code_1", 1, queue_so_code_1 },
     { "queue_so_code_2", 2, queue_so_code_2 },
@@ -1605,19 +1605,19 @@ static const struct liarc_code_S arr_decl_queue_so_bf54a8e58a072fe8 [12] =
   };
 
 int
-decl_queue_so_bf54a8e58a072fe8 (void)
+decl_queue_so_dffc4a5a42c72e0f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_queue_so_bf54a8e58a072fe8);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_queue_so_dffc4a5a42c72e0f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("queue.so", 3, decl_queue_so_bf54a8e58a072fe8, queue_so_bf54a8e58a072fe8)
+DECLARE_COMPILED_CODE ("queue.so", 3, decl_queue_so_dffc4a5a42c72e0f, queue_so_dffc4a5a42c72e0f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_queue_so_data_bf54a8e58a072fe8 [988] =
+static const unsigned char prog_queue_so_data_dffc4a5a42c72e0f [1004] =
   "\x26\x11\xae\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x08\x22\x29\x21"
   "\x9d\x2b\xb9\x1d\xb0\x82\x88\x07\xc1\xba\x22\x29\x22\x29\x21\x17"
   "\x2b\xbb\x1d\xb0\x83\x88\xb2\x28\x0d\xbc\x23\x22\x29\x22\x29\x21"
@@ -1637,9 +1637,10 @@ static const unsigned char prog_queue_so_data_bf54a8e58a072fe8 [988] =
   "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb4\x2a\x1b\x2a\xb6\x2a\x1b\x2a"
   "\x1b\x2a\xb5\x2a\xb3\x2a\xb1\x2a\x17\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
   "\xb7\x1b\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21"
-  "\x17\x02\x42\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d"
-  "\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69"
-  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73"
+  "\x17\x02\x52\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f"
+  "\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65"
+  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d"
+  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73"
   "\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x71\x75\x65\x75\x65"
   "\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74"
   "\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x04\x82\x02\x03\x02"
@@ -1682,19 +1683,19 @@ static const unsigned char prog_queue_so_data_bf54a8e58a072fe8 [988] =
   "\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-queue_so_data_bf54a8e58a072fe8 (entry_count_t dispatch_base)
+queue_so_data_dffc4a5a42c72e0f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_queue_so_data_bf54a8e58a072fe8 [0]))), (sizeof (prog_queue_so_data_bf54a8e58a072fe8)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_queue_so_data_dffc4a5a42c72e0f [0]))), (sizeof (prog_queue_so_data_dffc4a5a42c72e0f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("queue.so", queue_so_data_bf54a8e58a072fe8)
+DECLARE_COMPILED_DATA_NS ("queue.so", queue_so_data_dffc4a5a42c72e0f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("queue.so", "90fc42bacbf956ad")
+DECLARE_DYNAMIC_INITIALIZATION ("queue.so", "baf710b2d0f9909c")
