@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:49-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:58-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1746,7 +1746,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-savres_so_13c1ccc50261d913 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+savres_so_222fc7055e72d104 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1826,7 +1826,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_savres_so_13c1ccc50261d913 [3] =
+static const struct liarc_code_S arr_decl_savres_so_222fc7055e72d104 [3] =
   {
     { "savres_so_code_1", 42, savres_so_code_1 },
     { "savres_so_code_2", 15, savres_so_code_2 },
@@ -1834,19 +1834,19 @@ static const struct liarc_code_S arr_decl_savres_so_13c1ccc50261d913 [3] =
   };
 
 int
-decl_savres_so_13c1ccc50261d913 (void)
+decl_savres_so_222fc7055e72d104 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_savres_so_13c1ccc50261d913);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_savres_so_222fc7055e72d104);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("savres.so", 3, decl_savres_so_13c1ccc50261d913, savres_so_13c1ccc50261d913)
+DECLARE_COMPILED_CODE ("savres.so", 3, decl_savres_so_222fc7055e72d104, savres_so_222fc7055e72d104)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_savres_so_data_13c1ccc50261d913 [1973] =
+static const unsigned char prog_savres_so_data_222fc7055e72d104 [1989] =
   "\x95\x01\x0b\xdb\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0d\x0c"
   "\xc2\x1d\xc2\xc1\x07\xc1\xc0\x1d\x0d\xb9\x0d\xba\x0d\xbb\x25\xb3"
   "\x0d\x0d\xb2\x0d\x24\x28\x0d\xbc\x28\x0d\x28\x0d\xbd\x28\x0d\x28"
@@ -1869,9 +1869,10 @@ static const unsigned char prog_savres_so_data_13c1ccc50261d913 [1973] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbe\x9a"
   "\xbd\x88\xb5\xb6\x2a\x1b\x2a\x1b\x2a\x06\x06\x0c\x9d\xb7\x0d\x0d"
   "\xb2\xb1\xb3\x9d\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02"
-  "\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63"
+  "\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
+  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
+  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
   "\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x61\x76\x72\x65\x73\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x12\x44\x69\x73\x6b\x20\x73"
@@ -1973,19 +1974,19 @@ static const unsigned char prog_savres_so_data_13c1ccc50261d913 [1973] =
   "\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-savres_so_data_13c1ccc50261d913 (entry_count_t dispatch_base)
+savres_so_data_222fc7055e72d104 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_savres_so_data_13c1ccc50261d913 [0]))), (sizeof (prog_savres_so_data_13c1ccc50261d913)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_savres_so_data_222fc7055e72d104 [0]))), (sizeof (prog_savres_so_data_222fc7055e72d104)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("savres.so", savres_so_data_13c1ccc50261d913)
+DECLARE_COMPILED_DATA_NS ("savres.so", savres_so_data_222fc7055e72d104)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("savres.so", "9f9792d01eb31a28")
+DECLARE_DYNAMIC_INITIALIZATION ("savres.so", "511df307e54ce594")
