@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:49-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:59-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2987,7 +2987,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-scan_so_c29e215d446a6bed (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+scan_so_ef16c105d088f611 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3074,7 +3074,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_scan_so_c29e215d446a6bed [10] =
+static const struct liarc_code_S arr_decl_scan_so_ef16c105d088f611 [10] =
   {
     { "scan_so_code_1", 2, scan_so_code_1 },
     { "scan_so_code_2", 3, scan_so_code_2 },
@@ -3089,19 +3089,19 @@ static const struct liarc_code_S arr_decl_scan_so_c29e215d446a6bed [10] =
   };
 
 int
-decl_scan_so_c29e215d446a6bed (void)
+decl_scan_so_ef16c105d088f611 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_scan_so_c29e215d446a6bed);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_scan_so_ef16c105d088f611);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("scan.so", 3, decl_scan_so_c29e215d446a6bed, scan_so_c29e215d446a6bed)
+DECLARE_COMPILED_CODE ("scan.so", 3, decl_scan_so_ef16c105d088f611, scan_so_ef16c105d088f611)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_scan_so_data_c29e215d446a6bed [1986] =
+static const unsigned char prog_scan_so_data_ef16c105d088f611 [2002] =
   "\x7f\x19\x83\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x02\x0d\xb9\x24"
   "\x28\x0d\xba\x23\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88"
   "\x08\xb1\x24\x28\x0d\xbc\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
@@ -3134,10 +3134,11 @@ static const unsigned char prog_scan_so_data_c29e215d446a6bed [1986] =
   "\x1b\x1b\x2a\x1b\x2a\x1b\x2a\xb2\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
   "\x2a\xb5\x2a\xb3\x2a\xb1\x08\x88\x02\x02\xb6\x17\x1b\x1b\xb7\x1b"
   "\x0d\x1b\x1b\xb4\x0d\x1b\xb1\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x41\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x51\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x73\x63\x61\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x1a\x0e"
   "\x6e\x75\x6c\x6c\x2d\x73\x65\x71\x75\x65\x6e\x63\x65\x02\x05\x11"
@@ -3229,19 +3230,19 @@ static const unsigned char prog_scan_so_data_c29e215d446a6bed [1986] =
   "\x07\x11";
 
 SCHEME_OBJECT *
-scan_so_data_c29e215d446a6bed (entry_count_t dispatch_base)
+scan_so_data_ef16c105d088f611 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_scan_so_data_c29e215d446a6bed [0]))), (sizeof (prog_scan_so_data_c29e215d446a6bed)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_scan_so_data_ef16c105d088f611 [0]))), (sizeof (prog_scan_so_data_ef16c105d088f611)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("scan.so", scan_so_data_c29e215d446a6bed)
+DECLARE_COMPILED_DATA_NS ("scan.so", scan_so_data_ef16c105d088f611)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("scan.so", "09ac68cb96f355b0")
+DECLARE_DYNAMIC_INITIALIZATION ("scan.so", "2b8b9d521118fc01")
