@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:49-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:59-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1673,7 +1673,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-sdata_so_5c919fa73d80bc80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+sdata_so_b09756d4bc4283d9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1769,7 +1769,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_sdata_so_5c919fa73d80bc80 [19] =
+static const struct liarc_code_S arr_decl_sdata_so_b09756d4bc4283d9 [19] =
   {
     { "sdata_so_code_1", 2, sdata_so_code_1 },
     { "sdata_so_code_2", 2, sdata_so_code_2 },
@@ -1793,19 +1793,19 @@ static const struct liarc_code_S arr_decl_sdata_so_5c919fa73d80bc80 [19] =
   };
 
 int
-decl_sdata_so_5c919fa73d80bc80 (void)
+decl_sdata_so_b09756d4bc4283d9 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_sdata_so_5c919fa73d80bc80);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_sdata_so_b09756d4bc4283d9);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("sdata.so", 3, decl_sdata_so_5c919fa73d80bc80, sdata_so_5c919fa73d80bc80)
+DECLARE_COMPILED_CODE ("sdata.so", 3, decl_sdata_so_b09756d4bc4283d9, sdata_so_b09756d4bc4283d9)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_sdata_so_data_5c919fa73d80bc80 [1517] =
+static const unsigned char prog_sdata_so_data_b09756d4bc4283d9 [1533] =
   "\x2e\x17\x9d\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc3\xb9\x08\x28"
   "\x0d\xba\x23\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\x28"
   "\x0d\xbc\x23\x22\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x83\x88\xc2"
@@ -1832,9 +1832,10 @@ static const unsigned char prog_sdata_so_data_5c919fa73d80bc80 [1517] =
   "\x1b\x2a\x1b\x2a\xb6\x2a\x1b\x2a\xb1\x2a\xb7\x2a\xb5\x2a\xb3\x2a"
   "\x17\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
   "\x0d\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17"
-  "\x02\x42\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70"
-  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74"
-  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72"
+  "\x02\x52\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66"
+  "\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c"
+  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
+  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72"
   "\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x64\x61\x74\x61\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x11\x73\x79\x73\x74\x65\x6d"
@@ -1903,19 +1904,19 @@ static const unsigned char prog_sdata_so_data_5c919fa73d80bc80 [1517] =
   "\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-sdata_so_data_5c919fa73d80bc80 (entry_count_t dispatch_base)
+sdata_so_data_b09756d4bc4283d9 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_sdata_so_data_5c919fa73d80bc80 [0]))), (sizeof (prog_sdata_so_data_5c919fa73d80bc80)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_sdata_so_data_b09756d4bc4283d9 [0]))), (sizeof (prog_sdata_so_data_b09756d4bc4283d9)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("sdata.so", sdata_so_data_5c919fa73d80bc80)
+DECLARE_COMPILED_DATA_NS ("sdata.so", sdata_so_data_b09756d4bc4283d9)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("sdata.so", "728d09420cbc3860")
+DECLARE_DYNAMIC_INITIALIZATION ("sdata.so", "805f2774eed56f51")
