@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:50-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:50:59-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2205,7 +2205,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-socket_so_ecb57b09f6ce35f8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+socket_so_d61b07f52a9aba70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2302,7 +2302,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_socket_so_ecb57b09f6ce35f8 [20] =
+static const struct liarc_code_S arr_decl_socket_so_d61b07f52a9aba70 [20] =
   {
     { "socket_so_code_1", 5, socket_so_code_1 },
     { "socket_so_code_2", 4, socket_so_code_2 },
@@ -2327,19 +2327,19 @@ static const struct liarc_code_S arr_decl_socket_so_ecb57b09f6ce35f8 [20] =
   };
 
 int
-decl_socket_so_ecb57b09f6ce35f8 (void)
+decl_socket_so_d61b07f52a9aba70 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_socket_so_ecb57b09f6ce35f8);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_socket_so_d61b07f52a9aba70);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("socket.so", 3, decl_socket_so_ecb57b09f6ce35f8, socket_so_ecb57b09f6ce35f8)
+DECLARE_COMPILED_CODE ("socket.so", 3, decl_socket_so_d61b07f52a9aba70, socket_so_d61b07f52a9aba70)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_socket_so_data_ecb57b09f6ce35f8 [2591] =
+static const unsigned char prog_socket_so_data_d61b07f52a9aba70 [2607] =
   "\x39\x24\xae\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc0\xb9\x1d\x28"
   "\x0d\xba\x28\x0d\xbb\x28\x0d\xbc\x23\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x82\x88\xc2\x07\xc0\x28\x0d"
@@ -2375,9 +2375,10 @@ static const unsigned char prog_socket_so_data_ecb57b09f6ce35f8 [2591] =
   "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb7\x2a\xb5\x2a\x17\x0d\x0d\x0d"
   "\x0d\x1b\x1b\x0d\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d"
   "\x1b\xb4\xb3\xb2\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21"
-  "\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d"
-  "\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69"
-  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73"
+  "\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f"
+  "\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65"
+  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d"
+  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73"
   "\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x6f\x63\x6b\x65"
   "\x74\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x11\x68\x6f\x73\x74"
@@ -2504,19 +2505,19 @@ static const unsigned char prog_socket_so_data_ecb57b09f6ce35f8 [2591] =
   "\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-socket_so_data_ecb57b09f6ce35f8 (entry_count_t dispatch_base)
+socket_so_data_d61b07f52a9aba70 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_socket_so_data_ecb57b09f6ce35f8 [0]))), (sizeof (prog_socket_so_data_ecb57b09f6ce35f8)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_socket_so_data_d61b07f52a9aba70 [0]))), (sizeof (prog_socket_so_data_d61b07f52a9aba70)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("socket.so", socket_so_data_ecb57b09f6ce35f8)
+DECLARE_COMPILED_DATA_NS ("socket.so", socket_so_data_d61b07f52a9aba70)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("socket.so", "f5e0db19a75a1608")
+DECLARE_DYNAMIC_INITIALIZATION ("socket.so", "b2c6a05f9a1fdf5f")
