@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:55-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:05-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -3059,7 +3059,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-symbol_so_44ab93803baaa73e (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+symbol_so_e9387ba557fceac9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -3167,7 +3167,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_symbol_so_44ab93803baaa73e [31] =
+static const struct liarc_code_S arr_decl_symbol_so_e9387ba557fceac9 [31] =
   {
     { "symbol_so_code_1", 2, symbol_so_code_1 },
     { "symbol_so_code_2", 1, symbol_so_code_2 },
@@ -3203,19 +3203,19 @@ static const struct liarc_code_S arr_decl_symbol_so_44ab93803baaa73e [31] =
   };
 
 int
-decl_symbol_so_44ab93803baaa73e (void)
+decl_symbol_so_e9387ba557fceac9 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_symbol_so_44ab93803baaa73e);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_symbol_so_e9387ba557fceac9);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("symbol.so", 3, decl_symbol_so_44ab93803baaa73e, symbol_so_44ab93803baaa73e)
+DECLARE_COMPILED_CODE ("symbol.so", 3, decl_symbol_so_e9387ba557fceac9, symbol_so_e9387ba557fceac9)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_symbol_so_data_44ab93803baaa73e [2617] =
+static const unsigned char prog_symbol_so_data_e9387ba557fceac9 [2633] =
   "\x3f\x2d\xdc\x05\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x85\xc2\xb9"
   "\x02\x22\x29\x22\x29\x21\x17\x2b\xba\x1d\xb0\x82\x88\xb1\x07\x02"
   "\x22\x29\x21\x9f\x2b\xbb\x1d\xb0\x83\x88\xb1\x07\x85\x22\x29\x21"
@@ -3262,9 +3262,10 @@ static const unsigned char prog_symbol_so_data_44ab93803baaa73e [2617] =
   "\x2a\xb2\x2a\x17\x0d\x0d\x0d\x1b\x1b\x1b\x0d\x0d\x1b\x1b\x1b\x0d"
   "\x0d\x0d\x0d\x0d\x1b\x0d\x0d\x1b\x0d\x0d\xb1\x0d\x1b\x0d\xb5\x1b"
   "\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02"
-  "\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63"
+  "\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
+  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
+  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
   "\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x79\x6d\x62\x6f\x6c\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x0d\x6f\x62\x6a\x65\x63\x74"
@@ -3382,19 +3383,19 @@ static const unsigned char prog_symbol_so_data_44ab93803baaa73e [2617] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-symbol_so_data_44ab93803baaa73e (entry_count_t dispatch_base)
+symbol_so_data_e9387ba557fceac9 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_symbol_so_data_44ab93803baaa73e [0]))), (sizeof (prog_symbol_so_data_44ab93803baaa73e)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_symbol_so_data_e9387ba557fceac9 [0]))), (sizeof (prog_symbol_so_data_e9387ba557fceac9)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("symbol.so", symbol_so_data_44ab93803baaa73e)
+DECLARE_COMPILED_DATA_NS ("symbol.so", symbol_so_data_e9387ba557fceac9)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("symbol.so", "0a2d4ca780566b0d")
+DECLARE_DYNAMIC_INITIALIZATION ("symbol.so", "a8a462ba90f084bf")
