@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:55-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:05-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1939,7 +1939,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-syntax_check_so_12827bd23a739d66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+syntax_check_so_2056ed7114a6bc8c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2020,7 +2020,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_syntax_check_so_12827bd23a739d66 [4] =
+static const struct liarc_code_S arr_decl_syntax_check_so_2056ed7114a6bc8c [4] =
   {
     { "syntax_check_so_code_1", 4, syntax_check_so_code_1 },
     { "syntax_check_so_code_2", 1, syntax_check_so_code_2 },
@@ -2029,19 +2029,19 @@ static const struct liarc_code_S arr_decl_syntax_check_so_12827bd23a739d66 [4] =
   };
 
 int
-decl_syntax_check_so_12827bd23a739d66 (void)
+decl_syntax_check_so_2056ed7114a6bc8c (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_check_so_12827bd23a739d66);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_check_so_2056ed7114a6bc8c);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("syntax-check.so", 3, decl_syntax_check_so_12827bd23a739d66, syntax_check_so_12827bd23a739d66)
+DECLARE_COMPILED_CODE ("syntax-check.so", 3, decl_syntax_check_so_2056ed7114a6bc8c, syntax_check_so_2056ed7114a6bc8c)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_syntax_check_so_data_12827bd23a739d66 [1036] =
+static const unsigned char prog_syntax_check_so_data_2056ed7114a6bc8c [1052] =
   "\x9a\x01\x08\xf4\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\xc1\xb9"
   "\x28\x0d\xba\x28\x0d\xbb\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21"
   "\x17\x2b\xbc\x1d\xb0\x82\x88\x0c\x28\x0d\x23\x22\x29\x21\x17\x2b"
@@ -2057,10 +2057,11 @@ static const unsigned char prog_syntax_check_so_data_12827bd23a739d66 [1036] =
   "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xb9\x1d\xb0\x84\x88\x28\x0d"
   "\x28\xb2\x23\x22\x29\x22\x29\x21\x17\x2b\xb8\x9b\xbe\x88\xb6\xb0"
   "\x2a\xb1\x2a\xb5\x2a\xb4\x2a\x9b\x0d\xb2\xb3\x0d\x9b\x28\x0d\x26"
-  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x49\x2f\x55\x73\x65\x72\x73"
-  "\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65"
-  "\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
-  "\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d"
+  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73"
+  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63"
+  "\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
+  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d"
   "\x65\x2f\x73\x79\x6e\x74\x61\x78\x2d\x63\x68\x65\x63\x6b\x2e\x69"
   "\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f"
   "\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x02\x04\x63\x64\x72\x04\x0e\x73"
@@ -2109,19 +2110,19 @@ static const unsigned char prog_syntax_check_so_data_12827bd23a739d66 [1036] =
   "\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-syntax_check_so_data_12827bd23a739d66 (entry_count_t dispatch_base)
+syntax_check_so_data_2056ed7114a6bc8c (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_syntax_check_so_data_12827bd23a739d66 [0]))), (sizeof (prog_syntax_check_so_data_12827bd23a739d66)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_syntax_check_so_data_2056ed7114a6bc8c [0]))), (sizeof (prog_syntax_check_so_data_2056ed7114a6bc8c)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("syntax-check.so", syntax_check_so_data_12827bd23a739d66)
+DECLARE_COMPILED_DATA_NS ("syntax-check.so", syntax_check_so_data_2056ed7114a6bc8c)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("syntax-check.so", "49d1aa27c6f03d42")
+DECLARE_DYNAMIC_INITIALIZATION ("syntax-check.so", "87a9e6cb8ccc3294")
