@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:55-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:05-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1719,7 +1719,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-syntax_classify_so_d9622183c5b11e67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+syntax_classify_so_0ba8d37fdbf62fb7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1803,7 +1803,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_syntax_classify_so_d9622183c5b11e67 [7] =
+static const struct liarc_code_S arr_decl_syntax_classify_so_0ba8d37fdbf62fb7 [7] =
   {
     { "syntax_classify_so_code_1", 37, syntax_classify_so_code_1 },
     { "syntax_classify_so_code_2", 2, syntax_classify_so_code_2 },
@@ -1815,19 +1815,19 @@ static const struct liarc_code_S arr_decl_syntax_classify_so_d9622183c5b11e67 [7
   };
 
 int
-decl_syntax_classify_so_d9622183c5b11e67 (void)
+decl_syntax_classify_so_0ba8d37fdbf62fb7 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_classify_so_d9622183c5b11e67);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_classify_so_0ba8d37fdbf62fb7);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("syntax-classify.so", 3, decl_syntax_classify_so_d9622183c5b11e67, syntax_classify_so_d9622183c5b11e67)
+DECLARE_COMPILED_CODE ("syntax-classify.so", 3, decl_syntax_classify_so_0ba8d37fdbf62fb7, syntax_classify_so_0ba8d37fdbf62fb7)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_syntax_classify_so_data_d9622183c5b11e67 [1768] =
+static const unsigned char prog_syntax_classify_so_data_0ba8d37fdbf62fb7 [1784] =
   "\x93\x01\x10\xe2\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x08\x0c\xc1"
   "\xb9\x0d\xc1\xba\x0d\xbb\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
   "\x0d\xbc\x28\x0d\x28\x0d\x28\x0d\xbd\x28\x0d\x28\x0d\x28\x0d\x28"
@@ -1850,10 +1850,11 @@ static const unsigned char prog_syntax_classify_so_data_d9622183c5b11e67 [1768]
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
   "\x9e\xba\x88\xb2\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb3\x2a\x1b\x2a"
   "\x1b\x2a\x9e\x0d\x0d\xb7\xb4\x1b\xb5\xb6\x9e\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x4c\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x5c\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x73\x79\x6e\x74\x61\x78\x2d\x63\x6c\x61\x73\x73\x69\x66\x79\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x23\x43\x6f\x6d\x62\x69\x6e"
@@ -1941,19 +1942,19 @@ static const unsigned char prog_syntax_classify_so_data_d9622183c5b11e67 [1768]
   "\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-syntax_classify_so_data_d9622183c5b11e67 (entry_count_t dispatch_base)
+syntax_classify_so_data_0ba8d37fdbf62fb7 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_syntax_classify_so_data_d9622183c5b11e67 [0]))), (sizeof (prog_syntax_classify_so_data_d9622183c5b11e67)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_syntax_classify_so_data_0ba8d37fdbf62fb7 [0]))), (sizeof (prog_syntax_classify_so_data_0ba8d37fdbf62fb7)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("syntax-classify.so", syntax_classify_so_data_d9622183c5b11e67)
+DECLARE_COMPILED_DATA_NS ("syntax-classify.so", syntax_classify_so_data_0ba8d37fdbf62fb7)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("syntax-classify.so", "29dfaed25e869857")
+DECLARE_DYNAMIC_INITIALIZATION ("syntax-classify.so", "e7087d645722508b")
