@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:55-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:05-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1284,7 +1284,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-syntax_compile_so_ff847bb85b0e543b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+syntax_compile_so_0da0f5598467f03e (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1783,7 +1783,7 @@ DEFLABEL (label_20)
 INVOKE_INTERFACE_TARGET_1
 }
 
-static const struct liarc_code_S arr_decl_syntax_compile_so_ff847bb85b0e543b [10] =
+static const struct liarc_code_S arr_decl_syntax_compile_so_0da0f5598467f03e [10] =
   {
     { "syntax_compile_so_code_1", 8, syntax_compile_so_code_1 },
     { "syntax_compile_so_code_2", 8, syntax_compile_so_code_2 },
@@ -1798,19 +1798,19 @@ static const struct liarc_code_S arr_decl_syntax_compile_so_ff847bb85b0e543b [10
   };
 
 int
-decl_syntax_compile_so_ff847bb85b0e543b (void)
+decl_syntax_compile_so_0da0f5598467f03e (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_compile_so_ff847bb85b0e543b);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_compile_so_0da0f5598467f03e);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("syntax-compile.so", 30, decl_syntax_compile_so_ff847bb85b0e543b, syntax_compile_so_ff847bb85b0e543b)
+DECLARE_COMPILED_CODE ("syntax-compile.so", 30, decl_syntax_compile_so_0da0f5598467f03e, syntax_compile_so_0da0f5598467f03e)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_syntax_compile_so_data_ff847bb85b0e543b [1964] =
+static const unsigned char prog_syntax_compile_so_data_0da0f5598467f03e [1980] =
   "\x5f\x11\x99\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28"
   "\x0d\xba\x28\x0d\xbb\x28\x0d\xbc\x28\x0d\xbd\x28\x0d\x28\x0d\x28"
   "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -1836,10 +1836,11 @@ static const unsigned char prog_syntax_compile_so_data_ff847bb85b0e543b [1964] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4b\x2f\x55"
-  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c"
-  "\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
-  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5b\x2f\x55"
+  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
+  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
+  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
   "\x6e\x74\x69\x6d\x65\x2f\x73\x79\x6e\x74\x61\x78\x2d\x63\x6f\x6d"
   "\x70\x69\x6c\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x03\x0e"
@@ -1936,19 +1937,19 @@ static const unsigned char prog_syntax_compile_so_data_ff847bb85b0e543b [1964] =
   "\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02\x3d\x5f";
 
 SCHEME_OBJECT *
-syntax_compile_so_data_ff847bb85b0e543b (entry_count_t dispatch_base)
+syntax_compile_so_data_0da0f5598467f03e (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_syntax_compile_so_data_ff847bb85b0e543b [0]))), (sizeof (prog_syntax_compile_so_data_ff847bb85b0e543b)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_syntax_compile_so_data_0da0f5598467f03e [0]))), (sizeof (prog_syntax_compile_so_data_0da0f5598467f03e)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_36]));
 }
 
-DECLARE_COMPILED_DATA_NS ("syntax-compile.so", syntax_compile_so_data_ff847bb85b0e543b)
+DECLARE_COMPILED_DATA_NS ("syntax-compile.so", syntax_compile_so_data_0da0f5598467f03e)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("syntax-compile.so", "98699bcb8a5e8c50")
+DECLARE_DYNAMIC_INITIALIZATION ("syntax-compile.so", "8c167f654015252a")
