@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:56-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:05-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2567,7 +2567,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-syntax_declaration_so_52e20d53e33eeb12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+syntax_declaration_so_f3fd9cdd8deef304 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2748,7 +2748,7 @@ DEFLABEL (continuation_6)
 INVOKE_INTERFACE_TARGET_1
 }
 
-static const struct liarc_code_S arr_decl_syntax_declaration_so_52e20d53e33eeb12 [8] =
+static const struct liarc_code_S arr_decl_syntax_declaration_so_f3fd9cdd8deef304 [8] =
   {
     { "syntax_declaration_so_code_1", 5, syntax_declaration_so_code_1 },
     { "syntax_declaration_so_code_2", 18, syntax_declaration_so_code_2 },
@@ -2761,19 +2761,19 @@ static const struct liarc_code_S arr_decl_syntax_declaration_so_52e20d53e33eeb12
   };
 
 int
-decl_syntax_declaration_so_52e20d53e33eeb12 (void)
+decl_syntax_declaration_so_f3fd9cdd8deef304 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_declaration_so_52e20d53e33eeb12);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_declaration_so_f3fd9cdd8deef304);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("syntax-declaration.so", 8, decl_syntax_declaration_so_52e20d53e33eeb12, syntax_declaration_so_52e20d53e33eeb12)
+DECLARE_COMPILED_CODE ("syntax-declaration.so", 8, decl_syntax_declaration_so_f3fd9cdd8deef304, syntax_declaration_so_f3fd9cdd8deef304)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_syntax_declaration_so_data_52e20d53e33eeb12 [1857] =
+static const unsigned char prog_syntax_declaration_so_data_f3fd9cdd8deef304 [1873] =
   "\x4c\x14\xf2\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\x1d\x0d\xb9"
   "\x25\xb1\x24\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x21\x17\x2b\xbb\x1d\xb0\x82\x88\x0c\x0c\xc1\xbc\x06\x07\x85"
@@ -2805,9 +2805,10 @@ static const unsigned char prog_syntax_declaration_so_data_52e20d53e33eeb12 [185
   "\x2a\x1b\x2a\x1b\x2a\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x08"
   "\x14\xb1\x0d\x1b\x9a\x08\xb6\x2a\xb3\x2a\x9a\x28\x0d\x26\x28\x0d"
   "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x21\x17\x02\x4f\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
-  "\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
-  "\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39"
+  "\x29\x22\x29\x21\x17\x02\x5f\x2f\x55\x73\x65\x72\x73\x2f\x63\x70"
+  "\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d"
+  "\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f"
+  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
   "\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73"
   "\x79\x6e\x74\x61\x78\x2d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f"
   "\x6e\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
@@ -2893,19 +2894,19 @@ static const unsigned char prog_syntax_declaration_so_data_52e20d53e33eeb12 [185
   "\x2f";
 
 SCHEME_OBJECT *
-syntax_declaration_so_data_52e20d53e33eeb12 (entry_count_t dispatch_base)
+syntax_declaration_so_data_f3fd9cdd8deef304 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_syntax_declaration_so_data_52e20d53e33eeb12 [0]))), (sizeof (prog_syntax_declaration_so_data_52e20d53e33eeb12)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_syntax_declaration_so_data_f3fd9cdd8deef304 [0]))), (sizeof (prog_syntax_declaration_so_data_f3fd9cdd8deef304)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_14]));
 }
 
-DECLARE_COMPILED_DATA_NS ("syntax-declaration.so", syntax_declaration_so_data_52e20d53e33eeb12)
+DECLARE_COMPILED_DATA_NS ("syntax-declaration.so", syntax_declaration_so_data_f3fd9cdd8deef304)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("syntax-declaration.so", "e42752b9980227e5")
+DECLARE_DYNAMIC_INITIALIZATION ("syntax-declaration.so", "f97d905951dfff61")
