@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:56-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:05-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -936,7 +936,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-syntax_definitions_so_9c15de43825fcfff (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+syntax_definitions_so_17b6cd8fda49a498 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1015,26 +1015,26 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_syntax_definitions_so_9c15de43825fcfff [2] =
+static const struct liarc_code_S arr_decl_syntax_definitions_so_17b6cd8fda49a498 [2] =
   {
     { "syntax_definitions_so_code_1", 1, syntax_definitions_so_code_1 },
     { "syntax_definitions_so_code_2", 43, syntax_definitions_so_code_2 }
   };
 
 int
-decl_syntax_definitions_so_9c15de43825fcfff (void)
+decl_syntax_definitions_so_17b6cd8fda49a498 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_definitions_so_9c15de43825fcfff);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_definitions_so_17b6cd8fda49a498);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("syntax-definitions.so", 3, decl_syntax_definitions_so_9c15de43825fcfff, syntax_definitions_so_9c15de43825fcfff)
+DECLARE_COMPILED_CODE ("syntax-definitions.so", 3, decl_syntax_definitions_so_17b6cd8fda49a498, syntax_definitions_so_17b6cd8fda49a498)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_syntax_definitions_so_data_9c15de43825fcfff [1309] =
+static const unsigned char prog_syntax_definitions_so_data_17b6cd8fda49a498 [1325] =
   "\x8c\x01\x05\xb6\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9"
   "\x23\x22\x29\x21\x9f\x2b\xba\x1d\xb0\x82\x88\x0d\x0d\x0d\x0d\x0d"
   "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
@@ -1046,10 +1046,11 @@ static const unsigned char prog_syntax_definitions_so_data_9c15de43825fcfff [130
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
   "\x17\x2b\xb8\x99\xbb\x88\xb3\xb0\x2a\xb2\x2a\x99\xb1\x0d\x99\x28"
-  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4f\x2f\x55\x73\x65"
-  "\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
+  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x5f\x2f\x55\x73\x65"
+  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
+  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
   "\x69\x6d\x65\x2f\x73\x79\x6e\x74\x61\x78\x2d\x64\x65\x66\x69\x6e"
   "\x69\x74\x69\x6f\x6e\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
   "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
@@ -1119,19 +1120,19 @@ static const unsigned char prog_syntax_definitions_so_data_9c15de43825fcfff [130
   "\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-syntax_definitions_so_data_9c15de43825fcfff (entry_count_t dispatch_base)
+syntax_definitions_so_data_17b6cd8fda49a498 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_syntax_definitions_so_data_9c15de43825fcfff [0]))), (sizeof (prog_syntax_definitions_so_data_9c15de43825fcfff)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_syntax_definitions_so_data_17b6cd8fda49a498 [0]))), (sizeof (prog_syntax_definitions_so_data_17b6cd8fda49a498)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("syntax-definitions.so", syntax_definitions_so_data_9c15de43825fcfff)
+DECLARE_COMPILED_DATA_NS ("syntax-definitions.so", syntax_definitions_so_data_17b6cd8fda49a498)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("syntax-definitions.so", "457f36e211ed9da6")
+DECLARE_DYNAMIC_INITIALIZATION ("syntax-definitions.so", "66f12045b1259625")
