@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:56-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:05-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -570,7 +570,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-syntax_items_so_90d81feb4de7089a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+syntax_items_so_bcca9dbfafd28479 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2544,7 +2544,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_syntax_items_so_90d81feb4de7089a [4] =
+static const struct liarc_code_S arr_decl_syntax_items_so_bcca9dbfafd28479 [4] =
   {
     { "syntax_items_so_code_1", 4, syntax_items_so_code_1 },
     { "syntax_items_so_code_2", 2, syntax_items_so_code_2 },
@@ -2553,19 +2553,19 @@ static const struct liarc_code_S arr_decl_syntax_items_so_90d81feb4de7089a [4] =
   };
 
 int
-decl_syntax_items_so_90d81feb4de7089a (void)
+decl_syntax_items_so_bcca9dbfafd28479 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_items_so_90d81feb4de7089a);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_items_so_bcca9dbfafd28479);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("syntax-items.so", 126, decl_syntax_items_so_90d81feb4de7089a, syntax_items_so_90d81feb4de7089a)
+DECLARE_COMPILED_CODE ("syntax-items.so", 126, decl_syntax_items_so_bcca9dbfafd28479, syntax_items_so_bcca9dbfafd28479)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_syntax_items_so_data_90d81feb4de7089a [2543] =
+static const unsigned char prog_syntax_items_so_data_bcca9dbfafd28479 [2559] =
   "\xdf\x02\x12\xea\x03\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9"
   "\x28\x0d\xba\x28\x0d\xbb\x28\x0d\xbc\x23\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x21\x17\x2b\xbd\x1d\xb0\x82\x88\x0d\xbe\x24\x28\x0d\x23"
@@ -2596,10 +2596,11 @@ static const unsigned char prog_syntax_items_so_data_90d81feb4de7089a [2543] =
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x49"
-  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72"
-  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73"
-  "\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f"
+  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x59"
+  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77"
+  "\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61"
+  "\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
+  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f"
   "\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x79\x6e\x74\x61\x78\x2d\x69"
   "\x74\x65\x6d\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x03\x11"
@@ -2727,19 +2728,19 @@ static const unsigned char prog_syntax_items_so_data_90d81feb4de7089a [2543] =
   "\x02\x02\x06\x81\x89\x02\x01\x04\x81\x83\x02\xfd\x01\xdf\x02";
 
 SCHEME_OBJECT *
-syntax_items_so_data_90d81feb4de7089a (entry_count_t dispatch_base)
+syntax_items_so_data_bcca9dbfafd28479 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_syntax_items_so_data_90d81feb4de7089a [0]))), (sizeof (prog_syntax_items_so_data_90d81feb4de7089a)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_syntax_items_so_data_bcca9dbfafd28479 [0]))), (sizeof (prog_syntax_items_so_data_bcca9dbfafd28479)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_134]));
 }
 
-DECLARE_COMPILED_DATA_NS ("syntax-items.so", syntax_items_so_data_90d81feb4de7089a)
+DECLARE_COMPILED_DATA_NS ("syntax-items.so", syntax_items_so_data_bcca9dbfafd28479)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("syntax-items.so", "b3a2311e6718c223")
+DECLARE_DYNAMIC_INITIALIZATION ("syntax-items.so", "a25294025e58a79f")
