@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:56-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:06-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -843,7 +843,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-syntax_transforms_so_e98badf930169f77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+syntax_transforms_so_93a929825f129e5f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -927,7 +927,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_syntax_transforms_so_e98badf930169f77 [7] =
+static const struct liarc_code_S arr_decl_syntax_transforms_so_93a929825f129e5f [7] =
   {
     { "syntax_transforms_so_code_1", 3, syntax_transforms_so_code_1 },
     { "syntax_transforms_so_code_2", 3, syntax_transforms_so_code_2 },
@@ -939,19 +939,19 @@ static const struct liarc_code_S arr_decl_syntax_transforms_so_e98badf930169f77
   };
 
 int
-decl_syntax_transforms_so_e98badf930169f77 (void)
+decl_syntax_transforms_so_93a929825f129e5f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_transforms_so_e98badf930169f77);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_syntax_transforms_so_93a929825f129e5f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("syntax-transforms.so", 3, decl_syntax_transforms_so_e98badf930169f77, syntax_transforms_so_e98badf930169f77)
+DECLARE_COMPILED_CODE ("syntax-transforms.so", 3, decl_syntax_transforms_so_93a929825f129e5f, syntax_transforms_so_93a929825f129e5f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_syntax_transforms_so_data_e98badf930169f77 [805] =
+static const unsigned char prog_syntax_transforms_so_data_93a929825f129e5f [821] =
   "\x1c\x0c\xc3\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x28\x0d\xb9\x28"
   "\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0\x82"
   "\x88\x28\xb1\x28\xb2\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbc"
@@ -964,10 +964,11 @@ static const unsigned char prog_syntax_transforms_so_data_e98badf930169f77 [805]
   "\xba\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xb9"
   "\x9e\xb8\x88\xb0\xb1\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb7\x2a\xb4\x2a"
   "\xb3\x2a\x9e\xb2\x0d\xb5\xb6\x0d\x0d\x0d\x9e\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x4e\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x5e\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x73\x79\x6e\x74\x61\x78\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d"
   "\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61"
   "\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x03\x13\x6d\x61\x6b"
@@ -1005,19 +1006,19 @@ static const unsigned char prog_syntax_transforms_so_data_e98badf930169f77 [805]
   "\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-syntax_transforms_so_data_e98badf930169f77 (entry_count_t dispatch_base)
+syntax_transforms_so_data_93a929825f129e5f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_syntax_transforms_so_data_e98badf930169f77 [0]))), (sizeof (prog_syntax_transforms_so_data_e98badf930169f77)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_syntax_transforms_so_data_93a929825f129e5f [0]))), (sizeof (prog_syntax_transforms_so_data_93a929825f129e5f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("syntax-transforms.so", syntax_transforms_so_data_e98badf930169f77)
+DECLARE_COMPILED_DATA_NS ("syntax-transforms.so", syntax_transforms_so_data_93a929825f129e5f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("syntax-transforms.so", "a6257738d25cd801")
+DECLARE_DYNAMIC_INITIALIZATION ("syntax-transforms.so", "736042949ff8fa41")
