@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:56-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:06-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1451,7 +1451,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-sysclk_so_47cf7fd7b438883a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+sysclk_so_72978662f2cad41c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1538,7 +1538,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_sysclk_so_47cf7fd7b438883a [10] =
+static const struct liarc_code_S arr_decl_sysclk_so_72978662f2cad41c [10] =
   {
     { "sysclk_so_code_1", 4, sysclk_so_code_1 },
     { "sysclk_so_code_2", 5, sysclk_so_code_2 },
@@ -1553,19 +1553,19 @@ static const struct liarc_code_S arr_decl_sysclk_so_47cf7fd7b438883a [10] =
   };
 
 int
-decl_sysclk_so_47cf7fd7b438883a (void)
+decl_sysclk_so_72978662f2cad41c (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_sysclk_so_47cf7fd7b438883a);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_sysclk_so_72978662f2cad41c);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("sysclk.so", 3, decl_sysclk_so_47cf7fd7b438883a, sysclk_so_47cf7fd7b438883a)
+DECLARE_COMPILED_CODE ("sysclk.so", 3, decl_sysclk_so_72978662f2cad41c, sysclk_so_72978662f2cad41c)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_sysclk_so_data_47cf7fd7b438883a [1099] =
+static const unsigned char prog_sysclk_so_data_72978662f2cad41c [1115] =
   "\x2e\x14\xa8\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x0d\x24"
   "\x28\xb1\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
   "\xba\x1d\xb0\x82\x88\x80\xc0\xbb\x0d\xbc\x0d\xbd\x25\xb5\x24\x22"
@@ -1584,10 +1584,11 @@ static const unsigned char prog_sysclk_so_data_47cf7fd7b438883a [1099] =
   "\x21\x17\x2b\x1c\x17\x1c\x88\x1b\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
   "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb0\xb3\x1e\x1e\xb6\x2a\xb2\x2a"
   "\x17\x0d\x0d\x1b\xb7\x0d\x1b\x0d\x0d\x0d\x0d\xb5\xb4\xb1\x0d\x17"
-  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
+  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
   "\x74\x69\x6d\x65\x2f\x73\x79\x73\x63\x6c\x6b\x2e\x69\x6e\x66\x15"
   "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
   "\x6f\x6f\x74\x5d\x02\x14\x72\x65\x73\x65\x74\x2d\x73\x79\x73\x74"
@@ -1637,19 +1638,19 @@ static const unsigned char prog_sysclk_so_data_47cf7fd7b438883a [1099] =
   "\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-sysclk_so_data_47cf7fd7b438883a (entry_count_t dispatch_base)
+sysclk_so_data_72978662f2cad41c (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_sysclk_so_data_47cf7fd7b438883a [0]))), (sizeof (prog_sysclk_so_data_47cf7fd7b438883a)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_sysclk_so_data_72978662f2cad41c [0]))), (sizeof (prog_sysclk_so_data_72978662f2cad41c)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("sysclk.so", sysclk_so_data_47cf7fd7b438883a)
+DECLARE_COMPILED_DATA_NS ("sysclk.so", sysclk_so_data_72978662f2cad41c)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("sysclk.so", "00dc61ebe22ca155")
+DECLARE_DYNAMIC_INITIALIZATION ("sysclk.so", "a1551cb2b029f308")
