@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:57-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:06-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1801,7 +1801,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-sysmac_so_febb571f722e00f6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+sysmac_so_b2bb52706c528e2e (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2160,7 +2160,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_sysmac_so_febb571f722e00f6 [6] =
+static const struct liarc_code_S arr_decl_sysmac_so_b2bb52706c528e2e [6] =
   {
     { "sysmac_so_code_1", 22, sysmac_so_code_1 },
     { "sysmac_so_code_2", 3, sysmac_so_code_2 },
@@ -2171,19 +2171,19 @@ static const struct liarc_code_S arr_decl_sysmac_so_febb571f722e00f6 [6] =
   };
 
 int
-decl_sysmac_so_febb571f722e00f6 (void)
+decl_sysmac_so_b2bb52706c528e2e (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_sysmac_so_febb571f722e00f6);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_sysmac_so_b2bb52706c528e2e);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("sysmac.so", 20, decl_sysmac_so_febb571f722e00f6, sysmac_so_febb571f722e00f6)
+DECLARE_COMPILED_CODE ("sysmac.so", 20, decl_sysmac_so_b2bb52706c528e2e, sysmac_so_b2bb52706c528e2e)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_sysmac_so_data_febb571f722e00f6 [1481] =
+static const unsigned char prog_sysmac_so_data_b2bb52706c528e2e [1497] =
   "\x51\x0d\xd0\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\x81\x0d\xc2"
   "\xb9\x08\x06\x07\x85\xc2\x02\xc1\xba\x0d\xbb\xc1\xbc\x0d\xbd\x24"
   "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\xbe\x23"
@@ -2205,9 +2205,10 @@ static const unsigned char prog_sysmac_so_data_febb571f722e00f6 [1481] =
   "\x1b\x2a\xb7\x2a\x28\x0d\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
-  "\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f"
-  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31"
+  "\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
+  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
+  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
+  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
   "\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x79\x73"
   "\x6d\x61\x63\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
   "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x02\x61\x12"
@@ -2279,19 +2280,19 @@ static const unsigned char prog_sysmac_so_data_febb571f722e00f6 [1481] =
   "\x85\x02\x01\x04\x81\x83\x02\x29\x43";
 
 SCHEME_OBJECT *
-sysmac_so_data_febb571f722e00f6 (entry_count_t dispatch_base)
+sysmac_so_data_b2bb52706c528e2e (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_sysmac_so_data_febb571f722e00f6 [0]))), (sizeof (prog_sysmac_so_data_febb571f722e00f6)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_sysmac_so_data_b2bb52706c528e2e [0]))), (sizeof (prog_sysmac_so_data_b2bb52706c528e2e)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_25]));
 }
 
-DECLARE_COMPILED_DATA_NS ("sysmac.so", sysmac_so_data_febb571f722e00f6)
+DECLARE_COMPILED_DATA_NS ("sysmac.so", sysmac_so_data_b2bb52706c528e2e)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("sysmac.so", "6a0058ebf12fbac9")
+DECLARE_DYNAMIC_INITIALIZATION ("sysmac.so", "7111d43bfd8d19e5")
