@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:57-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:06-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1793,7 +1793,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-system_so_a3a3d4c37251ea89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+system_so_038856944edd9295 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1879,7 +1879,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_system_so_a3a3d4c37251ea89 [9] =
+static const struct liarc_code_S arr_decl_system_so_038856944edd9295 [9] =
   {
     { "system_so_code_1", 14, system_so_code_1 },
     { "system_so_code_2", 11, system_so_code_2 },
@@ -1893,19 +1893,19 @@ static const struct liarc_code_S arr_decl_system_so_a3a3d4c37251ea89 [9] =
   };
 
 int
-decl_system_so_a3a3d4c37251ea89 (void)
+decl_system_so_038856944edd9295 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_system_so_a3a3d4c37251ea89);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_system_so_038856944edd9295);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("system.so", 3, decl_system_so_a3a3d4c37251ea89, system_so_a3a3d4c37251ea89)
+DECLARE_COMPILED_CODE ("system.so", 3, decl_system_so_038856944edd9295, system_so_038856944edd9295)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_system_so_data_a3a3d4c37251ea89 [1417] =
+static const unsigned char prog_system_so_data_038856944edd9295 [1433] =
   "\x3f\x11\xe1\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\xc2\xb9\x1d"
   "\xc2\x08\x0c\x0d\xba\x0d\xbb\x25\xb3\x24\x28\x0d\xbc\x28\x0d\x28"
   "\x0d\xbd\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22"
@@ -1928,9 +1928,10 @@ static const unsigned char prog_system_so_data_a3a3d4c37251ea89 [1417] =
   "\x22\x29\x21\x17\x2b\x1c\x17\xbf\x88\xb7\x08\x1b\x2a\xb1\x2a\xb4"
   "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb6\x2a\x17\xb3\x1b"
   "\xb5\x1b\x0d\x0d\x0d\x0d\x0d\xb2\x17\x28\x0d\x26\x22\x29\x22\x29"
-  "\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
-  "\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
-  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
+  "\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65"
+  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d"
+  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e"
   "\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x79"
   "\x73\x74\x65\x6d\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66"
   "\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x1b\x49"
@@ -1997,19 +1998,19 @@ static const unsigned char prog_system_so_data_a3a3d4c37251ea89 [1417] =
   "\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-system_so_data_a3a3d4c37251ea89 (entry_count_t dispatch_base)
+system_so_data_038856944edd9295 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_system_so_data_a3a3d4c37251ea89 [0]))), (sizeof (prog_system_so_data_a3a3d4c37251ea89)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_system_so_data_038856944edd9295 [0]))), (sizeof (prog_system_so_data_038856944edd9295)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("system.so", system_so_data_a3a3d4c37251ea89)
+DECLARE_COMPILED_DATA_NS ("system.so", system_so_data_038856944edd9295)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("system.so", "6d860bc55aa46688")
+DECLARE_DYNAMIC_INITIALIZATION ("system.so", "c0f77e9b34197e6d")
