@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:58-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:07-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -263,7 +263,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-tscript_so_965820b7c9e3e62c (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+tscript_so_1485cbcd4ca69a16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -342,35 +342,36 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_tscript_so_965820b7c9e3e62c [2] =
+static const struct liarc_code_S arr_decl_tscript_so_1485cbcd4ca69a16 [2] =
   {
     { "tscript_so_code_1", 5, tscript_so_code_1 },
     { "tscript_so_code_2", 4, tscript_so_code_2 }
   };
 
 int
-decl_tscript_so_965820b7c9e3e62c (void)
+decl_tscript_so_1485cbcd4ca69a16 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_tscript_so_965820b7c9e3e62c);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_tscript_so_1485cbcd4ca69a16);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("tscript.so", 3, decl_tscript_so_965820b7c9e3e62c, tscript_so_965820b7c9e3e62c)
+DECLARE_COMPILED_CODE ("tscript.so", 3, decl_tscript_so_1485cbcd4ca69a16, tscript_so_1485cbcd4ca69a16)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_tscript_so_data_965820b7c9e3e62c [429] =
+static const unsigned char prog_tscript_so_data_1485cbcd4ca69a16 [445] =
   "\x1e\x06\x59\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x1d\x28\x0d\xb9"
   "\x28\x0d\xba\x28\x0d\x28\x0d\x28\x0d\xbb\x23\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x82\x88\x1d\x1d\x28"
   "\xb1\x28\xb2\x28\xb3\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
   "\x21\x17\x2b\xbb\x99\xba\x88\xb2\xb3\x2a\xb4\x2a\x99\x0d\x0d\x99"
-  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x44\x2f\x55\x73"
-  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65"
-  "\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
-  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
+  "\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x54\x2f\x55\x73"
+  "\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65"
+  "\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d"
+  "\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
+  "\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e"
   "\x74\x69\x6d\x65\x2f\x74\x73\x63\x72\x69\x70\x74\x2e\x69\x6e\x66"
   "\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d"
   "\x72\x6f\x6f\x74\x5d\x02\x1e\x54\x72\x61\x6e\x73\x63\x72\x69\x70"
@@ -391,19 +392,19 @@ static const unsigned char prog_tscript_so_data_965820b7c9e3e62c [429] =
   "\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-tscript_so_data_965820b7c9e3e62c (entry_count_t dispatch_base)
+tscript_so_data_1485cbcd4ca69a16 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_tscript_so_data_965820b7c9e3e62c [0]))), (sizeof (prog_tscript_so_data_965820b7c9e3e62c)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_tscript_so_data_1485cbcd4ca69a16 [0]))), (sizeof (prog_tscript_so_data_1485cbcd4ca69a16)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("tscript.so", tscript_so_data_965820b7c9e3e62c)
+DECLARE_COMPILED_DATA_NS ("tscript.so", tscript_so_data_1485cbcd4ca69a16)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("tscript.so", "29ddbca7503cde49")
+DECLARE_DYNAMIC_INITIALIZATION ("tscript.so", "bf13d0ce6edcae4a")
