@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:58-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:07-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2408,7 +2408,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-ttyio_so_6182667c77879a4a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+ttyio_so_266befbf6a3db89f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2499,7 +2499,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_ttyio_so_6182667c77879a4a [14] =
+static const struct liarc_code_S arr_decl_ttyio_so_266befbf6a3db89f [14] =
   {
     { "ttyio_so_code_1", 32, ttyio_so_code_1 },
     { "ttyio_so_code_2", 4, ttyio_so_code_2 },
@@ -2518,19 +2518,19 @@ static const struct liarc_code_S arr_decl_ttyio_so_6182667c77879a4a [14] =
   };
 
 int
-decl_ttyio_so_6182667c77879a4a (void)
+decl_ttyio_so_266befbf6a3db89f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_ttyio_so_6182667c77879a4a);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_ttyio_so_266befbf6a3db89f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("ttyio.so", 3, decl_ttyio_so_6182667c77879a4a, ttyio_so_6182667c77879a4a)
+DECLARE_COMPILED_CODE ("ttyio.so", 3, decl_ttyio_so_266befbf6a3db89f, ttyio_so_266befbf6a3db89f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_ttyio_so_data_6182667c77879a4a [2662] =
+static const unsigned char prog_ttyio_so_data_266befbf6a3db89f [2678] =
   "\x83\x01\x21\xa6\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\x0d\xb9"
   "\x0d\x0d\x0d\x0d\x0d\xba\x0d\x0d\xbb\x0d\x0d\x0d\x08\x80\x0d\x0d"
   "\xbc\x0d\xbd\x25\x0d\xbe\x0d\x0d\xbf\x0d\x0d\x1c\x0d\x1c\x0d\x1c"
@@ -2565,10 +2565,11 @@ static const unsigned char prog_ttyio_so_data_6182667c77879a4a [2662] =
   "\x2a\xb2\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1e\x1e\x1e\x1b\x2a\x1b"
   "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1e\x1b\x2a\x17\x1b\x1b\x1b\x1b\x1b"
   "\x1b\x1b\x1b\x1b\x1b\x1b\xb5\x0d\x1b\x1b\xb7\xb6\xb4\x0d\x17\x28"
-  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x42\x2f\x55\x73\x65"
-  "\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61"
-  "\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
-  "\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
+  "\x0d\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x52\x2f\x55\x73\x65"
+  "\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f"
+  "\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
+  "\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d"
+  "\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74"
   "\x69\x6d\x65\x2f\x74\x74\x79\x69\x6f\x2e\x69\x6e\x66\x15\x23\x5b"
   "\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f"
   "\x74\x5d\x02\x05\x62\x65\x65\x70\x0c\x63\x68\x61\x72\x2d\x72\x65"
@@ -2700,19 +2701,19 @@ static const unsigned char prog_ttyio_so_data_6182667c77879a4a [2662] =
   "\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-ttyio_so_data_6182667c77879a4a (entry_count_t dispatch_base)
+ttyio_so_data_266befbf6a3db89f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_ttyio_so_data_6182667c77879a4a [0]))), (sizeof (prog_ttyio_so_data_6182667c77879a4a)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_ttyio_so_data_266befbf6a3db89f [0]))), (sizeof (prog_ttyio_so_data_266befbf6a3db89f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("ttyio.so", ttyio_so_data_6182667c77879a4a)
+DECLARE_COMPILED_DATA_NS ("ttyio.so", ttyio_so_data_266befbf6a3db89f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("ttyio.so", "eef584c556f79ae0")
+DECLARE_DYNAMIC_INITIALIZATION ("ttyio.so", "7bf9900a7c3a21ec")
