@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:33:58-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:07-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1488,7 +1488,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-tvector_so_b2c4c7579300409b (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+tvector_so_c3c337ba9128ffbf (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1578,7 +1578,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_tvector_so_b2c4c7579300409b [13] =
+static const struct liarc_code_S arr_decl_tvector_so_c3c337ba9128ffbf [13] =
   {
     { "tvector_so_code_1", 7, tvector_so_code_1 },
     { "tvector_so_code_2", 4, tvector_so_code_2 },
@@ -1596,19 +1596,19 @@ static const struct liarc_code_S arr_decl_tvector_so_b2c4c7579300409b [13] =
   };
 
 int
-decl_tvector_so_b2c4c7579300409b (void)
+decl_tvector_so_c3c337ba9128ffbf (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_tvector_so_b2c4c7579300409b);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_tvector_so_c3c337ba9128ffbf);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("tvector.so", 3, decl_tvector_so_b2c4c7579300409b, tvector_so_b2c4c7579300409b)
+DECLARE_COMPILED_CODE ("tvector.so", 3, decl_tvector_so_c3c337ba9128ffbf, tvector_so_c3c337ba9128ffbf)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_tvector_so_data_b2c4c7579300409b [1376] =
+static const unsigned char prog_tvector_so_data_c3c337ba9128ffbf [1392] =
   "\x23\x1b\xe6\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc2\xb9\x02\xc3"
   "\xba\x80\x0d\xbb\x0d\xbc\x24\x28\x0d\xbd\x28\x0d\xbe\x28\x0d\x23"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
@@ -1631,10 +1631,11 @@ static const unsigned char prog_tvector_so_data_b2c4c7579300409b [1376] =
   "\xb8\x88\xb0\xb1\x2a\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
   "\x1b\x2a\x1b\x2a\xb5\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb7\x2a\x17\x0d"
   "\xb4\xb6\x1b\x1b\x1b\xb2\x1b\x1b\x1b\x1b\x1b\x0d\xb3\x17\x28\x0d"
-  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x44\x2f\x55\x73\x65\x72"
-  "\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73"
-  "\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65"
-  "\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69"
+  "\x26\x22\x29\x22\x29\x22\x29\x21\x17\x02\x54\x2f\x55\x73\x65\x72"
+  "\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73"
+  "\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63"
+  "\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69"
   "\x6d\x65\x2f\x74\x76\x65\x63\x74\x6f\x72\x2e\x69\x6e\x66\x15\x23"
   "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
   "\x6f\x74\x5d\x02\x10\x6f\x62\x6a\x65\x63\x74\x2d\x73\x65\x74\x2d"
@@ -1697,19 +1698,19 @@ static const unsigned char prog_tvector_so_data_b2c4c7579300409b [1376] =
   "\x08\x80\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-tvector_so_data_b2c4c7579300409b (entry_count_t dispatch_base)
+tvector_so_data_c3c337ba9128ffbf (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_tvector_so_data_b2c4c7579300409b [0]))), (sizeof (prog_tvector_so_data_b2c4c7579300409b)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_tvector_so_data_c3c337ba9128ffbf [0]))), (sizeof (prog_tvector_so_data_c3c337ba9128ffbf)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("tvector.so", tvector_so_data_b2c4c7579300409b)
+DECLARE_COMPILED_DATA_NS ("tvector.so", tvector_so_data_c3c337ba9128ffbf)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("tvector.so", "2253e5c129470907")
+DECLARE_DYNAMIC_INITIALIZATION ("tvector.so", "df0ec0e06398b44d")
