@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:01-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:10-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1153,7 +1153,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-unxdir_so_561be98ef91b5002 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+unxdir_so_5ecea085fd4febee (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1236,7 +1236,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_unxdir_so_561be98ef91b5002 [6] =
+static const struct liarc_code_S arr_decl_unxdir_so_5ecea085fd4febee [6] =
   {
     { "unxdir_so_code_1", 3, unxdir_so_code_1 },
     { "unxdir_so_code_2", 27, unxdir_so_code_2 },
@@ -1247,19 +1247,19 @@ static const struct liarc_code_S arr_decl_unxdir_so_561be98ef91b5002 [6] =
   };
 
 int
-decl_unxdir_so_561be98ef91b5002 (void)
+decl_unxdir_so_5ecea085fd4febee (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_unxdir_so_561be98ef91b5002);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_unxdir_so_5ecea085fd4febee);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("unxdir.so", 3, decl_unxdir_so_561be98ef91b5002, unxdir_so_561be98ef91b5002)
+DECLARE_COMPILED_CODE ("unxdir.so", 3, decl_unxdir_so_5ecea085fd4febee, unxdir_so_5ecea085fd4febee)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_unxdir_so_data_561be98ef91b5002 [1166] =
+static const unsigned char prog_unxdir_so_data_5ecea085fd4febee [1182] =
   "\x66\x0e\x8f\x02\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\x0d\xb9\x24"
   "\x28\x0d\xba\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb"
   "\x1d\xb0\x82\x88\x1d\x0d\xbc\x0d\xbd\x25\x0d\xb5\x24\x28\x0d\xbe"
@@ -1277,9 +1277,10 @@ static const unsigned char prog_unxdir_so_data_561be98ef91b5002 [1166] =
   "\xb0\x86\x88\x07\x28\x0d\x23\x22\x29\x21\x17\x2b\xbc\x9d\xb8\x88"
   "\xb0\xb4\x2a\xb7\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb3\x2a\x07\x9e\x1b"
   "\xb1\x1b\xb6\xb2\x0d\xb5\x9e\x28\x0d\x26\x22\x29\x22\x29\x22\x29"
-  "\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74"
-  "\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d"
-  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f"
+  "\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53"
+  "\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72"
+  "\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74"
+  "\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f"
   "\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x75\x6e\x78\x64"
   "\x69\x72\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63"
   "\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x08\x0b\x70\x61"
@@ -1335,19 +1336,19 @@ static const unsigned char prog_unxdir_so_data_561be98ef91b5002 [1166] =
   "\x80\x04\x02\x06\x81\x81\x02\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-unxdir_so_data_561be98ef91b5002 (entry_count_t dispatch_base)
+unxdir_so_data_5ecea085fd4febee (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_unxdir_so_data_561be98ef91b5002 [0]))), (sizeof (prog_unxdir_so_data_561be98ef91b5002)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_unxdir_so_data_5ecea085fd4febee [0]))), (sizeof (prog_unxdir_so_data_5ecea085fd4febee)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("unxdir.so", unxdir_so_data_561be98ef91b5002)
+DECLARE_COMPILED_DATA_NS ("unxdir.so", unxdir_so_data_5ecea085fd4febee)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("unxdir.so", "32109a1b6eb35444")
+DECLARE_DYNAMIC_INITIALIZATION ("unxdir.so", "93b6cf07cb4ba5cc")
