@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:04-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:13-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -2617,7 +2617,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-where_so_74cd7e6c5ca697e6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+where_so_22ed7abcd33da938 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -2907,7 +2907,7 @@ INVOKE_INTERFACE_TARGET_0
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_where_so_74cd7e6c5ca697e6 [15] =
+static const struct liarc_code_S arr_decl_where_so_22ed7abcd33da938 [15] =
   {
     { "where_so_code_1", 8, where_so_code_1 },
     { "where_so_code_2", 1, where_so_code_2 },
@@ -2927,19 +2927,19 @@ static const struct liarc_code_S arr_decl_where_so_74cd7e6c5ca697e6 [15] =
   };
 
 int
-decl_where_so_74cd7e6c5ca697e6 (void)
+decl_where_so_22ed7abcd33da938 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_where_so_74cd7e6c5ca697e6);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_where_so_22ed7abcd33da938);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("where.so", 13, decl_where_so_74cd7e6c5ca697e6, where_so_74cd7e6c5ca697e6)
+DECLARE_COMPILED_CODE ("where.so", 13, decl_where_so_22ed7abcd33da938, where_so_22ed7abcd33da938)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_where_so_data_74cd7e6c5ca697e6 [2790] =
+static const unsigned char prog_where_so_data_22ed7abcd33da938 [2806] =
   "\x4d\x1e\x93\x04\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x07\x08\x0c"
   "\x1d\x0d\x0c\x0d\xb9\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
   "\xba\x28\x0d\x28\x0d\xbb\x28\x0d\xbc\x23\x22\x29\x22\x29\x22\x29"
@@ -2973,10 +2973,11 @@ static const unsigned char prog_where_so_data_74cd7e6c5ca697e6 [2790] =
   "\x2a\x1b\x2a\x99\x0d\x1c\x0d\x99\xb5\x2a\x0c\x0d\x08\x88\x08\xb6"
   "\x2a\x28\x0d\x28\x0d\x28\x0d\x26\x1b\x24\x22\x29\x22\x29\x22\x29"
   "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x42\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x52\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x77\x68\x65\x72\x65\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69"
   "\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x4b"
   "\x59\x6f\x75\x20\x61\x72\x65\x20\x6e\x6f\x77\x20\x69\x6e\x20\x74"
@@ -3117,19 +3118,19 @@ static const unsigned char prog_where_so_data_74cd7e6c5ca697e6 [2790] =
   "\x04\x81\x83\x02\x1b\x36";
 
 SCHEME_OBJECT *
-where_so_data_74cd7e6c5ca697e6 (entry_count_t dispatch_base)
+where_so_data_22ed7abcd33da938 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_where_so_data_74cd7e6c5ca697e6 [0]))), (sizeof (prog_where_so_data_74cd7e6c5ca697e6)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_where_so_data_22ed7abcd33da938 [0]))), (sizeof (prog_where_so_data_22ed7abcd33da938)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_20]));
 }
 
-DECLARE_COMPILED_DATA_NS ("where.so", where_so_data_74cd7e6c5ca697e6)
+DECLARE_COMPILED_DATA_NS ("where.so", where_so_data_22ed7abcd33da938)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("where.so", "3ea781a8e0907893")
+DECLARE_DYNAMIC_INITIALIZATION ("where.so", "f39acc2438a6bddd")
