@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:04-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:14-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -939,7 +939,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-wrkdir_so_a30a7d06fed422f2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+wrkdir_so_d0629e1db2bc1d0a (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1022,7 +1022,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_wrkdir_so_a30a7d06fed422f2 [6] =
+static const struct liarc_code_S arr_decl_wrkdir_so_d0629e1db2bc1d0a [6] =
   {
     { "wrkdir_so_code_1", 4, wrkdir_so_code_1 },
     { "wrkdir_so_code_2", 6, wrkdir_so_code_2 },
@@ -1033,19 +1033,19 @@ static const struct liarc_code_S arr_decl_wrkdir_so_a30a7d06fed422f2 [6] =
   };
 
 int
-decl_wrkdir_so_a30a7d06fed422f2 (void)
+decl_wrkdir_so_d0629e1db2bc1d0a (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_wrkdir_so_a30a7d06fed422f2);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_wrkdir_so_d0629e1db2bc1d0a);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("wrkdir.so", 3, decl_wrkdir_so_a30a7d06fed422f2, wrkdir_so_a30a7d06fed422f2)
+DECLARE_COMPILED_CODE ("wrkdir.so", 3, decl_wrkdir_so_d0629e1db2bc1d0a, wrkdir_so_d0629e1db2bc1d0a)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_wrkdir_so_data_a30a7d06fed422f2 [919] =
+static const unsigned char prog_wrkdir_so_data_d0629e1db2bc1d0a [935] =
   "\x2b\x0c\xd3\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x0d\x24"
   "\x28\xb1\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
   "\xba\x1d\xb0\x82\x88\x1d\xc0\x0d\xbb\x0d\xbc\x25\x28\x0d\xbd\x28"
@@ -1059,10 +1059,11 @@ static const unsigned char prog_wrkdir_so_data_a30a7d06fed422f2 [919] =
   "\x28\xb5\x28\xb6\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
   "\xbe\x9d\xbd\x88\xb5\xb6\x2a\xb4\x2a\x1b\x2a\x1b\x2a\x1e\xb7\x2a"
   "\xb2\x2a\x9e\x1b\x0d\x0d\x0d\xb3\xb1\x0d\x9e\x28\x0d\x26\x22\x29"
-  "\x22\x29\x22\x29\x21\x17\x02\x43\x2f\x55\x73\x65\x72\x73\x2f\x63"
-  "\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39"
-  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
-  "\x39\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
+  "\x22\x29\x22\x29\x21\x17\x02\x53\x2f\x55\x73\x65\x72\x73\x2f\x63"
+  "\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65"
+  "\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31"
+  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f"
   "\x77\x72\x6b\x64\x69\x72\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72"
   "\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02"
   "\x07\x72\x65\x73\x65\x74\x21\x14\x65\x76\x65\x6e\x74\x3a\x61\x66"
@@ -1106,19 +1107,19 @@ static const unsigned char prog_wrkdir_so_data_a30a7d06fed422f2 [919] =
   "\x01\x04\x81\x81\x02\x07\x11";
 
 SCHEME_OBJECT *
-wrkdir_so_data_a30a7d06fed422f2 (entry_count_t dispatch_base)
+wrkdir_so_data_d0629e1db2bc1d0a (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_wrkdir_so_data_a30a7d06fed422f2 [0]))), (sizeof (prog_wrkdir_so_data_a30a7d06fed422f2)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_wrkdir_so_data_d0629e1db2bc1d0a [0]))), (sizeof (prog_wrkdir_so_data_d0629e1db2bc1d0a)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("wrkdir.so", wrkdir_so_data_a30a7d06fed422f2)
+DECLARE_COMPILED_DATA_NS ("wrkdir.so", wrkdir_so_data_d0629e1db2bc1d0a)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("wrkdir.so", "fc387eb220d1623a")
+DECLARE_DYNAMIC_INITIALIZATION ("wrkdir.so", "7fc8dee44da54c07")
