@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:11-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:21-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -873,7 +873,7 @@ INVOKE_INTERFACE_TARGET_0
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-butils_so_de78c4da102fc1c6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+butils_so_406282e1adf7d7a2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1168,7 +1168,7 @@ INVOKE_INTERFACE_TARGET_1
 INVOKE_PRIMITIVE_TARGET
 }
 
-static const struct liarc_code_S arr_decl_butils_so_de78c4da102fc1c6 [6] =
+static const struct liarc_code_S arr_decl_butils_so_406282e1adf7d7a2 [6] =
   {
     { "butils_so_code_1", 14, butils_so_code_1 },
     { "butils_so_code_2", 1, butils_so_code_2 },
@@ -1179,19 +1179,19 @@ static const struct liarc_code_S arr_decl_butils_so_de78c4da102fc1c6 [6] =
   };
 
 int
-decl_butils_so_de78c4da102fc1c6 (void)
+decl_butils_so_406282e1adf7d7a2 (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_butils_so_de78c4da102fc1c6);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_butils_so_406282e1adf7d7a2);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("butils.so", 17, decl_butils_so_de78c4da102fc1c6, butils_so_de78c4da102fc1c6)
+DECLARE_COMPILED_CODE ("butils.so", 17, decl_butils_so_406282e1adf7d7a2, butils_so_406282e1adf7d7a2)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_butils_so_data_de78c4da102fc1c6 [1113] =
+static const unsigned char prog_butils_so_data_406282e1adf7d7a2 [1129] =
   "\x48\x0b\xfa\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x1d\x1d\x0d\x0d"
   "\x28\x0d\x28\x0d\xb9\x28\xb1\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
   "\x0d\xb9\x28\x0d\x28\x0d\xba\x23\x22\x29\x22\x29\x22\x29\x22\x29"
@@ -1207,10 +1207,11 @@ static const unsigned char prog_butils_so_data_de78c4da102fc1c6 [1113] =
   "\x2a\x1b\x2a\x0c\xb4\x2a\xb6\x2a\xc3\x0d\x1c\xb3\x2a\x28\x0d\x26"
   "\x28\x1b\x28\xb5\x28\xb2\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
-  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x3e\x2f"
-  "\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f\x72\x65"
-  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
-  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63\x2f\x73"
+  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x4e\x2f"
+  "\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61"
+  "\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73"
+  "\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65"
+  "\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x73"
   "\x66\x2f\x62\x75\x74\x69\x6c\x73\x2e\x69\x6e\x66\x15\x23\x5b\x70"
   "\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74"
   "\x5d\x02\x02\x08\x05\x77\x69\x6c\x64\x07\x6e\x65\x77\x65\x73\x74"
@@ -1264,19 +1265,19 @@ static const unsigned char prog_butils_so_data_de78c4da102fc1c6 [1113] =
   "\x83\x02\x01\x04\x81\x83\x02\x23\x48";
 
 SCHEME_OBJECT *
-butils_so_data_de78c4da102fc1c6 (entry_count_t dispatch_base)
+butils_so_data_406282e1adf7d7a2 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_butils_so_data_de78c4da102fc1c6 [0]))), (sizeof (prog_butils_so_data_de78c4da102fc1c6)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_butils_so_data_406282e1adf7d7a2 [0]))), (sizeof (prog_butils_so_data_406282e1adf7d7a2)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_25]));
 }
 
-DECLARE_COMPILED_DATA_NS ("butils.so", butils_so_data_de78c4da102fc1c6)
+DECLARE_COMPILED_DATA_NS ("butils.so", butils_so_data_406282e1adf7d7a2)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("butils.so", "92b9e8152be25cfa")
+DECLARE_DYNAMIC_INITIALIZATION ("butils.so", "c11024b6e4377bcd")
