@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:12-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:21-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -1248,7 +1248,7 @@ INVOKE_PRIMITIVE_TARGET
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-emodel_so_5c07b135c7ece17d (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+emodel_so_84dab40ff096fc7f (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1333,7 +1333,7 @@ DEFLABEL (label_3)
 INVOKE_INTERFACE_TARGET_4
 }
 
-static const struct liarc_code_S arr_decl_emodel_so_5c07b135c7ece17d [8] =
+static const struct liarc_code_S arr_decl_emodel_so_84dab40ff096fc7f [8] =
   {
     { "emodel_so_code_1", 3, emodel_so_code_1 },
     { "emodel_so_code_2", 4, emodel_so_code_2 },
@@ -1346,19 +1346,19 @@ static const struct liarc_code_S arr_decl_emodel_so_5c07b135c7ece17d [8] =
   };
 
 int
-decl_emodel_so_5c07b135c7ece17d (void)
+decl_emodel_so_84dab40ff096fc7f (void)
 {
-  DECLARE_SUBCODE_MULTIPLE (arr_decl_emodel_so_5c07b135c7ece17d);
+  DECLARE_SUBCODE_MULTIPLE (arr_decl_emodel_so_84dab40ff096fc7f);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("emodel.so", 3, decl_emodel_so_5c07b135c7ece17d, emodel_so_5c07b135c7ece17d)
+DECLARE_COMPILED_CODE ("emodel.so", 3, decl_emodel_so_84dab40ff096fc7f, emodel_so_84dab40ff096fc7f)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_emodel_so_data_5c07b135c7ece17d [835] =
+static const unsigned char prog_emodel_so_data_84dab40ff096fc7f [851] =
   "\x20\x10\xf1\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\xb9\x28\x0d"
   "\xba\x28\x0d\xbb\x28\x0d\xbc\x23\x22\x29\x22\x29\x22\x29\x21\x17"
   "\x2b\xbd\x1d\xb0\x82\x88\xc3\xbe\xc2\xbf\x85\x08\x28\x0d\x23\x22"
@@ -1374,9 +1374,10 @@ static const unsigned char prog_emodel_so_data_5c07b135c7ece17d [835] =
   "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbe\x9f\xb8\x88\xb0\xb6"
   "\x2a\x1b\x2a\x1b\x2a\xb2\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb5\x2a\x9f"
   "\xb7\x0d\x0d\x1b\xb3\x1b\xb4\xb1\x9f\x28\x0d\x26\x22\x29\x22\x29"
-  "\x22\x29\x21\x17\x02\x3e\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
-  "\x2f\x74\x6d\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
-  "\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e"
+  "\x22\x29\x21\x17\x02\x4e\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
+  "\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65"
+  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d"
+  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e"
   "\x31\x2f\x73\x72\x63\x2f\x73\x66\x2f\x65\x6d\x6f\x64\x65\x6c\x2e"
   "\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69"
   "\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x14\x76\x61\x72\x69\x61\x62"
@@ -1414,19 +1415,19 @@ static const unsigned char prog_emodel_so_data_5c07b135c7ece17d [835] =
   "\x02\x07\x11";
 
 SCHEME_OBJECT *
-emodel_so_data_5c07b135c7ece17d (entry_count_t dispatch_base)
+emodel_so_data_84dab40ff096fc7f (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_emodel_so_data_5c07b135c7ece17d [0]))), (sizeof (prog_emodel_so_data_5c07b135c7ece17d)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_emodel_so_data_84dab40ff096fc7f [0]))), (sizeof (prog_emodel_so_data_84dab40ff096fc7f)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_7]));
 }
 
-DECLARE_COMPILED_DATA_NS ("emodel.so", emodel_so_data_5c07b135c7ece17d)
+DECLARE_COMPILED_DATA_NS ("emodel.so", emodel_so_data_84dab40ff096fc7f)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("emodel.so", "5f2e0e266f29a60e")
+DECLARE_DYNAMIC_INITIALIZATION ("emodel.so", "9c0a21fd313d0e6c")
