@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:12-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:21-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -123,7 +123,7 @@ INVOKE_INTERFACE_TARGET_1
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-make_so_3ace1476ceb85418 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+make_so_b7410d45eb63a965 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -217,26 +217,27 @@ INVOKE_INTERFACE_TARGET_1
 }
 
 int
-decl_make_so_3ace1476ceb85418 (void)
+decl_make_so_b7410d45eb63a965 (void)
 {
   DECLARE_SUBCODE ("make_so_code_1", 4, make_so_code_1);
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("make.so", 5, decl_make_so_3ace1476ceb85418, make_so_3ace1476ceb85418)
+DECLARE_COMPILED_CODE ("make.so", 5, decl_make_so_b7410d45eb63a965, make_so_b7410d45eb63a965)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_make_so_data_3ace1476ceb85418 [376] =
+static const unsigned char prog_make_so_data_b7410d45eb63a965 [392] =
   "\x1b\x02\x3f\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0d\x08\x88\x0d\x0c"
   "\x28\x0d\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21"
   "\x17\x2b\xb8\x98\x88\xb0\x0c\x84\x02\x08\x89\x0c\xb0\x2a\x28\x0d"
   "\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
-  "\x17\x02\x3c\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d"
-  "\x70\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69"
-  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73"
+  "\x17\x02\x4c\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f"
+  "\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65"
+  "\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d"
+  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73"
   "\x72\x63\x2f\x73\x66\x2f\x6d\x61\x6b\x65\x2e\x69\x6e\x66\x15\x23"
   "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
   "\x6f\x74\x5d\x02\x10\x73\x63\x6f\x64\x65\x2d\x6f\x70\x74\x69\x6d"
@@ -256,19 +257,19 @@ static const unsigned char prog_make_so_data_3ace1476ceb85418 [376] =
   "\x02\x01\x04\x81\x83\x02\x0b\x1b";
 
 SCHEME_OBJECT *
-make_so_data_3ace1476ceb85418 (entry_count_t dispatch_base)
+make_so_data_b7410d45eb63a965 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_make_so_data_3ace1476ceb85418 [0]))), (sizeof (prog_make_so_data_3ace1476ceb85418)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_make_so_data_b7410d45eb63a965 [0]))), (sizeof (prog_make_so_data_b7410d45eb63a965)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_11]));
 }
 
-DECLARE_COMPILED_DATA_NS ("make.so", make_so_data_3ace1476ceb85418)
+DECLARE_COMPILED_DATA_NS ("make.so", make_so_data_b7410d45eb63a965)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("make.so", "dc74527591054d87")
+DECLARE_DYNAMIC_INITIALIZATION ("make.so", "3147315db101ea6a")
