@@ -1,5 +1,5 @@
 /* Emacs: this is -*- C -*- code, */
-/* generated 2011-10-15T20:34:13-07 by Liar version 4.118. */
+/* generated 2011-11-08T22:51:23-08 by Liar version 4.118. */
 
 #include "liarc.h"
 
@@ -94,7 +94,7 @@
 #ifndef WANT_ONLY_DATA
 
 SCHEME_OBJECT *
-pthmap_so_faa31244a692bcc8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
+pthmap_so_86af4667c66b5294 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
 {
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES ();
@@ -1276,18 +1276,18 @@ INVOKE_PRIMITIVE_TARGET
 }
 
 int
-decl_pthmap_so_faa31244a692bcc8 (void)
+decl_pthmap_so_86af4667c66b5294 (void)
 {
   return (0);
 }
 
-DECLARE_COMPILED_CODE ("pthmap.so", 48, decl_pthmap_so_faa31244a692bcc8, pthmap_so_faa31244a692bcc8)
+DECLARE_COMPILED_CODE ("pthmap.so", 48, decl_pthmap_so_86af4667c66b5294, pthmap_so_86af4667c66b5294)
 
 #endif /* !WANT_ONLY_DATA */
 
 #ifndef WANT_ONLY_CODE
 
-static const unsigned char prog_pthmap_so_data_faa31244a692bcc8 [810] =
+static const unsigned char prog_pthmap_so_data_86af4667c66b5294 [826] =
   "\x8e\x01\x05\x9b\x01\x1d\x0c\x1d\x0d\xb8\x07\x0d\xb9\x0d\xba\x0c"
   "\xc1\x08\xc1\x0c\xc3\x0d\xbb\x0c\xb0\xb1\xb2\xb3\x9b\x1e\x1e\x1e"
   "\x1e\x9b\x28\x0d\x26\x0d\x0d\x0d\x0d\x24\x28\x0d\x28\x0d\x28\x0d"
@@ -1298,9 +1298,10 @@ static const unsigned char prog_pthmap_so_data_faa31244a692bcc8 [810] =
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
   "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02"
-  "\x3e\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x74\x6d\x70\x2f"
-  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2f\x6d\x69\x74\x2d"
-  "\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2f\x73\x72\x63"
+  "\x4e\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74"
+  "\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65"
+  "\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63"
+  "\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63"
   "\x2f\x73\x66\x2f\x70\x74\x68\x6d\x61\x70\x2e\x69\x6e\x66\x02\x15"
   "\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x6d\x61\x70\x2f\x69\x6e\x73"
   "\x65\x72\x74\x21\x14\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x6d\x61"
@@ -1341,19 +1342,19 @@ static const unsigned char prog_pthmap_so_data_faa31244a692bcc8 [810] =
   "\x95\x02\x01\x04\x81\x83\x02\x61\x8e\x01";
 
 SCHEME_OBJECT *
-pthmap_so_data_faa31244a692bcc8 (entry_count_t dispatch_base)
+pthmap_so_data_86af4667c66b5294 (entry_count_t dispatch_base)
 {
   SCHEME_OBJECT ccb;
   SCHEME_OBJECT * current_block;
   DECLARE_VARIABLES_FOR_DATA ();
 
-  ccb = (unstackify (((unsigned char *) (& (prog_pthmap_so_data_faa31244a692bcc8 [0]))), (sizeof (prog_pthmap_so_data_faa31244a692bcc8)), dispatch_base));
+  ccb = (unstackify (((unsigned char *) (& (prog_pthmap_so_data_86af4667c66b5294 [0]))), (sizeof (prog_pthmap_so_data_86af4667c66b5294)), dispatch_base));
   current_block = (OBJECT_ADDRESS (ccb));
   return (& (current_block [LABEL_67]));
 }
 
-DECLARE_COMPILED_DATA_NS ("pthmap.so", pthmap_so_data_faa31244a692bcc8)
+DECLARE_COMPILED_DATA_NS ("pthmap.so", pthmap_so_data_86af4667c66b5294)
 
 #endif /* !WANT_ONLY_CODE */
 
-DECLARE_DYNAMIC_INITIALIZATION ("pthmap.so", "01f53a6c45116614")
+DECLARE_DYNAMIC_INITIALIZATION ("pthmap.so", "3e21eb0e14e27fcf")
